diff -pruN 4:18.04.1-1/CMakeLists.txt 4:20.04.1-0ubuntu1/CMakeLists.txt
--- 4:18.04.1-1/CMakeLists.txt	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/CMakeLists.txt	2020-05-12 01:16:33.000000000 +0000
@@ -1,25 +1,32 @@
 cmake_minimum_required(VERSION 3.0)
 
-set(SWEEPER_VERSION "1.11")
-project(sweeper VERSION ${SWEEPER_VERSION})
+# KDE Application Version, managed by release script
+set (RELEASE_SERVICE_VERSION_MAJOR "20")
+set (RELEASE_SERVICE_VERSION_MINOR "04")
+set (RELEASE_SERVICE_VERSION_MICRO "1")
+set (RELEASE_SERVICE_VERSION "${RELEASE_SERVICE_VERSION_MAJOR}.${RELEASE_SERVICE_VERSION_MINOR}.${RELEASE_SERVICE_VERSION_MICRO}")
+
+project(sweeper VERSION ${RELEASE_SERVICE_VERSION})
+
+set(REQUIRED_KF5_MIN_VERSION "5.23.0")
+set(REQUIRED_QT_VERSION "5.4.0")
 
 include(FeatureSummary)
-find_package(Qt5 REQUIRED COMPONENTS Core DBus Widgets)
-find_package(ECM 1.7.0 NO_MODULE REQUIRED)
+find_package(Qt5 ${REQUIRED_QT_VERSION} REQUIRED COMPONENTS Core DBus Widgets)
+find_package(ECM ${REQUIRED_KF5_MIN_VERSION} NO_MODULE REQUIRED)
 set(CMAKE_MODULE_PATH ${CMAKE_MODULE_PATH} ${ECM_MODULE_PATH} ${ECM_KDE_MODULE_DIR})
 
 include(ECMAddAppIcon)
 include(KDEInstallDirs)
 include(KDECMakeSettings)
-include(KDECompilerSettings NO_POLICY_SCOPE)
+include(KDEFrameworkCompilerSettings NO_POLICY_SCOPE)
 
 add_definitions(
-    -DQT_NO_CAST_TO_ASCII
-    -DQT_NO_CAST_FROM_ASCII
-    -DQT_NO_URL_CAST_FROM_STRING
+    -DQT_DISABLE_DEPRECATED_BEFORE=0x050400
+    -DQT_NO_NARROWING_CONVERSIONS_IN_CONNECT
 )
 
-find_package(KF5 5.23.0 REQUIRED COMPONENTS
+find_package(KF5 ${REQUIRED_KF5_MIN_VERSION} REQUIRED COMPONENTS
     ActivitiesStats
     Bookmarks
     Crash
@@ -32,6 +39,13 @@ find_package(KF5 5.23.0 REQUIRED COMPONE
     TextWidgets
     XmlGui
 )
+
+if (KF5Config_VERSION VERSION_GREATER "5.56.0")
+        add_definitions(-DQT_NO_FOREACH)
+        MESSAGE(STATUS "compile without foreach")
+endif()
+
+
 include_directories (${CMAKE_CURRENT_SOURCE_DIR} ${CMAKE_CURRENT_BINARY_DIR} )
 
 configure_file(config-sweeper.h.cmake
diff -pruN 4:18.04.1-1/config-sweeper.h.cmake 4:20.04.1-0ubuntu1/config-sweeper.h.cmake
--- 4:18.04.1-1/config-sweeper.h.cmake	2018-05-06 04:10:53.000000000 +0000
+++ 4:20.04.1-0ubuntu1/config-sweeper.h.cmake	2020-05-11 21:17:33.000000000 +0000
@@ -1,3 +1,3 @@
-#define SWEEPER_VERSION "${SWEEPER_VERSION}"
+#define SWEEPER_VERSION "${RELEASE_SERVICE_VERSION}"
 
 #define KDE_INSTALL_FULL_LIBEXECDIR_KF5 "${KDE_INSTALL_FULL_LIBEXECDIR_KF5}"
diff -pruN 4:18.04.1-1/debian/changelog 4:20.04.1-0ubuntu1/debian/changelog
--- 4:18.04.1-1/debian/changelog	2018-05-30 22:43:29.000000000 +0000
+++ 4:20.04.1-0ubuntu1/debian/changelog	2020-05-15 13:43:40.000000000 +0000
@@ -1,3 +1,117 @@
+sweeper (4:20.04.1-0ubuntu1) groovy; urgency=medium
+
+  * New upstream release (20.04.1)
+
+ -- Rik Mills <rikmills@kde.org>  Fri, 15 May 2020 14:43:40 +0100
+
+sweeper (4:20.04.0-0ubuntu1) groovy; urgency=medium
+
+  * New upstream release (20.04.0)
+
+ -- Rik Mills <rikmills@kde.org>  Mon, 04 May 2020 10:29:13 +0100
+
+sweeper (4:19.12.3-0ubuntu1) focal; urgency=medium
+
+  * New upstream release (19.12.3)
+
+ -- Rik Mills <rikmills@kde.org>  Thu, 05 Mar 2020 16:19:13 +0000
+
+sweeper (4:19.12.2-0ubuntu1) focal; urgency=medium
+
+  * New upstream release (19.12.2)
+  * Update watch file to the new release-service location.
+
+ -- Rik Mills <rikmills@kde.org>  Thu, 06 Feb 2020 15:27:50 +0000
+
+sweeper (4:19.12.1-0ubuntu1) focal; urgency=medium
+
+  * New upstream release (19.12.1)
+
+ -- Rik Mills <rikmills@kde.org>  Thu, 09 Jan 2020 15:02:17 +0000
+
+sweeper (4:19.12.0-0ubuntu1) focal; urgency=medium
+
+  * New upstream release (19.12.0)
+
+ -- Rik Mills <rikmills@kde.org>  Thu, 12 Dec 2019 10:55:55 +0000
+
+sweeper (4:19.08.3-0ubuntu1) focal; urgency=medium
+
+  * New upstream release (19.08.0)
+  * New upstream release (19.08.1)
+  * New upstream release (19.08.2)
+  * New upstream release (19.08.3)
+
+ -- Rik Mills <rikmills@kde.org>  Thu, 07 Nov 2019 13:40:32 +0000
+
+sweeper (4:19.04.3-0ubuntu1) eoan; urgency=medium
+
+  * New upstream release (19.04.3)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Thu, 11 Jul 2019 14:22:03 +0100
+
+sweeper (4:19.04.2-0ubuntu1) eoan; urgency=medium
+
+  * New upstream release (19.04.2)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Sat, 08 Jun 2019 15:17:57 +0100
+
+sweeper (4:19.04.1-0ubuntu1) eoan; urgency=medium
+
+  * New upstream release (19.04.1)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Sun, 12 May 2019 21:05:31 +0100
+
+sweeper (4:19.04.0-0ubuntu1) eoan; urgency=medium
+
+  * New upstream release (19.04.0)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Fri, 26 Apr 2019 20:50:48 +0100
+
+sweeper (4:18.12.3-0ubuntu1) disco; urgency=medium
+
+  * New upstream release (18.12.3)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Thu, 07 Mar 2019 13:36:23 +0000
+
+sweeper (4:18.12.2-0ubuntu1) disco; urgency=medium
+
+  * New upstream release (18.12.2)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Sun, 17 Feb 2019 13:23:22 +0000
+
+sweeper (4:18.12.1-0ubuntu1) disco; urgency=medium
+
+  * New upstream release (18.12.1)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Thu, 10 Jan 2019 14:16:32 +0000
+
+sweeper (4:18.12.0-0ubuntu1) disco; urgency=medium
+
+  * New upstream beta release (18.11.80)
+  * New upstream release (18.12.0)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Sat, 05 Jan 2019 16:54:48 +0000
+
+sweeper (4:18.08.3-0ubuntu1) disco; urgency=medium
+
+  * New upstream release (18.08.3)
+  * Merge Debian changes. Remaining changes:
+    - d/rules: l10npkgs_firstversion_ok := 4:17.08.3-0ubuntu3~
+    - d/upstream/metadata: Vcs links updated to cgit.
+    - d/control: Kubuntu Vcs fields.
+
+ -- Rik Mills <rikmills@kubuntu.org>  Sun, 16 Dec 2018 08:34:55 +0000
+
+sweeper (4:18.04.3-0ubuntu1) cosmic; urgency=medium
+
+  * New upstream release (18.03.80)
+  * New upstream release (18.04.0)
+  * New upstream release (18.04.1)
+  * New upstream release (18.04.3)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Fri, 10 Aug 2018 09:24:43 +0100
+
 sweeper (4:18.04.1-1) unstable; urgency=medium
 
   * Team upload.
@@ -13,6 +127,12 @@ sweeper (4:18.04.1-1) unstable; urgency=
 
  -- Sandro Knauß <hefee@debian.org>  Thu, 31 May 2018 00:43:29 +0200
 
+sweeper (4:17.12.3-0ubuntu1) bionic; urgency=medium
+
+  * New upstream release (17.12.3)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Fri, 16 Mar 2018 13:34:56 +0000
+
 sweeper (4:17.12.2-1) unstable; urgency=medium
 
   * Team upload.
@@ -32,6 +152,17 @@ sweeper (4:17.12.2-1) unstable; urgency=
 
  -- Pino Toscano <pino@debian.org>  Tue, 20 Feb 2018 21:27:44 +0100
 
+sweeper (4:17.12.2-0ubuntu1) bionic; urgency=medium
+
+  * Port to Kf5
+  * New upstream release (17.11.80)
+  * New upstream release (17.11.90)
+  * New upstream release (17.12.0)
+  * New upstream release (17.12.2)
+  * Breaks/replaces against conflicting kde-l10n
+
+ -- Rik Mills <rikmills@kubuntu.org>  Thu, 22 Feb 2018 17:04:01 +0000
+
 sweeper (4:17.08.3-1) unstable; urgency=medium
 
   * Team upload.
@@ -46,6 +177,41 @@ sweeper (4:17.08.3-1) unstable; urgency=
 
  -- Pino Toscano <pino@debian.org>  Thu, 11 Jan 2018 09:54:01 +0100
 
+sweeper (4:17.08.3-0ubuntu1) bionic; urgency=medium
+
+  * New upstream release (17.08.3)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Fri, 01 Dec 2017 15:14:30 +0000
+
+sweeper (4:17.04.3-0ubuntu1) artful; urgency=low
+
+  * New upstream release (17.04.1)
+  * New upstream release (17.04.2)
+  * New upstream release (17.04.3)
+
+ -- José Manuel Santamaría Lema <panfaust@gmail.com>  Fri, 18 Aug 2017 08:35:34 +0100
+
+sweeper (4:16.12.3-0ubuntu1) zesty; urgency=low
+
+  [ Darin Miller ]
+  * New upstream release (16.12.2)
+
+  [ José Manuel Santamaría Lema ]
+  * New upstream release (16.12.3)
+
+ -- José Manuel Santamaría Lema <panfaust@gmail.com>  Fri, 10 Mar 2017 21:30:58 +0000
+
+sweeper (4:16.12.1-0ubuntu1) zesty; urgency=medium
+
+  [ José Manuel Santamaría Lema ]
+  * Update Vcs-Git fields to use https:// instead of git://
+
+  [ Rik Mills ]
+  * New upstream release (16.12.0)
+  * New upstream release (16.12.1)
+
+ -- Rik Mills <rikmills@kubuntu.org>  Thu, 19 Jan 2017 16:19:58 +0000
+
 sweeper (4:16.08.0-1) unstable; urgency=medium
 
   * Team upload.
@@ -53,18 +219,143 @@ sweeper (4:16.08.0-1) unstable; urgency=
 
  -- Pino Toscano <pino@debian.org>  Wed, 24 Aug 2016 06:27:35 +0200
 
-sweeper (4:4.12.2-3) unstable; urgency=medium
+sweeper (4:16.04.3-0ubuntu1) yakkety; urgency=medium
 
-  [ Maximiliano Curia ]
-  * Update watch file.
-  * Add upstream metadata (DEP-12)
-  * debian/control: Update Vcs-Browser and Vcs-Git fields
-  * Update vcs uris to the applications one
+  [ Scarlett Clark ]
+  * New upstream release.
+  * Debian merge: No remaining changes. 
 
-  [ Automatic packaging ]
-  * Bump Standards-Version to 3.9.8
+  [ Philip Muškovac ]
+  * Update the Vcs URLs now that the repositories are hosted on
+    Launchpad
 
- -- Maximiliano Curia <maxy@debian.org>  Sat, 21 May 2016 23:57:11 +0200
+  [ Scarlett Clark ]
+  * New upstream bugfix release
+
+  [ Clive Johnston ]
+  * New upstream release (16.04.2)
+  * New upstream release (16.04.3)
+
+ -- José Manuel Santamaría Lema <panfaust@gmail.com>  Fri, 30 Sep 2016 06:27:34 +0200
+
+sweeper (4:15.12.3-0ubuntu1) xenial; urgency=medium
+
+  * New upstream bugfix release
+  * New upstream bugfix release
+
+ -- Scarlett Clark <sgclark@kubuntu.org>  Thu, 14 Apr 2016 16:31:30 -0700
+
+sweeper (4:15.12.1-0ubuntu1) xenial; urgency=medium
+
+  * New upstream release
+  * Merge with debian master 
+
+ -- Clive Johnston <clivejo@aol.com>  Wed, 09 Mar 2016 11:37:34 +0100
+
+sweeper (4:15.08.2-0ubuntu1) wily; urgency=medium
+
+  * New upstream release
+
+ -- Scarlett Clark <sgclark@kubuntu.org>  Wed, 14 Oct 2015 13:08:58 +0100
+
+sweeper (4:15.08.1-0ubuntu1) wily; urgency=medium
+
+  * New upstream release (15.08.1)
+
+ -- Clive Johnston <clivejo@aol.com>  Tue, 22 Sep 2015 17:48:22 +0100
+
+sweeper (4:15.08.0-0ubuntu1) wily; urgency=medium
+
+  * new upstream release
+
+ -- Clive Johnston <clivejo@aol.com>  Wed, 26 Aug 2015 18:24:08 +0100
+
+sweeper (4:15.07.90-0ubuntu1) wily; urgency=medium
+
+  * new upstream beta release
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Tue, 18 Aug 2015 12:35:07 +0100
+
+sweeper (4:15.04.2-0ubuntu1) wily; urgency=medium
+
+  [ Scarlett Clark ]
+  * New upstream release
+  * New upstream release
+
+  [ Jonathan Riddell ]
+  * New upstream release
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Tue, 09 Jun 2015 22:45:45 +0200
+
+sweeper (4:14.12.3-0ubuntu1) vivid; urgency=medium
+
+  * New upstream release
+
+ -- Scarlett Clark <sgclark@kubuntu.org>  Fri, 13 Mar 2015 14:19:57 -0700
+
+sweeper (4:14.12.2-0ubuntu1) vivid; urgency=medium
+
+  * New upstream release
+  * Remove unstable from watch file, uscan fails with 
+    remote site does not even have current version
+
+ -- Scarlett Clark <sgclark@kubuntu.org>  Tue, 10 Feb 2015 09:14:27 -0800
+
+sweeper (4:14.12.0-0ubuntu1) vivid; urgency=medium
+
+  * New upstream release
+  * Remove kdelibs5-dev depend version as there was not a new release.
+
+ -- Scarlett Clark <sgclark@kubuntu.org>  Mon, 15 Dec 2014 16:58:11 +0100
+
+sweeper (4:14.11.97-0ubuntu1) vivid; urgency=medium
+
+  * New upstream RC release
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Mon, 01 Dec 2014 18:03:54 +0100
+
+sweeper (4:4.14.2-0ubuntu1) vivid; urgency=medium
+
+  * New upstream release
+
+ -- Scarlett Clark <sgclark@kubuntu.org>  Fri, 10 Oct 2014 06:55:12 -0700
+
+sweeper (4:4.14.1-0ubuntu1) utopic; urgency=medium
+
+  * New upstream release
+
+ -- Scarlett Clark <scarlett@scarlettgatelyclark.com>  Mon, 22 Sep 2014 18:06:10 +0200
+
+sweeper (4:4.14.0-0ubuntu1) utopic; urgency=medium
+
+  * New upstream release
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Wed, 20 Aug 2014 13:48:26 +0200
+
+sweeper (4:4.13.97-0ubuntu1) utopic; urgency=medium
+
+  * New upstream beta release RC
+
+ -- Scarlett Clark <scarlett@scarlettgatelyclark.com>  Fri, 01 Aug 2014 17:43:27 +0200
+
+sweeper (4:4.13.95-0ubuntu1) utopic; urgency=medium
+
+  * New upstream beta release
+
+ -- Scarlett Clark <scarlett@scarlettgatelyclark.com>  Wed, 30 Jul 2014 21:01:57 +0200
+
+sweeper (4:4.13.90-0ubuntu1) utopic; urgency=medium
+
+  * New upstream beta release
+
+ -- Scarlett Clark <scarlett@scarlettgatelyclark.com>  Thu, 24 Jul 2014 23:54:31 +0200
+
+sweeper (4:4.13.2-0ubuntu1) utopic; urgency=medium
+
+  * New upstream release
+  * Merge with Debian, no changes
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Tue, 17 Jun 2014 10:42:06 +0100
 
 sweeper (4:4.12.2-2) unstable; urgency=medium
 
@@ -109,6 +400,144 @@ sweeper (4:4.10.4-1) experimental; urgen
 
  -- Maximiliano Curia <maxy@debian.org>  Fri, 14 Jun 2013 19:46:07 +0200
 
+sweeper (4:4.13.0-0ubuntu1) trusty; urgency=medium
+
+  * New upstream KDE Software Compilation release
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Thu, 10 Apr 2014 22:35:40 +0100
+
+sweeper (4:4.12.97-0ubuntu1) trusty; urgency=medium
+
+  * New upstream release candidate
+
+ -- Philip Muškovac <yofel@kubuntu.org>  Wed, 02 Apr 2014 12:04:08 +0200
+
+sweeper (4:4.12.95-0ubuntu1) trusty; urgency=medium
+
+  * New upstream beta release
+
+ -- Rohan Garg <rohangarg@kubuntu.org>  Sun, 23 Mar 2014 13:07:37 +0100
+
+sweeper (4:4.12.90-0ubuntu1) trusty; urgency=medium
+
+  * New upstream beta release
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Wed, 19 Mar 2014 12:12:32 +0000
+
+sweeper (4:4.12.3-0ubuntu1) trusty; urgency=medium
+
+  * New upstream bugfix release
+
+ -- Rohan Garg <rohangarg@kubuntu.org>  Tue, 04 Mar 2014 21:24:02 +0100
+
+sweeper (4:4.12.2-3) unstable; urgency=medium
+
+  [ Maximiliano Curia ]
+  * Update watch file.
+  * Add upstream metadata (DEP-12)
+  * debian/control: Update Vcs-Browser and Vcs-Git fields
+  * Update vcs uris to the applications one
+
+  [ Automatic packaging ]
+  * Bump Standards-Version to 3.9.8
+
+ -- Maximiliano Curia <maxy@debian.org>  Sat, 21 May 2016 23:57:11 +0200
+
+sweeper (4:4.12.2-0ubuntu1) trusty; urgency=medium
+
+  * New upstream bugfix release
+
+ -- Rohan Garg <rohangarg@kubuntu.org>  Wed, 05 Feb 2014 00:37:58 +0000
+
+sweeper (4:4.12.1-0ubuntu1) trusty; urgency=low
+
+  * New upstream bugfix release
+
+ -- Rohan Garg <rohangarg@kubuntu.org>  Thu, 16 Jan 2014 08:52:14 +0000
+
+sweeper (4:4.12.0-0ubuntu1) trusty; urgency=low
+
+  * New upstream release
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Wed, 18 Dec 2013 17:55:32 +0000
+
+sweeper (4:4.11.97-0ubuntu1) trusty; urgency=low
+
+  * New upstream RC release
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Fri, 29 Nov 2013 13:53:57 +0000
+
+sweeper (4:4.11.95-0ubuntu1) trusty; urgency=low
+
+  * New upstream beta release
+
+ -- Rohan Garg <rohangarg@kubuntu.org>  Mon, 25 Nov 2013 18:48:12 +0100
+
+sweeper (4:4.11.80-0ubuntu1) trusty; urgency=low
+
+  * New upstream beta release
+
+ -- Rohan Garg <rohangarg@kubuntu.org>  Sat, 23 Nov 2013 18:08:52 +0100
+
+sweeper (4:4.11.2-0ubuntu1) saucy; urgency=low
+
+  * New upstream bugfix release
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Mon, 30 Sep 2013 15:03:49 +0100
+
+sweeper (4:4.11.1-0ubuntu1) saucy; urgency=low
+
+  * New upstream bugfix release.
+
+ -- Philip Muškovac <yofel@kubuntu.org>  Fri, 06 Sep 2013 22:47:14 +0100
+
+sweeper (4:4.11.0-0ubuntu1) saucy; urgency=low
+
+  [ Howard Chan ]
+  * New upstream release
+
+  [ Jonathan Riddell ]
+  * New upstream release
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Wed, 14 Aug 2013 00:48:05 +0100
+
+sweeper (4:4.10.97-0ubuntu1) saucy; urgency=low
+
+  * New upstream RC 2 release
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Fri, 26 Jul 2013 20:17:55 +0100
+
+sweeper (4:4.10.95-0ubuntu1) saucy; urgency=low
+
+  * New upstream RC release
+
+ -- Rohan Garg <rohangarg@kubuntu.org>  Fri, 19 Jul 2013 12:33:46 +0000
+
+sweeper (4:4.10.90-0ubuntu1) saucy; urgency=low
+
+  * New upstream bet release
+
+ -- Michał Zając <quintasan@kubuntu.org>  Fri, 28 Jun 2013 18:37:50 +0100
+
+sweeper (4:4.10.80-0ubuntu1) saucy; urgency=low
+
+  * New upstream release
+
+ -- Rohan Garg <rohangarg@kubuntu.org>  Fri, 21 Jun 2013 02:06:59 +0100
+
+sweeper (4:4.10.4-0ubuntu1) saucy-proposed; urgency=low
+
+  * New upstream bugfix release
+
+ -- Rohan Garg <rohangarg@kubuntu.org>  Fri, 07 Jun 2013 01:01:05 +0100
+
+sweeper (4:4.10.3-0ubuntu1) saucy; urgency=low
+
+  * New upstream release
+  * Merge with Debian
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Tue, 07 May 2013 16:55:14 +0000
+
 sweeper (4:4.10.2-1) experimental; urgency=low
 
   [ Diane Trout ]
@@ -120,6 +549,92 @@ sweeper (4:4.10.2-1) experimental; urgen
 
  -- Sune Vuorela <sune@debian.org>  Thu, 11 Apr 2013 07:04:32 +0000
 
+sweeper (4:4.10.2-0ubuntu1) raring; urgency=low
+
+  * New upstream bugfix release
+
+ -- Philip Muškovac <yofel@kubuntu.org>  Sun, 31 Mar 2013 15:08:05 +0200
+
+sweeper (4:4.10.1-0ubuntu1) raring-proposed; urgency=low
+
+  * New upstream bugfix release
+
+ -- Philip Muškovac <yofel@kubuntu.org>  Tue, 05 Mar 2013 21:04:36 +0000
+
+sweeper (4:4.10.0-0ubuntu1) raring-proposed; urgency=low
+
+  * New upstream release
+
+ -- Rohan Garg <rohangarg@kubuntu.org>  Wed, 06 Feb 2013 12:26:41 +0000
+
+sweeper (4:4.9.98-0ubuntu1) raring-proposed; urgency=low
+
+  * New upstream release candidate
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Fri, 18 Jan 2013 16:37:15 +0000
+
+sweeper (4:4.9.97-0ubuntu1) raring; urgency=low
+
+  * New upstream release candidate
+
+ -- Philip Muškovac <yofel@kubuntu.org>  Thu, 03 Jan 2013 22:52:23 +0100
+
+sweeper (4:4.9.95-0ubuntu1) raring; urgency=low
+
+  * New upstream RC release
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Tue, 18 Dec 2012 23:53:07 +0000
+
+sweeper (4:4.9.90-0ubuntu1) raring-proposed; urgency=low
+
+  * New upstream beta release
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Fri, 07 Dec 2012 18:22:23 +0000
+
+sweeper (4:4.9.80-0ubuntu1) raring; urgency=low
+
+  * New upstream beta release
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Mon, 19 Nov 2012 16:30:11 +0000
+
+sweeper (4:4.9.3-0ubuntu1) raring; urgency=low
+
+  * New upstream release (LP: #1074747)
+
+ -- Philip Muškovac <yofel@kubuntu.org>  Tue, 06 Nov 2012 22:54:07 +0100
+
+sweeper (4:4.9.2-0ubuntu1) quantal-proposed; urgency=low
+
+  * New upstream bugfix release
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Tue, 02 Oct 2012 15:49:13 +0100
+
+sweeper (4:4.9.1-0ubuntu1) quantal; urgency=low
+
+  * New upstream release
+
+ -- Harald Sitter <apachelogger@ubuntu.com>  Mon, 10 Sep 2012 18:50:16 +0530
+
+sweeper (4:4.9.0-0ubuntu1) quantal; urgency=low
+
+  * Use direct build-depends versions rather than kde-sc-dev-latest
+  * Use direct build-depends versions rather than kde-sc-dev-latest
+  * New upstream release
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Thu, 26 Jul 2012 22:56:22 +0100
+
+sweeper (4:4.8.90-0ubuntu1) quantal; urgency=low
+
+  * New upstream beta release.
+
+ -- Felix Geyer <debfx@ubuntu.com>  Mon, 11 Jun 2012 23:51:11 +0200
+
+sweeper (4:4.8.80-0ubuntu1) quantal; urgency=low
+
+  * New upstream release
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Wed, 06 Jun 2012 16:52:49 +0100
+
 sweeper (4:4.8.4-1) unstable; urgency=low
 
   * Team upload.
@@ -128,3 +643,51 @@ sweeper (4:4.8.4-1) unstable; urgency=lo
   * Initial packaging, split from kdeutils.
 
  -- Lisandro Damián Nicanor Pérez Meyer <lisandro@debian.org>  Tue, 19 Jun 2012 12:38:27 -0300
+
+sweeper (4:4.8.3-0ubuntu1) quantal; urgency=low
+
+  * New upstream bugfix release
+
+ -- Jonathan Thomas <echidnaman@kubuntu.org>  Fri, 18 May 2012 16:16:39 -0400
+
+sweeper (4:4.8.2-0ubuntu2) precise-proposed; urgency=low
+
+  * Rebuild for .pot generation
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Thu, 12 Apr 2012 16:32:12 +0100
+
+sweeper (4:4.8.2-0ubuntu1) precise; urgency=low
+
+  * new upstream release
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Tue, 03 Apr 2012 08:52:09 +0000
+
+sweeper (4:4.8.1-0ubuntu1) precise; urgency=low
+
+  * New upstream release 
+
+ -- Philip Muškovac <yofel@kubuntu.org>  Sun, 04 Mar 2012 21:56:55 +0100
+
+sweeper (4:4.8.0-0ubuntu1) precise; urgency=low
+
+  * New upstream release
+
+ -- Philip Muškovac <yofel@kubuntu.org>  Mon, 23 Jan 2012 22:23:39 +0100
+
+sweeper (4:4.7.97-0ubuntu1) precise; urgency=low
+
+  * New upstream release candidate
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Thu, 05 Jan 2012 12:18:43 +0000
+
+sweeper (4:4.7.95-0ubuntu1) precise; urgency=low
+
+  * New upstream release candidate
+
+ -- Philip Muškovac <yofel@kubuntu.org>  Sat, 24 Dec 2011 23:29:18 +0100
+
+sweeper (4:4.7.90-0ubuntu1) precise; urgency=low
+
+  * Initial package
+
+ -- Jonathan Riddell <jriddell@ubuntu.com>  Sat, 17 Dec 2011 17:32:11 +0000
diff -pruN 4:18.04.1-1/debian/control 4:20.04.1-0ubuntu1/debian/control
--- 4:18.04.1-1/debian/control	2018-05-30 21:33:13.000000000 +0000
+++ 4:20.04.1-0ubuntu1/debian/control	2020-05-15 13:43:40.000000000 +0000
@@ -1,7 +1,7 @@
 Source: sweeper
 Section: kde
 Priority: optional
-Maintainer: Debian Qt/KDE Maintainers <debian-qt-kde@lists.debian.org>
+Maintainer: Debian/Kubuntu Qt/KDE Maintainers <debian-qt-kde@lists.debian.org>
 Uploaders: Sune Vuorela <sune@debian.org>,
            Modestas Vainius <modax@debian.org>,
            George Kiagiadakis <kiagiadakis.george@gmail.com>,
@@ -25,8 +25,8 @@ Build-Depends: cmake (>= 3.0~),
                qtbase5-dev,
 Standards-Version: 4.1.4
 Homepage: http://www.kde.org/
-Vcs-Browser: https://salsa.debian.org/qt-kde-team/kde/sweeper
-Vcs-Git: https://salsa.debian.org/qt-kde-team/kde/sweeper.git
+Vcs-Browser: https://code.launchpad.net/~kubuntu-packagers/kubuntu-packaging/+git/sweeper
+Vcs-Git: https://git.launchpad.net/~kubuntu-packagers/kubuntu-packaging/+git/sweeper
 
 Package: sweeper
 Section: utils
diff -pruN 4:18.04.1-1/debian/rules 4:20.04.1-0ubuntu1/debian/rules
--- 4:18.04.1-1/debian/rules	2018-05-30 18:31:28.000000000 +0000
+++ 4:20.04.1-0ubuntu1/debian/rules	2020-05-15 13:43:40.000000000 +0000
@@ -1,6 +1,6 @@
 #!/usr/bin/make -f
 
-l10npkgs_firstversion_ok := 4:17.08.3-4~
+l10npkgs_firstversion_ok := 4:17.08.3-0ubuntu3~
 
 include /usr/share/pkg-kde-tools/qt-kde-team/3/debian-qt-kde.mk
 include /usr/share/pkg-kde-tools/qt-kde-team/2/l10n-packages.mk
diff -pruN 4:18.04.1-1/debian/upstream/metadata 4:20.04.1-0ubuntu1/debian/upstream/metadata
--- 4:18.04.1-1/debian/upstream/metadata	2018-05-30 18:31:28.000000000 +0000
+++ 4:20.04.1-0ubuntu1/debian/upstream/metadata	2020-05-15 13:43:40.000000000 +0000
@@ -1,7 +1,7 @@
 Name: sweeper
-Changelog: https://quickgit.kde.org/?p=sweeper.git&a=log
+Changelog: https://cgit.kde.org/sweeper.git/log/
 Contact: kde-devel@kde.org
 Donation: https://www.kde.org/community/donations/index.php
 Repository: https://anongit.kde.org/sweeper.git
-Repository-Browse: https://quickgit.kde.org/?p=sweeper.git
+Repository-Browse: https://cgit.kde.org/sweeper.git/
 Security-Contact: security@kde.org
diff -pruN 4:18.04.1-1/debian/watch 4:20.04.1-0ubuntu1/debian/watch
--- 4:18.04.1-1/debian/watch	2018-05-30 18:35:35.000000000 +0000
+++ 4:20.04.1-0ubuntu1/debian/watch	2020-05-15 13:43:40.000000000 +0000
@@ -1,2 +1,2 @@
 version=4
-opts=pgpsigurlmangle=s/$/.sig/ https://download.kde.org/stable/applications/([\d.]+)/src/@PACKAGE@-([\d.]+)\.tar\.xz
+opts=pgpsigurlmangle=s/$/.sig/ https://download.kde.org/stable/release-service/([\d.]+)/src/@PACKAGE@-([\d.]+)\.tar\.xz
diff -pruN 4:18.04.1-1/.gitignore 4:20.04.1-0ubuntu1/.gitignore
--- 4:18.04.1-1/.gitignore	1970-01-01 00:00:00.000000000 +0000
+++ 4:20.04.1-0ubuntu1/.gitignore	2020-05-11 21:17:33.000000000 +0000
@@ -0,0 +1,22 @@
+# Ignore the following files
+*~
+*.[oa]
+*.diff
+*.kate-swp
+*.kdev4
+.kdev_include_paths
+*.kdevelop.pcs
+*.moc
+*.moc.cpp
+*.orig
+*.user
+.*.swp
+.swp.*
+Doxyfile
+Makefile
+avail
+random_seed
+/build*/
+CMakeLists.txt.user*
+*.unc-backup*
+.cmake/
diff -pruN 4:18.04.1-1/main.cpp 4:20.04.1-0ubuntu1/main.cpp
--- 4:18.04.1-1/main.cpp	2018-05-06 04:10:53.000000000 +0000
+++ 4:20.04.1-0ubuntu1/main.cpp	2020-05-11 21:17:33.000000000 +0000
@@ -27,7 +27,7 @@
 #include <Kdelibs4ConfigMigrator>
 #include <KLocalizedString>
 
-#include "config-sweeper.h"
+#include <config-sweeper.h>
 
 int main(int argc, char *argv[])
 {
@@ -44,9 +44,9 @@ int main(int argc, char *argv[])
                         QStringLiteral(SWEEPER_VERSION),
                         i18n("Helps clean unwanted traces the user leaves on the system."),
                         KAboutLicense::LGPL,
-                        i18n("(c) 2003-2005, Ralf Hoelzer"),
+                        i18n("© 2003-2005, Ralf Hoelzer"),
                         QString(),
-                        QStringLiteral("http://utils.kde.org/projects/sweeper"));
+                        QStringLiteral("https://utils.kde.org/projects/sweeper"));
 
    aboutData.addAuthor(i18n("Ralf Hoelzer"), i18n("Original author"), QStringLiteral("ralf@well.com"));
    aboutData.addAuthor(i18n("Brian S. Stephan"), i18n("Maintainer"), QStringLiteral("bssteph@irtonline.org"));
diff -pruN 4:18.04.1-1/org.kde.sweeper.appdata.xml 4:20.04.1-0ubuntu1/org.kde.sweeper.appdata.xml
--- 4:18.04.1-1/org.kde.sweeper.appdata.xml	2018-05-06 04:10:53.000000000 +0000
+++ 4:20.04.1-0ubuntu1/org.kde.sweeper.appdata.xml	2020-05-11 21:17:33.000000000 +0000
@@ -12,16 +12,22 @@
   <name xml:lang="el">Sweeper</name>
   <name xml:lang="en-GB">Sweeper</name>
   <name xml:lang="es">Sweeper</name>
+  <name xml:lang="et">Sweeper</name>
+  <name xml:lang="eu">Sweeper</name>
   <name xml:lang="fi">Sweeper</name>
   <name xml:lang="fr">Sweeper</name>
   <name xml:lang="gl">Sweeper</name>
   <name xml:lang="ia">Sweeper</name>
+  <name xml:lang="id">Sweeper</name>
   <name xml:lang="it">Spazzino</name>
   <name xml:lang="ko">Sweeper</name>
+  <name xml:lang="lt">Išvalymo įrankis</name>
   <name xml:lang="nl">Sweeper</name>
   <name xml:lang="nn">Sweeper</name>
+  <name xml:lang="pa">ਸਵੀਪਰ</name>
   <name xml:lang="pl">Czyściciel</name>
   <name xml:lang="pt">Sweeper</name>
+  <name xml:lang="pt-BR">Sweeper</name>
   <name xml:lang="ru">Sweeper</name>
   <name xml:lang="sk">Zametač</name>
   <name xml:lang="sl">Sweeper</name>
@@ -33,8 +39,8 @@
   <name xml:lang="uk">Sweeper</name>
   <name xml:lang="x-test">xxSweeperxx</name>
   <name xml:lang="zh-CN">Sweeper</name>
+  <name xml:lang="zh-TW">Sweeper</name>
   <summary>System cleaning utility</summary>
-  <summary xml:lang="ast">Utilidá de llimpieza del sistema</summary>
   <summary xml:lang="ca">Utilitat per a netejar el sistema</summary>
   <summary xml:lang="ca-valencia">Utilitat per a netejar el sistema</summary>
   <summary xml:lang="cs">Nástroj pro úklid systému</summary>
@@ -43,16 +49,23 @@
   <summary xml:lang="el">Εργαλείο καθαρισμού του συστήματος</summary>
   <summary xml:lang="en-GB">System cleaning utility</summary>
   <summary xml:lang="es">Utilidad de limpieza del sistema</summary>
+  <summary xml:lang="et">Süsteemi puhastamise tööriist</summary>
+  <summary xml:lang="eu">Sistema garbitzeko baliagarritasuna</summary>
   <summary xml:lang="fi">Järjestelmän siivoustyökalu</summary>
   <summary xml:lang="fr">Utilitaire de nettoyage du système</summary>
   <summary xml:lang="gl">Utilidade de limpeza do sistema</summary>
   <summary xml:lang="ia">Utilitate per nettar le systema</summary>
+  <summary xml:lang="id">Utilitas pembersihan sistem</summary>
   <summary xml:lang="it">Utilità per la pulizia del sistema</summary>
   <summary xml:lang="ko">시스템 청소 도구</summary>
+  <summary xml:lang="lt">Sistemos išvalymo paslaugų programa</summary>
   <summary xml:lang="nl">Hulpmiddel voor opschonen van het systeem</summary>
   <summary xml:lang="nn">Verktøy for dataopprydding</summary>
+  <summary xml:lang="pa">ਸਿਸਟਮ ਸਫ਼ਾਈ ਸਹੂਲਤ</summary>
   <summary xml:lang="pl">Narzędzie do czyszczenia systemu</summary>
   <summary xml:lang="pt">Utilitário de limpeza do sistema</summary>
+  <summary xml:lang="pt-BR">Utilitário de limpeza do sistema</summary>
+  <summary xml:lang="ru">Приложение для очистки системы</summary>
   <summary xml:lang="sk">Nástroj na čistenie systému</summary>
   <summary xml:lang="sl">Orodje za čiščenje sistema</summary>
   <summary xml:lang="sr">Алатка за чишћење система</summary>
@@ -63,6 +76,7 @@
   <summary xml:lang="uk">Програма для чищення системи</summary>
   <summary xml:lang="x-test">xxSystem cleaning utilityxx</summary>
   <summary xml:lang="zh-CN">系统清洁实用程序</summary>
+  <summary xml:lang="zh-TW">系統清理工具</summary>
   <description>
     <p>
       Sweeper helps to clean unwanted traces the user leaves on the system. It
@@ -76,16 +90,22 @@
     <p xml:lang="el">Το Sweeper βοηθάει στον καθαρισμό ανεπιθύμητων ιχνών που ο χρήστης αφήνει στο σύστημα. Μπορεί να αφαιρέσει cookies και να καθαρίσει προσωρινές μνήμες, για παράδειγμα.</p>
     <p xml:lang="en-GB">Sweeper helps to clean unwanted traces the user leaves on the system. It can remove cookies and clean out caches, for example.</p>
     <p xml:lang="es">Sweeper ayuda a borrar el rastro no deseado que deja el usuario en el sistema. Puede eliminar cookies y borrar cachés, por ejemplo.</p>
+    <p xml:lang="et">Sweeper aitab kõrvaldada soovimatud jäljed, mida kasutaja süsteemi jätab. Näiteks võib see eemaldada küpsised ja puhastada puhvrid.</p>
+    <p xml:lang="eu">Sweeperrek erabiltzaileak sisteman uzten dituen nahigabeko arrastoak garbitzen ditu. Kukiak kendu ditzake eta cacheak garbitu, esaterako.</p>
     <p xml:lang="fi">Sweeper auttaa poistamaan käyttäjän järjestelmään jättämät turhat jäljet. Se osaa esimerkiksi poistaa evästeet ja tyhjentää välimuistit.</p>
     <p xml:lang="fr">Sweeper aide à effacer les traces indésirables laissées par l'utilisateur sur le système. Il peut supprimer les cookies et vider les caches, par exemple.</p>
     <p xml:lang="gl">Sweeper axuda a limpar os restos sen usar que o usuario deixa no sistema. Pode eliminar cookies e cachés, por exemplo.</p>
     <p xml:lang="ia">Sweeper adjuta nettar tracias non volite que le usator lassa in le systema. Il pote remover cookies e nettar caches pro exemplo.</p>
+    <p xml:lang="id">Sweeper membantu membersihkan jejak yang tidak diinginkan yang ditinggalkan pengguna pada sistem. Itu dapat menghapus cookie dan membersihkan cache, misalnya.</p>
     <p xml:lang="it">Lo spazzino aiuta a cancellare le tracce indesiderate che l'utente lascia nel sistema, ad esempio può rimuovere i cookie e ripulire la cache.</p>
     <p xml:lang="ko">Sweeper는 시스템에 남아 있는 사용자의 과거 기록을 청소합니다. 쿠키와 캐시 등 데이터를 지울 수 있습니다.</p>
+    <p xml:lang="lt">Išvalymo įrankis padeda išvalyti nepageidaujamus pėdsakus, kuriuos naudotojas palieka sistemoje. Šis įrankis, pavyzdžiui, gali pašalinti slapukus ir išvalyti podėlius.</p>
     <p xml:lang="nl">Sweeper helpt bij het uitwissen van ongewenste sporen die de gebruiker op het systeem achterlaat. Het kan bijvoorbeeld cookies verwijderen en caches opschonen.</p>
     <p xml:lang="nn">Sweeper hjelper deg å fjerna uønskte spor på datamaskina. Du kan blant anna bruka det til å fjerna infokapslar og mellom-/snøgglager.</p>
     <p xml:lang="pl">Czyściciel pomaga zatrzeć niechciane ślady, które użytkownik zostawia na systemie. Może na przykład usunąć ciasteczka, a także wyczyścić pamięci podręczne.</p>
     <p xml:lang="pt">O Sweeper ajuda a limpar os vestígios indesejados que o utilizador deixa no sistema. Poderá remover os 'cookies' e limpar as 'caches', por exemplo.</p>
+    <p xml:lang="pt-BR">O Sweeper ajuda a limpar os vestígios indesejados que o usuário deixa no sistema. Ele pode remover os cookies e apagar os 'caches', por exemplo.</p>
+    <p xml:lang="ru">Приложение предназначено для удаления следов работы пользователя в операционной системе, таких как файлы cookie и кешированные файлы.</p>
     <p xml:lang="sk">Zametač vám pomôže vyčistiť neželané stopy, ktoré používateľ zanecháva v systéme. Môže napríklad odstrániť cookies a vyčistiť vyrovnávacie pamäte.</p>
     <p xml:lang="sl">Sweeper pomaga pri čiščenju neželenih sledi, ki jih uporabnik pušča na sistemu. Med drugim lahko odstrani piškotke in predpomnilnike.</p>
     <p xml:lang="sr">Чистач помаже у отклањању нежељених трагова које корисник остави на систему. На пример, може да уклања колачиће и чисти кешеве.</p>
@@ -97,16 +117,23 @@
     <p xml:lang="x-test">xxSweeper helps to clean unwanted traces the user leaves on the system. It can remove cookies and clean out caches, for example.xx</p>
     <p xml:lang="zh-CN">Sweeper 帮助用户清理留在系统上的不需要的痕迹。例如，它能移除 Cookie 和清理缓存。</p>
   </description>
-  <url type="homepage">http://utils.kde.org/projects/sweeper/</url>
+  <url type="homepage">https://utils.kde.org/projects/sweeper/</url>
   <url type="bugtracker">https://bugs.kde.org/enter_bug.cgi?format=guided&amp;product=sweeper</url>
-  <url type="help">http://docs.kde.org/?application=sweeper</url>
+  <url type="help">https://docs.kde.org/?application=sweeper</url>
+  <url type="donation">https://www.kde.org/community/donations/?app=sweeper&amp;source=appdata</url>
   <screenshots>
     <screenshot type="default">
-      <image>http://kde.org/images/screenshots/sweeper.png</image>
+      <image>https://cdn.kde.org/screenshots/sweeper/sweeper.png</image>
     </screenshot>
   </screenshots>
   <project_group>KDE</project_group>
   <provides>
     <binary>sweeper</binary>
   </provides>
+  <releases>
+    <release version="20.04.1" date="2020-05-14"/>
+    <release version="20.04.0" date="2020-04-23"/>
+    <release version="19.12.2" date="2020-02-06"/>
+    <release version="19.12.1" date="2020-01-09"/>
+  </releases>
 </component>
diff -pruN 4:18.04.1-1/org.kde.sweeper.desktop 4:20.04.1-0ubuntu1/org.kde.sweeper.desktop
--- 4:18.04.1-1/org.kde.sweeper.desktop	2018-05-06 04:10:53.000000000 +0000
+++ 4:20.04.1-0ubuntu1/org.kde.sweeper.desktop	2020-05-11 21:17:33.000000000 +0000
@@ -9,7 +9,6 @@ X-DBUS-StartupType=Multi
 Categories=Qt;KDE;Utility;
 Name=Sweeper
 Name[ar]=الكناس
-Name[ast]=Barrenderu
 Name[bg]=Sweeper
 Name[bs]=Čistač
 Name[ca]=Escombriaire
@@ -37,7 +36,7 @@ Name[ja]=Sweeper
 Name[kk]=Сыпырғыш
 Name[km]=កម្មវិធី​សម្អាត
 Name[ko]=Sweeper
-Name[lt]=Šlavėjas
+Name[lt]=Išvalymo įrankis
 Name[lv]=Sweeper
 Name[mr]=स्वीपर
 Name[nb]=Sweeper
@@ -70,7 +69,6 @@ Name[zh_CN]=Sweeper
 Name[zh_TW]=清掃器
 GenericName=System Cleaner
 GenericName[ar]=منظف النظام
-GenericName[ast]=Llimpiador del sistema
 GenericName[bg]=Почистване на системата
 GenericName[bs]=Čistač sistema
 GenericName[ca]=Netejador del sistema
@@ -83,7 +81,7 @@ GenericName[en_GB]=System Cleaner
 GenericName[eo]=Sistema purigilo
 GenericName[es]=Limpiador del sistema
 GenericName[et]=Süsteemi puhastaja
-GenericName[eu]=Sistemaren garbitzailea
+GenericName[eu]=Sistema garbitzailea
 GenericName[fa]=پاک‌کننده سیستم
 GenericName[fi]=Järjestelmän puhdistus
 GenericName[fr]=Nettoyeur du système
@@ -132,7 +130,6 @@ GenericName[x-test]=xxSystem Cleanerxx
 GenericName[zh_CN]=系统清理器
 GenericName[zh_TW]=系統清除器
 Comment=Helps to clean unwanted traces the user leaves on the system and to regain disk space removing unused temporary files
-Comment[ast]=Ayuda a llimpiar les traces que l'usuariu dexa nel sistema y llibera l'espaciu en discu desaniciando ficheros temporales non queríos
 Comment[ca]=Ajuda a netejar el rastre no desitjat que va deixant l'usuari al sistema i es recupera l'espai del disc eliminant els fitxers temporals no usats
 Comment[ca@valencia]=Ajuda a netejar el rastre no desitjat que va deixant l'usuari al sistema i es recupera l'espai del disc eliminant els fitxers temporals no usats
 Comment[cs]=Pomáhá smazat nechtěné stopy zanechané uživatelem v systému pro obnovení volného místa na disku smazáním dočasných souborů
@@ -141,15 +138,21 @@ Comment[de]=Hilft dem Benutzer ungewollt
 Comment[el]=Βοηθάει στον καθαρισμό ανεπιθύμητων ιχνών που αφήνει ο χρήστης στο σύστημα και στην ανάκτηση χώρου στο δίσκο με τη διαγραφή περιττών προσωρινών αρχείων
 Comment[en_GB]=Helps to clean unwanted traces the user leaves on the system and to regain disk space removing unused temporary files
 Comment[es]=Ayuda a borrar el rastro no deseado que deja el usuario en el sistema y permite ganar espacio en disco eliminando archivos temporales no usados
+Comment[et]=Abiks soovimatute jälgede kõrvaldamisel, mida kasutaja on süsteemi jätnud, ja kettaruumi suurendamine kasutamata ajutisi faile eemaldades
+Comment[eu]=Erabiltzaileak sisteman nahigabe uzten dituen arrastoak garbitzen laguntzen du, baita diskoan lekua berreskuratzen erabili gabeko aldi baterako fitxategiak ezabatuz
 Comment[fi]=Auttaa poistamaan käyttäjän järjestelmään jättämät turhat jäljet sekä lisäämään levytilaa poistamalla vanhat väliaikaistiedostot
 Comment[fr]=Aide à effacer les traces indésirables laissées par l'utilisateur sur le système et à regagner de l'espace disque en effaçant les fichiers temporaires inutilisés
 Comment[gl]=Axuda a limpar o ronsel non desexado que o usuario deixa no sistema e a recuperar espazo en disco retirando ficheiros temporais non usados.
+Comment[ia]=Adjuta nettar tracias non volite que le usator abandona sur le systema e obtine spatio de disco quando on remove files temporanee
 Comment[it]=Aiuta a cancellare le tracce indesiderate che l'utente lascia nel sistema ed a riguadagnare spazio su disco rimuovendo i file temporanei non usati
 Comment[ko]=시스템에 남아 있는 사용자의 과거 기록을 청소하고 사용하지 않는 임시 파일을 삭제해서 디스크 공간을 확보합니다
+Comment[lt]=Padeda išvalyti nepageidaujamus pėdsakus, kuriuos naudotojas palieka sistemoje, kad pašalinant nenaudojamus laikinuosius failus, būtų atgauta vieta diske
 Comment[nl]=Helpt bij het uitwissen van ongewenste sporen die de gebruiker op het systeem achterlaat en om schijfruimte terug te winnen door ongebruikte tijdelijke bestanden te verwijderen
 Comment[nn]=Hjelper til å fjerna uønskte spor som brukaren har etterlate på systemet og til å frigjera diskplass teken opp av mellombelse filer.
 Comment[pl]=Pomaga zatrzeć niechciane ślady, które użytkownik zostawia na systemie i odzyskać przestrzeń dyskową poprzez usunięcie nieużywanych plików tymczasowych
 Comment[pt]=Ajuda a limpar os vestígios indesejados que o utilizador deixa no sistema para voltar a ganhar espaço em disco, removendo os ficheiros temporários não usados
+Comment[pt_BR]=Ajuda a limpar os vestígios indesejados que o usuário deixa no sistema para voltar a ganhar espaço em disco, removendo os arquivos temporários que não são utilizados
+Comment[ru]=Приложение предназначено для удаления следов работы пользователя в операционной системе и удаления ненужных временных файлов
 Comment[sk]=Pomôže vám vyčistiť neželané stopy v systéme a obnoviť miesto na disku odstránením nepotrebných dočasných súborov.
 Comment[sl]=Pomaga pri čiščenju neželenih sledi, ki jih uporabnik pušča na sistemu, in sproščanju prostora na disku z odstranjevanjem neuporabljenih začasnih datotek
 Comment[sr]=Помаже у отклањању нежељених трагова које корисник остави на систему и ослобађању простора на диску брисањем привремених фајлова
diff -pruN 4:18.04.1-1/po/ar/sweeper.po 4:20.04.1-0ubuntu1/po/ar/sweeper.po
--- 4:18.04.1-1/po/ar/sweeper.po	2018-05-08 00:12:29.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/ar/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -10,8 +10,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
 "PO-Revision-Date: 2010-07-23 23:12+0400\n"
 "Last-Translator: Zayed Al-Saidi <zayed.alsaidi@gmail.com>\n"
 "Language-Team: Arabic <linuxac-kde-arabic-team@googlegroups.com>\n"
@@ -46,8 +46,9 @@ msgid "Helps clean unwanted traces the u
 msgstr "يساعد في تنظيف الأثار غير المرغوب بها التي يتركها المستخدم في النظام"
 
 #: main.cpp:47
-#, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+#, fuzzy, kde-format
+#| msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "(c) 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
@@ -85,17 +86,17 @@ msgstr "خابية المصغرة"
 msgid "Sweeps without user interaction"
 msgstr "نظف بدون تدخل المستخدم"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "االمصغرة لا يمكن أن تزال."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "الملف موجود ولكن لا يمكن أن يزال."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "فايكون لا يمكن أن يزال."
@@ -210,40 +211,40 @@ msgstr "التطبيقات الحديث
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "يمحي لائحة التطبيقات  المستخدمة  مؤخراً من قائمة تطبيقات كدي"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "عام"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "تصفح الويب"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "أنت تقوم بمحو بيانات ربما قد تكون ذات أهمية لك ، هل أنت متأكِّد ؟"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "جاري بدء التنظيف..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "جاري المحو %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "فشل محو %1: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "انتهت عملية التنظيف."
diff -pruN 4:18.04.1-1/po/ast/sweeper.po 4:20.04.1-0ubuntu1/po/ast/sweeper.po
--- 4:18.04.1-1/po/ast/sweeper.po	2018-05-08 00:12:29.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/ast/sweeper.po	1970-01-01 00:00:00.000000000 +0000
@@ -1,283 +0,0 @@
-# Copyright (C) YEAR This_file_is_part_of_KDE
-# This file is distributed under the same license as the PACKAGE package.
-#
-# enolp <enolp@softastur.org>, 2015.
-msgid ""
-msgstr ""
-"Project-Id-Version: \n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2015-03-31 03:38+0100\n"
-"Last-Translator: enolp <enolp@softastur.org>\n"
-"Language-Team: Asturian <kde-i18n-doc@kde.org>\n"
-"Language: ast\n"
-"MIME-Version: 1.0\n"
-"Content-Type: text/plain; charset=UTF-8\n"
-"Content-Transfer-Encoding: 8bit\n"
-"Plural-Forms: nplurals=2; plural=n != 1;\n"
-"X-Generator: Lokalize 2.0\n"
-
-#, kde-format
-msgctxt "NAME OF TRANSLATORS"
-msgid "Your names"
-msgstr ""
-
-#, kde-format
-msgctxt "EMAIL OF TRANSLATORS"
-msgid "Your emails"
-msgstr ""
-
-#: main.cpp:43
-#, kde-format
-msgid "Sweeper"
-msgstr ""
-
-#: main.cpp:45
-#, kde-format
-msgid "Helps clean unwanted traces the user leaves on the system."
-msgstr ""
-
-#: main.cpp:47
-#, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
-msgstr "(c) 2003-2005, Ralf Hoelzer"
-
-#: main.cpp:51
-#, kde-format
-msgid "Ralf Hoelzer"
-msgstr ""
-
-#: main.cpp:51
-#, kde-format
-msgid "Original author"
-msgstr ""
-
-#: main.cpp:52
-#, kde-format
-msgid "Brian S. Stephan"
-msgstr ""
-
-#: main.cpp:52
-#, kde-format
-msgid "Maintainer"
-msgstr ""
-
-#: main.cpp:53
-#, kde-format
-msgid "Benjamin Meyer"
-msgstr ""
-
-#: main.cpp:53 privacyfunctions.h:68
-#, kde-format
-msgid "Thumbnail Cache"
-msgstr ""
-
-#: main.cpp:61
-#, kde-format
-msgid "Sweeps without user interaction"
-msgstr ""
-
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
-#, kde-format
-msgid "A thumbnail could not be removed."
-msgstr ""
-
-#: privacyfunctions.cpp:150
-#, kde-format
-msgid "The file exists but could not be removed."
-msgstr ""
-
-#: privacyfunctions.cpp:236
-#, kde-format
-msgid "A favicon could not be removed."
-msgstr ""
-
-#: privacyfunctions.h:37
-#, kde-format
-msgid "Cookies"
-msgstr ""
-
-#: privacyfunctions.h:38
-#, kde-format
-msgid "Clears all stored cookies set by websites"
-msgstr ""
-
-#: privacyfunctions.h:48
-#, kde-format
-msgid "Cookie Policies"
-msgstr ""
-
-#: privacyfunctions.h:49
-#, kde-format
-msgid "Clears the cookie policies for all visited websites"
-msgstr ""
-
-#: privacyfunctions.h:58
-#, kde-format
-msgid "Saved Clipboard Contents"
-msgstr ""
-
-#: privacyfunctions.h:59
-#, kde-format
-msgid "Clears the clipboard contents stored by Klipper"
-msgstr ""
-
-#: privacyfunctions.h:69
-#, kde-format
-msgid "Clears all cached thumbnails"
-msgstr ""
-
-#: privacyfunctions.h:78
-#, kde-format
-msgid "Run Command History"
-msgstr ""
-
-#: privacyfunctions.h:79
-#, kde-format
-msgid ""
-"Clears the history of commands run through the Run Command tool on the "
-"desktop"
-msgstr ""
-
-#: privacyfunctions.h:88
-#, kde-format
-msgid "Form Completion Entries"
-msgstr ""
-
-#: privacyfunctions.h:89
-#, kde-format
-msgid "Clears values which were entered into forms on websites"
-msgstr ""
-
-#: privacyfunctions.h:98
-#, kde-format
-msgid "Web History"
-msgstr ""
-
-#: privacyfunctions.h:99
-#, kde-format
-msgid "Clears the history of visited websites"
-msgstr ""
-
-#: privacyfunctions.h:108
-#, kde-format
-msgid "Web Cache"
-msgstr ""
-
-#: privacyfunctions.h:109
-#, kde-format
-msgid "Clears the temporary cache of websites visited"
-msgstr ""
-
-#: privacyfunctions.h:118
-#, kde-format
-msgid "Recent Documents"
-msgstr ""
-
-#: privacyfunctions.h:119
-#, kde-format
-msgid ""
-"Clears the list of recently used documents from the KDE applications menu"
-msgstr ""
-
-#: privacyfunctions.h:128
-#, kde-format
-msgid "Favorite Icons"
-msgstr ""
-
-#: privacyfunctions.h:129
-#, kde-format
-msgid "Clears the FavIcons cached from visited websites"
-msgstr ""
-
-#: privacyfunctions.h:138
-#, kde-format
-msgid "Recent Applications"
-msgstr ""
-
-#: privacyfunctions.h:139
-#, kde-format
-msgid "Clears the list of recently used applications from KDE menu"
-msgstr ""
-
-#: sweeper.cpp:49
-#, kde-format
-msgctxt "General system content"
-msgid "General"
-msgstr ""
-
-#: sweeper.cpp:51
-#, kde-format
-msgctxt "Web browsing content"
-msgid "Web Browsing"
-msgstr ""
-
-#: sweeper.cpp:126
-#, kde-format
-msgid ""
-"You are deleting data that is potentially valuable to you. Are you sure?"
-msgstr ""
-
-#: sweeper.cpp:132
-#, kde-format
-msgid "Starting cleanup..."
-msgstr ""
-
-#: sweeper.cpp:138
-#, kde-format
-msgid "Clearing %1..."
-msgstr ""
-
-#: sweeper.cpp:143
-#, kde-format
-msgid "Clearing of %1 failed: %2"
-msgstr ""
-
-#: sweeper.cpp:149
-#, kde-format
-msgid "Clean up finished."
-msgstr ""
-
-#. i18n: ectx: property (whatsThis), widget (QTreeWidget, privacyListView)
-#: sweeperdialog.ui:27
-#, kde-format
-msgid ""
-"Check all cleanup actions you would like to perform. These will be executed "
-"by pressing the button below."
-msgstr ""
-
-#. i18n: ectx: property (text), widget (QTreeWidget, privacyListView)
-#: sweeperdialog.ui:37
-#, kde-format
-msgid "Privacy Settings"
-msgstr ""
-
-#. i18n: ectx: property (text), widget (QTreeWidget, privacyListView)
-#: sweeperdialog.ui:42
-#, kde-format
-msgid "Description"
-msgstr ""
-
-#. i18n: ectx: property (text), widget (QPushButton, selectAllButton)
-#: sweeperdialog.ui:58
-#, kde-format
-msgid "Select &All"
-msgstr ""
-
-#. i18n: ectx: property (text), widget (QPushButton, selectNoneButton)
-#: sweeperdialog.ui:65
-#, kde-format
-msgid "Select &None"
-msgstr ""
-
-#. i18n: ectx: property (whatsThis), widget (QPushButton, cleanupButton)
-#: sweeperdialog.ui:88
-#, kde-format
-msgid "Immediately performs the cleanup actions selected above"
-msgstr ""
-
-#. i18n: ectx: property (text), widget (QPushButton, cleanupButton)
-#: sweeperdialog.ui:91
-#, kde-format
-msgid "&Clean Up"
-msgstr ""
diff -pruN 4:18.04.1-1/po/bg/sweeper.po 4:20.04.1-0ubuntu1/po/bg/sweeper.po
--- 4:18.04.1-1/po/bg/sweeper.po	2018-05-08 00:12:29.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/bg/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -6,8 +6,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: privacy\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
 "PO-Revision-Date: 2011-07-24 14:06+0300\n"
 "Last-Translator: Yasen Pramatarov <yasen@lindeas.com>\n"
 "Language-Team: Bulgarian <dict@linux.zonebg.com>\n"
@@ -39,8 +39,9 @@ msgid "Helps clean unwanted traces the u
 msgstr "Почистване на нежелани следи, оставяни от потребителя в системата."
 
 #: main.cpp:47
-#, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+#, fuzzy, kde-format
+#| msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "(c) 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
@@ -78,17 +79,17 @@ msgstr "Кеш на миниатюрит
 msgid "Sweeps without user interaction"
 msgstr "Почистване без намеса на потребителя"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Грешка при премахване на миниатюра"
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Файлът съществува, но не може да се премахне."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Грешка при премахване на икона на сайт"
@@ -204,40 +205,40 @@ msgstr "Скорошни програм
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Изчистване на списъка с последно използвани програми на KDE"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Общи"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Сърфиране в уеб"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "Изтривате данни, които може да са ценни за вас. Сигурни ли сте?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Започване на изчистването..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Изчистване на %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Грешка при изчистване на %1: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Изчистването завърши."
diff -pruN 4:18.04.1-1/po/bs/sweeper.po 4:20.04.1-0ubuntu1/po/bs/sweeper.po
--- 4:18.04.1-1/po/bs/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/bs/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -6,8 +6,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: kdeutils\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
 "PO-Revision-Date: 2013-10-18 20:09+0000\n"
 "Last-Translator: Samir Ribić <Unknown>\n"
 "Language-Team: Bosnian <bs@li.org>\n"
@@ -41,8 +41,9 @@ msgid "Helps clean unwanted traces the u
 msgstr "Uklanjanje neželjenih tragova koje korisnik ostavlja na sistemu."
 
 #: main.cpp:47
-#, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+#, fuzzy, kde-format
+#| msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "(c) 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
@@ -80,17 +81,17 @@ msgstr "Spremnik umanjenih sličica"
 msgid "Sweeps without user interaction"
 msgstr "Čisti bez zapitkivanja korisnika."
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Sličica se ne može ukloniti."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Datoteka postoji, ali se ne može ukloniti."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Favikona se ne može ukloniti."
@@ -203,41 +204,41 @@ msgstr "Skorašnji programi"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Čisti spisak skoro korišćenih programa iz KDE‑ovog menija."
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Opšte"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Web pregledanje"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr ""
 "Brišete podatke koji bi mogli biti od neke vrijednosti. Da li ste sigurni?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Počinjem brisanje..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Brišem %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Čišćenje %1 nije uspelo: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Čišćenje je završeno."
diff -pruN 4:18.04.1-1/po/ca/sweeper.po 4:20.04.1-0ubuntu1/po/ca/sweeper.po
--- 4:18.04.1-1/po/ca/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/ca/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -1,17 +1,17 @@
 # Translation of sweeper.po to Catalan
-# Copyright (C) 2003-2017 This_file_is_part_of_KDE
+# Copyright (C) 2003-2019 This_file_is_part_of_KDE
 #
 # Antoni Bella Pérez <antonibella5@yahoo.com>, 2003, 2017.
 # Sebastià Pla i Sanz <sps@sastia.com>, 2004, 2005, 2006.
-# Josep Ma. Ferrer <txemaq@gmail.com>, 2007, 2008, 2009, 2010, 2011, 2014, 2017.
+# Josep Ma. Ferrer <txemaq@gmail.com>, 2007, 2008, 2009, 2010, 2011, 2014, 2017, 2019.
 # Joan Maspons <joanmaspons@gmail.com>, 2009.
 # Manuel Tortosa Moreno <manutortosa@gmail.com>, 2009.
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2017-09-03 13:48+0100\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-07-05 16:37+0100\n"
 "Last-Translator: Josep Ma. Ferrer <txemaq@gmail.com>\n"
 "Language-Team: Catalan <kde-i18n-ca@kde.org>\n"
 "Language: ca\n"
@@ -45,8 +45,8 @@ msgstr ""
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
-msgstr "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
+msgstr "© 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
 #, kde-format
@@ -83,17 +83,17 @@ msgstr "Memòria cau de les miniatures"
 msgid "Sweeps without user interaction"
 msgstr "Escombra sense la interacció de l'usuari"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "No s'ha pogut suprimir una miniatura."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "El fitxer existeix però no s'ha pogut eliminar."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "No s'ha pogut eliminar una icona de web."
@@ -211,40 +211,40 @@ msgstr "Aplicacions recents"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Neteja la llista d'aplicacions usades recentment des del menú del KDE"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "General"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Navegació web"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "Suprimireu dades que són potencialment valuoses. N'esteu segur?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "S'està iniciant la neteja..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "S'està netejant %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Ha fallat la neteja de %1: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Ha finalitzat la neteja."
@@ -294,101 +294,3 @@ msgstr "Efectua immediatament les accion
 #, kde-format
 msgid "&Clean Up"
 msgstr "&Neteja"
-
-#~ msgid "Network privacy level:"
-#~ msgstr "Nivell de privacitat de la xarxa:"
-
-#~ msgid "Low"
-#~ msgstr "Baix"
-
-#~ msgid "Medium"
-#~ msgstr "Mitjà"
-
-#~ msgid "High"
-#~ msgstr "Alt"
-
-#~ msgid "Custom"
-#~ msgstr "A mida"
-
-#~ msgid "Financial Information"
-#~ msgstr "Informació financera"
-
-#~ msgid ""
-#~ "Warn me when I visit a site that uses my financial or purchase "
-#~ "information:"
-#~ msgstr ""
-#~ "Avisa'm quan visito un lloc que usa la meva informació financera o de "
-#~ "compres:"
-
-#~ msgid "For marketing or advertising purposes"
-#~ msgstr "Amb propòsits de màrqueting o publicitat"
-
-#~ msgid "To share with other companies"
-#~ msgstr "Per a compartir amb d'altres companyies"
-
-#~ msgid "Health Information"
-#~ msgstr "Informació de salut"
-
-#~ msgid ""
-#~ "Warn me when I visit a site that uses my health or medical information: "
-#~ msgstr ""
-#~ "Avisa'm quan visito un lloc que usa la meva informació sanitària o "
-#~ "mèdica: "
-
-#~ msgid "Demographics"
-#~ msgstr "Demografia"
-
-#~ msgid ""
-#~ "Warn me when I visit a site that uses my non-personally identifiable "
-#~ "information:"
-#~ msgstr ""
-#~ "Avisa'm quan visito un lloc que usa informació meva no identificable "
-#~ "personalment:"
-
-#~ msgid "To determine my interests, habits or general behavior"
-#~ msgstr ""
-#~ "Per a determinar els meus interessos, costums o comportament general"
-
-#~ msgid ""
-#~ "Warn me when I visit a site that shares my personal information with "
-#~ "other companies"
-#~ msgstr ""
-#~ "Avisa'm quan visito un lloc que comparteix la meva informació personal "
-#~ "amb d'altres companyies"
-
-#~ msgid ""
-#~ "Warn me when I visit a site that does not let me know what information "
-#~ "they have about me"
-#~ msgstr ""
-#~ "Avisa'm quan visito un lloc que no em permet conèixer quina informació "
-#~ "meva tenen"
-
-#~ msgid "Personal Information"
-#~ msgstr "Informació personal"
-
-#~ msgid ""
-#~ "Warn me when I visit a site that may contact me about other products or "
-#~ "services:"
-#~ msgstr ""
-#~ "Avisa'm quan visito un lloc que pot contactar amb mi per a d'altres "
-#~ "productes o serveis:"
-
-#~ msgid "Warn me when I visit a site that may use my personal information to:"
-#~ msgstr ""
-#~ "Avisa'm quan visito un lloc que podria usar la meva informació personal "
-#~ "per a:"
-
-#~ msgid "Determine my habits, interests or general behavior"
-#~ msgstr "Determinar els meus costums, interessos o comportament general"
-
-#~ msgid "Via telephone"
-#~ msgstr "Via telefònica"
-
-#~ msgid "Via mail"
-#~ msgstr "Via correu"
-
-#~ msgid "Via email"
-#~ msgstr "Via correu electrònic"
-
-#~ msgid "And do not allow me to remove my contact information"
-#~ msgstr "I no em permet eliminar la meva informació de contacte"
diff -pruN 4:18.04.1-1/po/ca@valencia/sweeper.po 4:20.04.1-0ubuntu1/po/ca@valencia/sweeper.po
--- 4:18.04.1-1/po/ca@valencia/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/ca@valencia/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -6,19 +6,20 @@
 # Josep Ma. Ferrer <txemaq@gmail.com>, 2007, 2008, 2009, 2010, 2011, 2014, 2017.
 # Joan Maspons <joanmaspons@gmail.com>, 2009.
 # Manuel Tortosa Moreno <manutortosa@gmail.com>, 2009.
+# empar <montoro_mde@gva.es>, 2019.
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2017-09-03 13:48+0100\n"
-"Last-Translator: Josep Ma. Ferrer <txemaq@gmail.com>\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-09-27 08:52+0200\n"
+"Last-Translator: empar <montoro_mde@gva.es>\n"
 "Language-Team: Catalan <kde-i18n-ca@kde.org>\n"
 "Language: ca@valencia\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 2.0\n"
+"X-Generator: Lokalize 19.04.2\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 "X-Accelerator-Marker: &\n"
 
@@ -35,7 +36,7 @@ msgstr "antonibella5@yahoo.com,sps@sasti
 #: main.cpp:43
 #, kde-format
 msgid "Sweeper"
-msgstr "Escombriaire"
+msgstr "Agranador"
 
 #: main.cpp:45
 #, kde-format
@@ -44,8 +45,8 @@ msgstr ""
 "Ajuda a netejar els rastres no desitjats que l'usuari deixa en el sistema."
 
 #: main.cpp:47
-#, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+#, fuzzy, kde-format
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "(c) 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
@@ -81,19 +82,19 @@ msgstr "Memòria cau de les miniatures"
 #: main.cpp:61
 #, kde-format
 msgid "Sweeps without user interaction"
-msgstr "Escombra sense la interacció de l'usuari"
+msgstr "Agrana sense la interacció de l'usuari"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "No s'ha pogut suprimir una miniatura."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "El fitxer existeix però no s'ha pogut eliminar."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "No s'ha pogut eliminar una icona de web."
@@ -106,7 +107,7 @@ msgstr "Galetes"
 #: privacyfunctions.h:38
 #, kde-format
 msgid "Clears all stored cookies set by websites"
-msgstr "Neteja totes les galetes guardades pels llocs web"
+msgstr "Neteja totes les galetes guardades per als llocs web"
 
 #: privacyfunctions.h:48
 #, kde-format
@@ -121,12 +122,12 @@ msgstr "Neteja la política de les galet
 #: privacyfunctions.h:58
 #, kde-format
 msgid "Saved Clipboard Contents"
-msgstr "Contingut guardat al porta-retalls"
+msgstr "Contingut guardat en el porta-retalls"
 
 #: privacyfunctions.h:59
 #, kde-format
 msgid "Clears the clipboard contents stored by Klipper"
-msgstr "Neteja el contingut guardat al porta-retalls pel Klipper"
+msgstr "Neteja el contingut guardat en el porta-retalls per Klipper"
 
 #: privacyfunctions.h:69
 #, kde-format
@@ -209,42 +210,42 @@ msgstr "Aplicacions recents"
 #: privacyfunctions.h:139
 #, kde-format
 msgid "Clears the list of recently used applications from KDE menu"
-msgstr "Neteja la llista d'aplicacions usades recentment des del menú del KDE"
+msgstr "Neteja la llista d'aplicacions usades recentment des del menú de KDE"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "General"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Navegació web"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "Suprimireu dades que són potencialment valuoses. N'esteu segur?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "S'està iniciant la neteja..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "S'està netejant %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Ha fallat la neteja de %1: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Ha finalitzat la neteja."
@@ -257,13 +258,13 @@ msgid ""
 "by pressing the button below."
 msgstr ""
 "Marqueu totes les opcions de neteja que vulgueu realitzar. S'executaran en "
-"prémer el botó que hi ha a sota."
+"prémer el botó que hi ha davall."
 
 #. i18n: ectx: property (text), widget (QTreeWidget, privacyListView)
 #: sweeperdialog.ui:37
 #, kde-format
 msgid "Privacy Settings"
-msgstr "Arranjament de la privadesa"
+msgstr "Configuració de la privadesa"
 
 #. i18n: ectx: property (text), widget (QTreeWidget, privacyListView)
 #: sweeperdialog.ui:42
@@ -287,108 +288,10 @@ msgstr "&No seleccionis res"
 #: sweeperdialog.ui:88
 #, kde-format
 msgid "Immediately performs the cleanup actions selected above"
-msgstr "Efectua immediatament les accions de neteja seleccionades a dalt"
+msgstr "Efectua immediatament les accions de neteja seleccionades dalt"
 
 #. i18n: ectx: property (text), widget (QPushButton, cleanupButton)
 #: sweeperdialog.ui:91
 #, kde-format
 msgid "&Clean Up"
 msgstr "&Neteja"
-
-#~ msgid "Network privacy level:"
-#~ msgstr "Nivell de privacitat de la xarxa:"
-
-#~ msgid "Low"
-#~ msgstr "Baix"
-
-#~ msgid "Medium"
-#~ msgstr "Mitjà"
-
-#~ msgid "High"
-#~ msgstr "Alt"
-
-#~ msgid "Custom"
-#~ msgstr "A mida"
-
-#~ msgid "Financial Information"
-#~ msgstr "Informació financera"
-
-#~ msgid ""
-#~ "Warn me when I visit a site that uses my financial or purchase "
-#~ "information:"
-#~ msgstr ""
-#~ "Avisa'm quan visito un lloc que usa la meva informació financera o de "
-#~ "compres:"
-
-#~ msgid "For marketing or advertising purposes"
-#~ msgstr "Amb propòsits de màrqueting o publicitat"
-
-#~ msgid "To share with other companies"
-#~ msgstr "Per a compartir amb d'altres companyies"
-
-#~ msgid "Health Information"
-#~ msgstr "Informació de salut"
-
-#~ msgid ""
-#~ "Warn me when I visit a site that uses my health or medical information: "
-#~ msgstr ""
-#~ "Avisa'm quan visito un lloc que usa la meva informació sanitària o "
-#~ "mèdica: "
-
-#~ msgid "Demographics"
-#~ msgstr "Demografia"
-
-#~ msgid ""
-#~ "Warn me when I visit a site that uses my non-personally identifiable "
-#~ "information:"
-#~ msgstr ""
-#~ "Avisa'm quan visito un lloc que usa informació meva no identificable "
-#~ "personalment:"
-
-#~ msgid "To determine my interests, habits or general behavior"
-#~ msgstr ""
-#~ "Per a determinar els meus interessos, costums o comportament general"
-
-#~ msgid ""
-#~ "Warn me when I visit a site that shares my personal information with "
-#~ "other companies"
-#~ msgstr ""
-#~ "Avisa'm quan visito un lloc que comparteix la meva informació personal "
-#~ "amb d'altres companyies"
-
-#~ msgid ""
-#~ "Warn me when I visit a site that does not let me know what information "
-#~ "they have about me"
-#~ msgstr ""
-#~ "Avisa'm quan visito un lloc que no em permet conèixer quina informació "
-#~ "meva tenen"
-
-#~ msgid "Personal Information"
-#~ msgstr "Informació personal"
-
-#~ msgid ""
-#~ "Warn me when I visit a site that may contact me about other products or "
-#~ "services:"
-#~ msgstr ""
-#~ "Avisa'm quan visito un lloc que pot contactar amb mi per a d'altres "
-#~ "productes o serveis:"
-
-#~ msgid "Warn me when I visit a site that may use my personal information to:"
-#~ msgstr ""
-#~ "Avisa'm quan visito un lloc que podria usar la meva informació personal "
-#~ "per a:"
-
-#~ msgid "Determine my habits, interests or general behavior"
-#~ msgstr "Determinar els meus costums, interessos o comportament general"
-
-#~ msgid "Via telephone"
-#~ msgstr "Via telefònica"
-
-#~ msgid "Via mail"
-#~ msgstr "Via correu"
-
-#~ msgid "Via email"
-#~ msgstr "Via correu electrònic"
-
-#~ msgid "And do not allow me to remove my contact information"
-#~ msgstr "I no em permet eliminar la meva informació de contacte"
diff -pruN 4:18.04.1-1/po/cs/sweeper.po 4:20.04.1-0ubuntu1/po/cs/sweeper.po
--- 4:18.04.1-1/po/cs/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/cs/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -2,22 +2,22 @@
 # This file is distributed under the same license as the PACKAGE package.
 # Lukáš Tinkl <ltinkl@redhat.com>, 2010.
 # Tomáš Chvátal <tomas.chvatal@gmail.com>, 2013.
-# Vit Pelcak <vit@pelcak.org>, 2013, 2014.
+# Vit Pelcak <vit@pelcak.org>, 2013, 2014, 2019.
 #
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2014-10-24 16:25+0200\n"
-"Last-Translator: Vít Pelčák <vit@pelcak.org>\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-09-05 15:39+0200\n"
+"Last-Translator: Vit Pelcak <vit@pelcak.org>\n"
 "Language-Team: Czech <kde-i18n-doc@kde.org>\n"
 "Language: cs\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;\n"
-"X-Generator: Lokalize 1.5\n"
+"X-Generator: Lokalize 19.08.0\n"
 
 #, kde-format
 msgctxt "NAME OF TRANSLATORS"
@@ -41,8 +41,8 @@ msgstr "Pomáhá smazat nechtěné stopy
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
-msgstr "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
+msgstr "© 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
 #, kde-format
@@ -79,17 +79,17 @@ msgstr "Mezipaměť miniatur"
 msgid "Sweeps without user interaction"
 msgstr "Vyčistí bez zásahu uživatele"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Nelze odstranit miniaturu."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Soubor existuje, ale nelze jej odstranit."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Nelze odstranit favicon."
@@ -202,40 +202,40 @@ msgstr "Nedávné aplikace"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Smaže seznam nedávno použitých aplikací z nabídky KDE"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Obecné"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Prohlížení webu"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "Mažete data, která jsou pro vás částečně hodnotná. Jste si jisti?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Startuji vyčištění..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Čistím %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Čištění %1 selhalo: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Vyčištění dokončeno."
diff -pruN 4:18.04.1-1/po/da/sweeper.po 4:20.04.1-0ubuntu1/po/da/sweeper.po
--- 4:18.04.1-1/po/da/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/da/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -3,20 +3,20 @@
 # Copyright (C).
 #
 # Erik Kjær Pedersen <erik@binghamton.edu>, 2003, 2004.
-# Martin Schlander <mschlander@opensuse.org>, 2008, 2009, 2010.
+# Martin Schlander <mschlander@opensuse.org>, 2008, 2009, 2010, 2020.
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2010-06-04 10:31+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2020-02-13 20:04+0100\n"
 "Last-Translator: Martin Schlander <mschlander@opensuse.org>\n"
 "Language-Team: Danish <dansk@dansk-gruppen.dk>\n"
 "Language: da\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 1.0\n"
+"X-Generator: Lokalize 18.12.3\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 
 #, kde-format
@@ -42,7 +42,7 @@ msgstr ""
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "(c) 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
@@ -80,17 +80,17 @@ msgstr "Miniature-cache"
 msgid "Sweeps without user interaction"
 msgstr "Gør rent uden brugerinteraktion"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "En miniature kunne ikke fjernes."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Filen eksisterer men kunne ikke fjernes."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Et favicon kunne ikke fjernes."
@@ -205,40 +205,40 @@ msgstr "Nylige programmer"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Rydder listen for nyligt brugte dokumenter fra KDE-menuen"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Generelt"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Webbrowsing"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "Du sletter data der er potentielt værdifulde for dig. Er du sikker?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Starter oprydning..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Rydder %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Rydning af %1 mislykkedes: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Oprydning færdig."
diff -pruN 4:18.04.1-1/po/de/sweeper.po 4:20.04.1-0ubuntu1/po/de/sweeper.po
--- 4:18.04.1-1/po/de/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/de/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -2,21 +2,21 @@
 # Stephan Johach <hunsum@gmx.de>, 2005.
 # Thomas Reitelbach <tr@erdfunkstelle.de>, 2005, 2006, 2007.
 # Gregor Zumstein <gz@orchester-bremgarten.ch>, 2007, 2008.
-# Burkhard Lück <lueck@hube-lueck.de>, 2009, 2010, 2014, 2016.
+# Burkhard Lück <lueck@hube-lueck.de>, 2009, 2010, 2014, 2016, 2019.
 # Panagiotis Papadopoulos <pano_90@gmx.net>, 2010.
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2016-04-08 06:37+0100\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-07-09 07:16+0200\n"
 "Last-Translator: Burkhard Lück <lueck@hube-lueck.de>\n"
 "Language-Team: German <kde-i18n-de@kde.org>\n"
 "Language: de\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 2.0\n"
+"X-Generator: Lokalize 18.12.3\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 
 #, kde-format
@@ -41,7 +41,7 @@ msgstr "Hilft dem Benutzer ungewollte Sp
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "© 2003–2005, Ralf Hoelzer"
 
 #: main.cpp:51
@@ -79,17 +79,17 @@ msgstr "Zwischenspeicher für Minivorsch
 msgid "Sweeps without user interaction"
 msgstr "Bereinigung des Zwischenspeichers ohne Eingriffe des Benutzers"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Eine Vorschau-Datei lässt sich nicht entfernen."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Die Datei existiert, kann aber nicht entfernt werden."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Ein Favicon lässt sich nicht entfernen."
@@ -207,19 +207,19 @@ msgstr "Zuletzt benutzte Anwendungen"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Leert die Liste der zuletzt geöffneten Anwendungen im K-Menü"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Allgemein"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Webbrowser"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
@@ -227,22 +227,22 @@ msgstr ""
 "Sie sind im Begriff, Daten zu löschen, die möglicherweise wichtig für Sie "
 "sind. Möchten Sie fortfahren?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Bereinigung wird gestartet ..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Wird bereinigt: %1"
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Bereinigen von %1 ist fehlgeschlagen: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Bereinigung abgeschlossen"
diff -pruN 4:18.04.1-1/po/el/sweeper.po 4:20.04.1-0ubuntu1/po/el/sweeper.po
--- 4:18.04.1-1/po/el/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/el/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -6,19 +6,20 @@
 # Toussis Manolis <manolis@koppermind.homelinux.org>, 2007.
 # Antonis Geralis <capoiosct@gmail.com>, 2011, 2012.
 # Dimitrios Glentadakis <dglent@gmail.com>, 2012.
+# Stelios <sstavra@gmail.com>, 2019.
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2012-01-03 19:09+0100\n"
-"Last-Translator: Dimitrios Glentadakis <dglent@gmail.com>\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-07-26 11:06+0300\n"
+"Last-Translator: Stelios <sstavra@gmail.com>\n"
 "Language-Team: Greek <kde-i18n-el@kde.org>\n"
 "Language: el\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 1.2\n"
+"X-Generator: Lokalize 18.12.3\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 
 #, kde-format
@@ -44,8 +45,8 @@ msgstr ""
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
-msgstr "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
+msgstr "© 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
 #, kde-format
@@ -82,17 +83,17 @@ msgstr "Λανθάνουσα μνήμη
 msgid "Sweeps without user interaction"
 msgstr "Καθαρίζει χωρίς την αλληλεπίδραση του χρήστη"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Αδυναμία αφαίρεσης μιας εικόνας επισκόπησης."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Το αρχείο υπάρχει αλλά δεν μπορεί να αφαιρεθεί."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Ένα εικονίδιο αγαπημένων δεν μπορεί να αφαιρεθεί."
@@ -212,41 +213,41 @@ msgid "Clears the list of recently used
 msgstr ""
 "Καθαρίζει τη λίστα των πρόσφατων εφαρμογών από το μενού εφαρμογών του KDE"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Γενικά"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Περιήγηση ιστού"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr ""
 "Διαγράφεται δεδομένα που μπορεί να σας είναι πολύτιμα. Είσαστε σίγουροι;"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Εκκίνηση καθαρισμού..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Καθάρισμα %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Ο καθαρισμός του %1 απέτυχε: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Το καθάρισμα τελείωσε."
diff -pruN 4:18.04.1-1/po/en_GB/sweeper.po 4:20.04.1-0ubuntu1/po/en_GB/sweeper.po
--- 4:18.04.1-1/po/en_GB/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/en_GB/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -3,19 +3,21 @@
 #
 # Malcolm Hunter <malcolm.hunter@gmx.co.uk>, 2003.
 # Andrew Coles <andrew_coles@yahoo.co.uk>, 2004, 2009, 2010.
+# Steve Allewell <steve.allewell@gmail.com>, 2019.
 msgid ""
 msgstr ""
 "Project-Id-Version: privacy\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2010-05-07 15:58+0100\n"
-"Last-Translator: Andrew Coles <andrew_coles@yahoo.co.uk>\n"
-"Language-Team: British English <kde-i18n-doc@kde.org>\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-08-03 16:38+0100\n"
+"Last-Translator: Steve Allewell <steve.allewell@gmail.com>\n"
+"Language-Team: British English <kde-l10n-en_gb@kde.org>\n"
 "Language: en_GB\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
+"X-Generator: Lokalize 19.07.70\n"
 
 #, kde-format
 msgctxt "NAME OF TRANSLATORS"
@@ -39,8 +41,8 @@ msgstr "Helps clean unwanted traces the
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
-msgstr "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
+msgstr "© 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
 #, kde-format
@@ -77,17 +79,17 @@ msgstr "Thumbnail Cache"
 msgid "Sweeps without user interaction"
 msgstr "Sweeps without user interaction"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "A thumbnail could not be removed."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "The file exists but could not be removed."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "A favicon could not be removed."
@@ -203,41 +205,41 @@ msgstr "Recent Applications"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Clears the list of recently used applications from KDE menu"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "General"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Web Browsing"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Starting cleanup..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Clearing %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Clearing of %1 failed: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Clean up finished."
diff -pruN 4:18.04.1-1/po/eo/sweeper.po 4:20.04.1-0ubuntu1/po/eo/sweeper.po
--- 4:18.04.1-1/po/eo/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/eo/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -3,8 +3,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: privacy\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
 "PO-Revision-Date: 2007-03-01 09:39+0100\n"
 "Last-Translator: Axel Rousseau <axel@esperanto-jeunes.org>\n"
 "Language-Team: Esperanto <eo@li.org>\n"
@@ -38,7 +38,7 @@ msgstr ""
 #: main.cpp:47
 #, fuzzy, kde-format
 #| msgid "(c) 2003 Ralf Hoelzer"
-msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "© 2003 Ralf Hoelzer"
 
 #: main.cpp:51
@@ -76,17 +76,17 @@ msgstr "miniatura staplo"
 msgid "Sweeps without user interaction"
 msgstr ""
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr ""
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr ""
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr ""
@@ -203,40 +203,40 @@ msgstr ""
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Ĝi forigas la liston de lastlaboritaj dokumentoj el la aplikaĵa menuo"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Ĝenerale"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "TTT-Rigardo"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "Vi forigas datumoj, kiuj eble estas gravaj por vi. Ĉu vi certas?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Komencu de forigu"
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Forigas %1"
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, fuzzy, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Forigo de %1 fiaskis"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Forigo finis."
diff -pruN 4:18.04.1-1/po/es/sweeper.po 4:20.04.1-0ubuntu1/po/es/sweeper.po
--- 4:18.04.1-1/po/es/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/es/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -3,20 +3,20 @@
 #
 # Miguel Revilla Rodríguez <yo@miguelrevilla.com>, 2003.
 # Jaime Robles <jaime@kde.org>, 2004.
-# Eloy Cuadra <ecuadra@eloihr.net>, 2007, 2008, 2009, 2010, 2011, 2014.
+# Eloy Cuadra <ecuadra@eloihr.net>, 2007, 2008, 2009, 2010, 2011, 2014, 2019.
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2014-03-26 15:59+0100\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-07-12 03:50+0200\n"
 "Last-Translator: Eloy Cuadra <ecuadra@eloihr.net>\n"
 "Language-Team: Spanish <kde-l10n-es@kde.org>\n"
 "Language: es\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 1.5\n"
+"X-Generator: Lokalize 19.04.2\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 
 #, kde-format
@@ -42,8 +42,8 @@ msgstr ""
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
-msgstr "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
+msgstr "© 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
 #, kde-format
@@ -80,17 +80,17 @@ msgstr "Caché de miniaturas"
 msgid "Sweeps without user interaction"
 msgstr "Limpia sin la interacción del usuario"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "No se ha podido eliminar una miniatura."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "El archivo existe, pero no se ha podido eliminar."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "No se ha podido eliminar un «favicon»."
@@ -209,40 +209,40 @@ msgid "Clears the list of recently used
 msgstr ""
 "Limpia la lista de las aplicaciones recientemente usadas del menú de KDE"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "General"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Navegación web"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "Está eliminando información potencialmente valiosa. ¿Está seguro?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Iniciando limpieza..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Limpiando %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "La limpieza de %1 ha fallado: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Limpieza finalizada."
diff -pruN 4:18.04.1-1/po/et/sweeper.po 4:20.04.1-0ubuntu1/po/et/sweeper.po
--- 4:18.04.1-1/po/et/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/et/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -2,20 +2,20 @@
 # Copyright (C) 2003 Free Software Foundation, Inc.
 #
 # Marek Laane <bald@starman.ee>, 2003-2004,2007-2008.
-# Marek Laane <bald@smail.ee>, 2009, 2010.
+# Marek Laane <bald@smail.ee>, 2009, 2010, 2019.
 msgid ""
 msgstr ""
 "Project-Id-Version: privacy\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2010-07-05 01:21+0300\n"
-"Last-Translator: Marek Laane <bald@smail.ee>\n"
-"Language-Team: Estonian <kde-et@linux.ee>\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-11-10 23:09+0200\n"
+"Last-Translator: Marek Laane <qiilaq69@gmail.com>\n"
+"Language-Team: Estonian <kde-et@lists.linux.ee>\n"
 "Language: et\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 1.0\n"
+"X-Generator: Lokalize 19.08.1\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 
 #, kde-format
@@ -26,7 +26,7 @@ msgstr "Marek Laane"
 #, kde-format
 msgctxt "EMAIL OF TRANSLATORS"
 msgid "Your emails"
-msgstr "bald@starman.ee"
+msgstr "qiilaq69@gmail.com"
 
 #: main.cpp:43
 #, kde-format
@@ -40,8 +40,8 @@ msgstr "Aitab kõrvaldada süsteemist ka
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
-msgstr "(c) 2003-2005: Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
+msgstr "© 2003-2005: Ralf Hoelzer"
 
 #: main.cpp:51
 #, kde-format
@@ -78,17 +78,17 @@ msgstr "Pisipiltide puhver"
 msgid "Sweeps without user interaction"
 msgstr "Kõrvaldamine ilma kasutaja sekkumisvõimaluseta"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Pisipilti ei saa eemaldada."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Fail on olemas, aga seda ei saa eemaldada."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Tunnusikooni ei saa eemaldada."
@@ -203,19 +203,19 @@ msgstr "Viimati kasutatud rakendused"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Puhastab KDE menüüs viimati kasutatud rakenduste nimekirja"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Üldine"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Veebilehitsemine"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
@@ -223,22 +223,22 @@ msgstr ""
 "Kavatsed kustutada andmeid, millel võib olla mingi väärtus. Kas oled ikka "
 "kindel?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Puhastamise alustamine..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Puhastatakse: %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "%1: puhastamine nurjus: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Puhastamine lõpetatud."
diff -pruN 4:18.04.1-1/po/eu/sweeper.po 4:20.04.1-0ubuntu1/po/eu/sweeper.po
--- 4:18.04.1-1/po/eu/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/eu/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -1,24 +1,28 @@
 # Translation of sweeper.po to Euskara/Basque (eu).
 # Copyright (C) 2003, 2004, 2005, 2006 Free Software Foundation.
+# Copyright (C) 2007-2019, This file is copyright:
+# This file is distributed under the same license as the sweeper package.
+# KDE euskaratzeko proiektuaren arduraduna <xalba@euskalnet.net>.
 #
+# Translators:
 # Marcos  <marcos@euskalgnu.org>, 2003, 2005, 2006.
 # Juan Irigoien <juanirigioen@yahoo.es>, 2004.
 # Juan Irigoien <juanirigoien@irakasle.net>, 2004.
-# Iñigo Salvador Azurmendi <xalba@euskalnet.net>, 2008, 2009, 2010, 2011, 2013.
+# Iñigo Salvador Azurmendi <xalba@euskalnet.net>, 2008, 2009, 2010, 2011, 2013, 2019.
 # Hizkuntza Politikarako Sailburuordetza <hizpol@ej-gv.es>, 2013.
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2013-12-23 19:24+0100\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-07-05 23:39+0200\n"
 "Last-Translator: Iñigo Salvador Azurmendi <xalba@euskalnet.net>\n"
-"Language-Team: Basque <kde-i18n-doc@kde.org>\n"
+"Language-Team: Basque <kde-i18n-eu@kde.org>\n"
 "Language: eu\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 1.5\n"
+"X-Generator: Lokalize 19.04.2\n"
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
 
 #, kde-format
@@ -47,8 +51,8 @@ msgstr "Erabiltzaileak sisteman uzten di
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
-msgstr "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
+msgstr "© 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
 #, kde-format
@@ -85,17 +89,17 @@ msgstr "Koadro txikien cachea"
 msgid "Sweeps without user interaction"
 msgstr "Erabiltzailearen parte-hartzerik gabe garbitzen du"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Ezin izan da koadro txiki bat kendu."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Fitxategia badago, baina ezin izan da kendu."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Ezin izan da kendu gogikono bat."
@@ -212,40 +216,40 @@ msgstr "Azken aplikazioak"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Erabilitako azken aplikazioen zerrenda garbitzen du KDEren menuan"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Orokorra"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Web-a arakatzea"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "Baliogarri izan daitezkeen datuak ezabatzen ari zara. Ziur zaude?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Garbiketa abiarazten..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "%1 garbitzen..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Huts egin du %1 garbitzean: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Garbiketa bukatuta."
diff -pruN 4:18.04.1-1/po/fa/sweeper.po 4:20.04.1-0ubuntu1/po/fa/sweeper.po
--- 4:18.04.1-1/po/fa/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/fa/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -6,8 +6,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
 "PO-Revision-Date: 2007-09-03 15:26+0330\n"
 "Last-Translator: Nazanin Kazemi <kazemi@itland.ir>\n"
 "Language-Team: Persian <kde-i18n-fa@kde.org>\n"
@@ -40,7 +40,7 @@ msgstr ""
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr ""
 
 #: main.cpp:51
@@ -78,17 +78,17 @@ msgstr "نهانگاه ریزنقش"
 msgid "Sweeps without user interaction"
 msgstr ""
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr ""
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr ""
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr ""
@@ -201,40 +201,40 @@ msgstr ""
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "فهرست اسناد اخیراً استفاده‌شده را از گزینگان کاربردهای KDE پاک می‌کند"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "عمومی"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "مرورگر وب"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "داده‌هایی را حذف می‌کنید که برای شما بسیار با ارزشند. آیا مطمئن هستید؟"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "آغاز پاک‌سازی..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "پاک کردن %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "پاک کردن %1 خراب شد: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "پاک‌سازی تمام شد."
diff -pruN 4:18.04.1-1/po/fi/sweeper.po 4:20.04.1-0ubuntu1/po/fi/sweeper.po
--- 4:18.04.1-1/po/fi/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/fi/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -6,23 +6,24 @@
 # Tapio Kautto <eleknader@phnet.fi>, 2004.
 # Ilpo Kantonen <ilpo@iki.fi>, 2005.
 # Lasse Liehu <lasse.liehu@gmail.com>, 2010, 2011, 2012, 2013, 2014.
+# Tommi Nieminen <translator@legisign.org>, 2019.
 #
 # KDE Finnish translation sprint participants:
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2014-11-08 03:39+0200\n"
-"Last-Translator: Lasse Liehu <lasse.liehu@gmail.com>\n"
-"Language-Team: Finnish <lokalisointi@lists.coss.fi>\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-07-30 23:11+0200\n"
+"Last-Translator: Tommi Nieminen <translator@legisign.org>\n"
+"Language-Team: Finnish <kde-i18n-doc@kde.org>\n"
 "Language: fi\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
 "X-POT-Import-Date: 2012-12-01 22:25:43+0000\n"
-"X-Generator: Lokalize 1.5\n"
+"X-Generator: Lokalize 2.0\n"
 
 #, kde-format
 msgctxt "NAME OF TRANSLATORS"
@@ -48,7 +49,7 @@ msgstr "Ohjelma käyttäjän jättämien
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "© 2003–2005 Ralf Hoelzer"
 
 #: main.cpp:51
@@ -86,17 +87,17 @@ msgstr "Esikatselukuvakkeiden välimuist
 msgid "Sweeps without user interaction"
 msgstr "Puhdistaa ilman käyttäjän vuorovaikutusta"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Esikatselukuvaketta ei voitu poistaa."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Tiedosto on olemassa, mutta sitä ei voitu poistaa."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Sivustokuvaketta ei voitu poistaa."
@@ -209,19 +210,19 @@ msgstr "Viimeksi käytetyt ohjelmat"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Tyhjentää viimeksi käytettyjen ohjelmien luettelon KDE-valikosta"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Yleiset"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Verkkoselaus"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
@@ -229,22 +230,22 @@ msgstr ""
 "Olet poistamassa tietoja, jotka voivat olla hyödyllistä. Haluatko varmasti "
 "jatkaa?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Käynnistetään tyhjentäminen…"
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Tyhennetään kohdetta %1…"
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Kohteen %1 tyhjentäminen epäonnistui: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Tyhjentäminen valmis."
diff -pruN 4:18.04.1-1/po/fr/sweeper.po 4:20.04.1-0ubuntu1/po/fr/sweeper.po
--- 4:18.04.1-1/po/fr/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/fr/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -11,21 +11,22 @@
 # Nicolas Ternisien <nicolas.ternisien@gmail.com>, 2008.
 # xavier <xavier.besnard@neuf.fr>, 2013.
 # Ludovic Grossard <ludovic.grossard@unilim.fr>, 2014.
+# Simon Depiets <sdepiets@gmail.com>, 2019.
 #
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2014-03-25 18:58+0100\n"
-"Last-Translator: Ludovic Grossard <ludovic.grossard@unilim.fr>\n"
-"Language-Team: French <kde-i18n-doc@kde.org>\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-07-20 13:08+0800\n"
+"Last-Translator: Simon Depiets <sdepiets@gmail.com>\n"
+"Language-Team: French <kde-francophone@kde.org>\n"
 "Language: fr\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n > 1);\n"
-"X-Generator: Lokalize 1.5\n"
+"X-Generator: Lokalize 19.07.70\n"
 "X-Environment: kde\n"
 "X-Accelerator-Marker: &\n"
 "X-Text-Markup: kde4\n"
@@ -33,12 +34,12 @@ msgstr ""
 #, kde-format
 msgctxt "NAME OF TRANSLATORS"
 msgid "Your names"
-msgstr "Matthieu Robin, François Grange"
+msgstr "Matthieu Robin, François Grange, Simon Depiets"
 
 #, kde-format
 msgctxt "EMAIL OF TRANSLATORS"
 msgid "Your emails"
-msgstr "kde@macolu.org, rumbaya@congelo.com"
+msgstr "kde@macolu.org, rumbaya@congelo.com, sdepiets@gmail.com"
 
 #: main.cpp:43
 #, kde-format
@@ -54,8 +55,8 @@ msgstr ""
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
-msgstr "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
+msgstr "© 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
 #, kde-format
@@ -92,17 +93,17 @@ msgstr "Cache des aperçus"
 msgid "Sweeps without user interaction"
 msgstr "Nettoie sans interaction avec l'utilisateur"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Impossible de supprimer un aperçu."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Le fichier existe mais impossible de le supprimer."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Impossible de supprimer une émoticône."
@@ -219,19 +220,19 @@ msgstr "Applications récentes"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Efface la liste des applications récemment utilisées du menu de KDE"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Général"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Navigation Web"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
@@ -239,22 +240,22 @@ msgstr ""
 "Vous êtes sur le point d'effacer des données qui sont peut-être importantes "
 "pour vous. Voulez-vous vraiment continuer ?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Démarrage du nettoyage..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Suppression de %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "La suppression de %1 a échoué : %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Nettoyage terminé."
diff -pruN 4:18.04.1-1/po/ga/sweeper.po 4:20.04.1-0ubuntu1/po/ga/sweeper.po
--- 4:18.04.1-1/po/ga/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/ga/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -5,8 +5,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: kdebase/privacy.po\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
 "PO-Revision-Date: 2004-12-03 14:52-0500\n"
 "Last-Translator: Kevin Scannell <kscanne@gmail.com>\n"
 "Language-Team: Irish <gaeilge-gnulinux@lists.sourceforge.net>\n"
@@ -38,8 +38,9 @@ msgid "Helps clean unwanted traces the u
 msgstr "Glan loirg a fhágann an t-úsáideoir ar an gcóras gan chuimhneamh."
 
 #: main.cpp:47
-#, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+#, fuzzy, kde-format
+#| msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "© 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
@@ -77,17 +78,17 @@ msgstr "Taisce Mionsamhlacha"
 msgid "Sweeps without user interaction"
 msgstr "Scuabadh gan idirghníomhú ón úsáideoir"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Níorbh fhéidir mionsamhail a bhaint."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Tá an comhad ann ach níorbh fhéidir é a bhaint."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Níorbh fhéidir deilbhín ceanán a bhaint."
@@ -205,19 +206,19 @@ msgstr "Feidhmchláir Le Déanaí"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Glan an liosta d'fheidhmchláir a úsáideadh le déanaí ón roghchlár KDE"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Ginearálta"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Brabhsáil Ghréasáin"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
@@ -225,22 +226,22 @@ msgstr ""
 "Tá tú ar tí sonraí a scriosadh agus seans go bhfuil na sonraí seo luachmhar. "
 "An bhfuil tú cinnte?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Glanadh á thosú..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "%1 á ghlanadh..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Theip ar ghlanadh %1: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Glanta."
diff -pruN 4:18.04.1-1/po/gl/sweeper.po 4:20.04.1-0ubuntu1/po/gl/sweeper.po
--- 4:18.04.1-1/po/gl/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/gl/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -6,24 +6,21 @@
 # mvillarino <mvillarino@users.sourceforge.net>, 2007, 2008.
 # Marce Villarino <mvillarino@gmail.com>, 2009, 2014.
 # Adrian Chaves Fernandez <adriyetichaves@gmail.com>, 2013.
-# Adrián Chaves (Gallaecio) <adrian@chaves.io>, 2017, 2018.
+# Adrián Chaves (Gallaecio) <adrian@chaves.io>, 2017, 2018, 2019.
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2018-04-28 22:40+0100\n"
-"Last-Translator: Adrian Chaves <adrian@chaves.io>\n"
-"Language-Team: Galician <kde-i18n-doc@kde.org>\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-09-29 09:22+0200\n"
+"Last-Translator: Adrián Chaves (Gallaecio) <adrian@chaves.io>\n"
+"Language-Team: Galician <proxecto@trasno.gal>\n"
 "Language: gl\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 2.0\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
-"X-Environment: kde\n"
-"X-Accelerator-Marker: &\n"
-"X-Text-Markup: kde4\n"
+"X-Generator: Lokalize 19.11.70\n"
 
 #, kde-format
 msgctxt "NAME OF TRANSLATORS"
@@ -47,8 +44,8 @@ msgstr "Axuda a limpar o ronsel non dese
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
-msgstr "© 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
+msgstr "© 2003-2005 Ralf Hoelzer"
 
 #: main.cpp:51
 #, kde-format
@@ -68,7 +65,7 @@ msgstr "Brian S. Stephan"
 #: main.cpp:52
 #, kde-format
 msgid "Maintainer"
-msgstr "Mantenedor"
+msgstr "Mantedor"
 
 #: main.cpp:53
 #, kde-format
@@ -85,17 +82,17 @@ msgstr "Caché de miniaturas"
 msgid "Sweeps without user interaction"
 msgstr "Varre automaticamente."
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Non se puido retirar unha miniatura."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "O ficheiro existe, pero non se puido retirar."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Non se puido retirar unha icona de páxina."
@@ -189,7 +186,7 @@ msgstr "Documentos recentes"
 msgid ""
 "Clears the list of recently used documents from the KDE applications menu"
 msgstr ""
-"Limpa a lista de documentos usados recentemente do menú de aplicativos de KDE"
+"Limpa a lista de documentos usados recentemente do menú de aplicacións de KDE"
 
 #: privacyfunctions.h:128
 #, kde-format
@@ -204,26 +201,26 @@ msgstr "Limpa a caché de iconas de páx
 #: privacyfunctions.h:138
 #, kde-format
 msgid "Recent Applications"
-msgstr "Aplicativos recentes"
+msgstr "Aplicacións recentes"
 
 #: privacyfunctions.h:139
 #, kde-format
 msgid "Clears the list of recently used applications from KDE menu"
-msgstr "Limpa a lista de aplicativos empregados recentemente do menú de KDE"
+msgstr "Limpa a lista de aplicacións usadas recentemente do menú de KDE"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Xeral"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Navegación web"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
@@ -231,22 +228,22 @@ msgstr ""
 "Está a eliminar datos que son potencialmente valiosos para vostede. Está "
 "seguro?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Estase a comezar a limpeza…"
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Estase a limpar %1…"
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Fallou a limpeza de %1: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Rematou a limpeza."
diff -pruN 4:18.04.1-1/po/he/sweeper.po 4:20.04.1-0ubuntu1/po/he/sweeper.po
--- 4:18.04.1-1/po/he/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/he/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -12,8 +12,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: privacy\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
 "PO-Revision-Date: 2005-08-28 13:38+0300\n"
 "Last-Translator: Israel Berger <israelb@gmail.com>\n"
 "Language-Team: hebrew <kde-l10n-he@kde.org>\n"
@@ -47,7 +47,7 @@ msgstr ""
 #: main.cpp:47
 #, fuzzy, kde-format
 #| msgid "(c) 2003 Ralf Hoelzer"
-msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "(c) 2003 Ralf Hoelzer"
 
 #: main.cpp:51
@@ -86,17 +86,17 @@ msgstr "מטמון תמונות מוקט
 msgid "Sweeps without user interaction"
 msgstr ""
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr ""
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr ""
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr ""
@@ -213,42 +213,42 @@ msgstr ""
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "מנקה את רשימת המסמכים ששומשו לאחרונה מתפריט תוכניות KDE"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, fuzzy, kde-format
 #| msgid "General"
 msgctxt "General system content"
 msgid "General"
 msgstr "כללי"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, fuzzy, kde-format
 #| msgid "Web Browsing"
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "גלישה ברשת"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "הנך מוחק מידע שיכול להיות בעל ערך לך. אתה בטוח?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "מתחיל בניקיון..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "מנקה %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, fuzzy, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "ניקוי של %1 נכשל"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "ניקיון הסתיים."
diff -pruN 4:18.04.1-1/po/hi/sweeper.po 4:20.04.1-0ubuntu1/po/hi/sweeper.po
--- 4:18.04.1-1/po/hi/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/hi/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -6,8 +6,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
 "PO-Revision-Date: 2008-02-04 15:10+0530\n"
 "Last-Translator: Ravishankar Shrivastava <aviratlami@aol.in>\n"
 "Language-Team: Hindi <indlinux-hindi@lists.sourceforge.net>\n"
@@ -43,8 +43,9 @@ msgstr ""
 "करता है."
 
 #: main.cpp:47
-#, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+#, fuzzy, kde-format
+#| msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "(c) 2003 - 2005, रॉल्फ हॉल्जर"
 
 #: main.cpp:51
@@ -82,17 +83,17 @@ msgstr "थम्बनेल कैश"
 msgid "Sweeps without user interaction"
 msgstr ""
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "लघुछवि मिटाई नहीं जा सकती."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "फ़ाइल मौजूद है, परंतु इसे मिटाया नहीं जा सकता."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "फ़ेविकोन मिटाई नहीं जा सकती."
@@ -207,42 +208,42 @@ msgstr ""
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "केडीई अनुप्रयोग मेन्यू से हालिया दस्तावेज़ों की सूची साफ करे"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, fuzzy, kde-format
 #| msgid "General"
 msgctxt "General system content"
 msgid "General"
 msgstr "सामान्य"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, fuzzy, kde-format
 #| msgid "Web Browsing"
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "वेब ब्राउजिंग"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "आप डाटा मिटा रहे हैं जो आपके लिए मूल्यवान हो सकते हैं. क्या आप सुनिश्चित हैं?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "क्लीनअप प्रारंभ किया जा रहा है..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "%1 साफ किया जा रहा है..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "%1 का साफ करना असफल: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "साफ करना पूर्ण."
diff -pruN 4:18.04.1-1/po/hr/sweeper.po 4:20.04.1-0ubuntu1/po/hr/sweeper.po
--- 4:18.04.1-1/po/hr/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/hr/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -4,8 +4,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
 "PO-Revision-Date: 2009-10-13 20:33+0200\n"
 "Last-Translator: Marko Dimjasevic <marko@dimjasevic.net>\n"
 "Language-Team: Croatian <kde-croatia-list@lists.sourceforge.net>\n"
@@ -43,7 +43,7 @@ msgstr ""
 #: main.cpp:47
 #, fuzzy, kde-format
 #| msgid "(c) 2003 Ralf Hoelzer"
-msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "(c) 2003 Ralf Hoelzer"
 
 #: main.cpp:51
@@ -82,17 +82,17 @@ msgstr "Pohrana sličica"
 msgid "Sweeps without user interaction"
 msgstr ""
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr ""
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr ""
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr ""
@@ -213,43 +213,43 @@ msgid "Clears the list of recently used
 msgstr ""
 "Brisanje popisa nedavno korištenih dokumenata s KDE izbornika aplikacija"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, fuzzy, kde-format
 #| msgid "General"
 msgctxt "General system content"
 msgid "General"
 msgstr "Opće"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, fuzzy, kde-format
 #| msgid "Web Browsing"
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Pregledavanje Interneta"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr ""
 "Izbrisat ćete podatke koji imaju potencijalnu vrijednost. Jeste li sigurni?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Započinjanje čišćenja …"
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Čišćenje %1 …"
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, fuzzy, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Čišćenje %1 nije uspjelo"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Čišćenje je završeno"
diff -pruN 4:18.04.1-1/po/hu/sweeper.po 4:20.04.1-0ubuntu1/po/hu/sweeper.po
--- 4:18.04.1-1/po/hu/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/hu/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -4,8 +4,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: KDE 4.3\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
 "PO-Revision-Date: 2011-04-29 17:58+0200\n"
 "Last-Translator: Tamas Krutki <negusnyul@gmail.com>\n"
 "Language-Team: Hungarian <kde-lista@sophia.jpte.hu>\n"
@@ -37,8 +37,9 @@ msgid "Helps clean unwanted traces the u
 msgstr "Eltávolítja a nem kívánt személyes fájlokat a rendszerből."
 
 #: main.cpp:47
-#, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+#, fuzzy, kde-format
+#| msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "(c) Ralf Hoelzer, 2003-2005."
 
 #: main.cpp:51
@@ -76,17 +77,17 @@ msgstr "Villámnézeti gyorsítótár"
 msgid "Sweeps without user interaction"
 msgstr "Felhasználói beavatkozás nélkül töröl"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Nem sikerült eltávolítani egy villámnézetet."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "A fájl létezik, de nem sikerült eltávolítani."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Nem sikerült eltávolítani egy favikont."
@@ -199,19 +200,19 @@ msgstr "A nemrég használt alkalmazáso
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "A nemrég használt alkalmazások listája a KDE menüben"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Általános"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Webböngészés"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
@@ -219,22 +220,22 @@ msgstr ""
 "Olyan adatok törlésére készül, amelyek értékes információkat "
 "tartalmazhatnak. Biztosan ezt szeretné?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "A törlés megkezdése..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "%1 törlése..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "%1 törlése nem sikerült: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Az adatok törlése befejeződött."
diff -pruN 4:18.04.1-1/po/ia/sweeper.po 4:20.04.1-0ubuntu1/po/ia/sweeper.po
--- 4:18.04.1-1/po/ia/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/ia/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -1,20 +1,20 @@
 # Copyright (C) YEAR This_file_is_part_of_KDE
 # This file is distributed under the same license as the PACKAGE package.
 #
-# g.sora <g.sora@tiscali.it>, 2012, 2013.
+# g.sora <g.sora@tiscali.it>, 2012, 2013, 2019.
 msgid ""
 msgstr ""
 "Project-Id-Version: \n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2013-05-16 10:27+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-12-22 21:42+0100\n"
 "Last-Translator: Giovanni Sora <g.sora@tiscali.it>\n"
-"Language-Team: Interlingua <kde-l10n-ia@kde.org>\n"
+"Language-Team: Interlingua <kde-i18n-doc@kde.org>\n"
 "Language: ia\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 1.5\n"
+"X-Generator: Lokalize 2.0\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 
 #, kde-format
@@ -39,7 +39,7 @@ msgstr "Il adjuta nettar tracias non vol
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "(c)2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
@@ -77,17 +77,17 @@ msgstr "Cache de miniatura"
 msgid "Sweeps without user interaction"
 msgstr "Il scopa sin interaction de usator"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Un miniatura non pote esser removite"
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Le file existe ma il non pote esser removite"
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Un favicon non pote esser removite"
@@ -205,40 +205,40 @@ msgstr "Netta Applicationes recente"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Il netta le lista de applicationes usate recentemente ex menu de KDE"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "General"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Navigation Web"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "Tu es delente datos que pote esser de valor pro te. Tu es secur?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Initiante nettamento..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Nettante %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Nettamento de %1 falleva %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Nettamento terminava"
diff -pruN 4:18.04.1-1/po/id/sweeper.po 4:20.04.1-0ubuntu1/po/id/sweeper.po
--- 4:18.04.1-1/po/id/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/id/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -1,22 +1,22 @@
 # Copyright (C) YEAR This_file_is_part_of_KDE
 # This file is distributed under the same license as the PACKAGE package.
 # Dirgita <dirgitadevina@yahoo.co.id>, 2010.
-# Wantoyo <wantoyek@gmail.com>, 2017, 2018.
+# Wantoyo <wantoyek@gmail.com>, 2017, 2018, 2019.
 #
 msgid ""
 msgstr ""
 "Project-Id-Version: \n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2018-04-03 06:37+0700\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-11-05 19:29+0700\n"
 "Last-Translator: Wantoyo <wantoyek@gmail.com>\n"
 "Language-Team: Indonesian <kde-i18n-doc@kde.org>\n"
 "Language: id\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"Plural-Forms: nplurals=1; plural=0;\n"
-"X-Generator: Lokalize 2.0\n"
+"Plural-Forms: nplurals=2; plural=(n != 1);\n"
+"X-Generator: Lokalize 19.08.1\n"
 
 #, kde-format
 msgctxt "NAME OF TRANSLATORS"
@@ -42,8 +42,9 @@ msgstr ""
 "pengguna."
 
 #: main.cpp:47
-#, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+#, fuzzy, kde-format
+#| msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "(c) 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
@@ -74,24 +75,24 @@ msgstr "Benjamin Meyer"
 #: main.cpp:53 privacyfunctions.h:68
 #, kde-format
 msgid "Thumbnail Cache"
-msgstr "Singgahan Ikon Miniatur (Thumbnail)"
+msgstr "Cache Gambar-mini"
 
 #: main.cpp:61
 #, kde-format
 msgid "Sweeps without user interaction"
 msgstr ""
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
-msgstr "Ikon miniatur tidak akan dibuang."
+msgstr "Sebuah gambar-mini tidak dapat dibuang."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Filenya ada, tetapi tidak akan dibuang."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Favicon tidak akan dibuang."
@@ -120,22 +121,22 @@ msgstr ""
 #: privacyfunctions.h:58
 #, kde-format
 msgid "Saved Clipboard Contents"
-msgstr "Isi Papan Klip yang Tersimpan"
+msgstr "Isi Papan-klip yang Tersimpan"
 
 #: privacyfunctions.h:59
 #, kde-format
 msgid "Clears the clipboard contents stored by Klipper"
-msgstr "Membersihkan isi papan klip yang disimpan oleh Klipper"
+msgstr "Membersihkan konten papan-klip yang disimpan oleh Klipper"
 
 #: privacyfunctions.h:69
 #, kde-format
 msgid "Clears all cached thumbnails"
-msgstr "Membersihkan semua singgahan ikon miniatur"
+msgstr "Membersihkan semua cache gambar-mini"
 
 #: privacyfunctions.h:78
 #, kde-format
 msgid "Run Command History"
-msgstr "Riwayat Menjalankan Perintah"
+msgstr "Histori Perintah Jalan"
 
 #: privacyfunctions.h:79
 #, kde-format
@@ -143,7 +144,7 @@ msgid ""
 "Clears the history of commands run through the Run Command tool on the "
 "desktop"
 msgstr ""
-"Membersihkan riwayat perintah yang pernah dijalankan melalui aplikasi "
+"Membersihkan histori perintah yang pernah dijalankan melalui aplikasi "
 "Jalankan Perintah dari desktop"
 
 #: privacyfunctions.h:88
@@ -159,34 +160,33 @@ msgstr "Membersihkan nilai-nilai yang pe
 #: privacyfunctions.h:98
 #, kde-format
 msgid "Web History"
-msgstr "Riwayat Web"
+msgstr "Histori Web"
 
 #: privacyfunctions.h:99
 #, kde-format
 msgid "Clears the history of visited websites"
-msgstr "Membersihkan riwayat situs web yang pernah dikunjungi"
+msgstr "Membersihkan histori situs web yang pernah dikunjungi"
 
 #: privacyfunctions.h:108
 #, kde-format
 msgid "Web Cache"
-msgstr "Singgahan Web"
+msgstr "Cache Web"
 
 #: privacyfunctions.h:109
 #, kde-format
 msgid "Clears the temporary cache of websites visited"
-msgstr "Membersihkan singgahan temporer dari situs web yang pernah dikunjungi"
+msgstr "Membersihkan cache temporer dari situs web yang pernah dikunjungi"
 
 #: privacyfunctions.h:118
 #, kde-format
 msgid "Recent Documents"
-msgstr "Dokumen yang Baru-baru Ini Dibuka"
+msgstr "Dokumen Baru-baru ini"
 
 #: privacyfunctions.h:119
 #, kde-format
 msgid ""
 "Clears the list of recently used documents from the KDE applications menu"
-msgstr ""
-"Membersihkan daftar dokumen yang baru-baru ini dibuka dari menu aplikasi KDE"
+msgstr "Membersihkan daftar dokumen yang barusan dibuka dari menu aplikasi KDE"
 
 #: privacyfunctions.h:128
 #, kde-format
@@ -197,54 +197,54 @@ msgstr "Ikon Favorit"
 #, kde-format
 msgid "Clears the FavIcons cached from visited websites"
 msgstr ""
-"Membersihkan singgahan ikon favorit (favicons) dari situs web yang pernah "
+"Membersihkan cache ikon favorit (favicons) dari situs web yang pernah "
 "dikunjungi"
 
 #: privacyfunctions.h:138
 #, kde-format
 msgid "Recent Applications"
-msgstr "Aplikasi yang Baru-baru ini Dipakai"
+msgstr "Aplikasi Baru-baru ini"
 
 #: privacyfunctions.h:139
 #, kde-format
 msgid "Clears the list of recently used applications from KDE menu"
-msgstr "Membersihkan daftar aplikasi yang baru-baru ini dipakai dari menu KDE"
+msgstr "Membersihkan daftar aplikasi yang barusan digunakan dari menu KDEbe"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Umum"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Penelusuran Web"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr ""
 "Anda akan menghapus data yang mungkin saja penting. Yakin untuk dihapus?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Mulai pembersihan..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Membersihkan %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Pembersihan %1 gagal: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Pembersihan selesai."
@@ -263,7 +263,7 @@ msgstr ""
 #: sweeperdialog.ui:37
 #, kde-format
 msgid "Privacy Settings"
-msgstr "Setelan Privasi"
+msgstr "Pengaturan Privasi"
 
 #. i18n: ectx: property (text), widget (QTreeWidget, privacyListView)
 #: sweeperdialog.ui:42
diff -pruN 4:18.04.1-1/po/is/sweeper.po 4:20.04.1-0ubuntu1/po/is/sweeper.po
--- 4:18.04.1-1/po/is/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/is/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -9,8 +9,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
 "PO-Revision-Date: 2010-05-31 12:30+0000\n"
 "Last-Translator: Sveinn í Felli <sveinki@nett.is>\n"
 "Language-Team: Icelandic <kde-isl@molar.is>\n"
@@ -47,8 +47,9 @@ msgstr ""
 "kerfinu."
 
 #: main.cpp:47
-#, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+#, fuzzy, kde-format
+#| msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "(c) 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
@@ -86,17 +87,17 @@ msgstr "Smámynda skyndiminni"
 msgid "Sweeps without user interaction"
 msgstr "Hreinsar án þess að notandinn þurfi að skipta sér af"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Ekki tókst að fjarlægja smámynd."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Skráin er til en var ekki hægt að fjarlægja."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Ekki tókst að fjarlægja veftáknmynd."
@@ -211,19 +212,19 @@ msgstr "Nýleg forrit"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Hreinsar lista yfir nýlega opnuð skjöl úr KDE forritavalmyndinni"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Almennt"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Vefskoðun"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
@@ -231,22 +232,22 @@ msgstr ""
 "Þú ert í þann mund að eyða gögnum sem eru þér mögulega einhvers virði.  Ertu "
 "viss?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Hef hreinsun..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Hreinsa %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Gat ekki hreinsað %1: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Hreinsun lokið."
diff -pruN 4:18.04.1-1/po/it/sweeper.po 4:20.04.1-0ubuntu1/po/it/sweeper.po
--- 4:18.04.1-1/po/it/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/it/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -1,22 +1,24 @@
 # translation of sweeper.po to Italian
 # Copyright (C) YEAR This_file_is_part_of_KDE
 # This file is distributed under the same license as the PACKAGE package.
-#
 # Federico Zenith <federico.zenith@member.fsf.org>, 2007.
 # Nicola Ruggero <nicola@nxnt.org>, 2008, 2009, 2010.
+# Pino Toscano <toscano.pino@tiscali.it>, 2019.
+#
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2010-07-26 10:24+0200\n"
-"Last-Translator: Nicola Ruggero <nicola@nxnt.org>\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-07-27 18:13+0100\n"
+"Last-Translator: Pino Toscano <toscano.pino@tiscali.it>\n"
 "Language-Team: Italian <kde-i18n-it@kde.org>\n"
 "Language: it\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
+"X-Generator: Lokalize 2.0\n"
 
 #, kde-format
 msgctxt "NAME OF TRANSLATORS"
@@ -41,7 +43,7 @@ msgstr ""
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "© 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
@@ -79,17 +81,17 @@ msgstr "Cache delle miniature"
 msgid "Sweeps without user interaction"
 msgstr "Pulisci senza interazione con l'utente"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Impossibile rimuovere una miniatura."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Il file esiste ma non è stato possibile rimuoverlo."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Impossibile rimuovere l'icona di un sito Web."
@@ -206,40 +208,40 @@ msgstr "Applicazioni recenti"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Ripulisce l'elenco delle applicazioni usate di recente dal menu di KDE"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Generale"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Navigazione nel Web"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "Stai eliminando dati che ti possono essere di valore. Sei sicuro?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Avvio pulizia..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Pulizia di %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Pulizia di %1 non riuscita: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Pulizia conclusa."
diff -pruN 4:18.04.1-1/po/ja/sweeper.po 4:20.04.1-0ubuntu1/po/ja/sweeper.po
--- 4:18.04.1-1/po/ja/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/ja/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -8,8 +8,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
 "PO-Revision-Date: 2008-04-13 20:00+0900\n"
 "Last-Translator: Yukiko Bando <ybando@k6.dion.ne.jp>\n"
 "Language-Team: Japanese <kde-jp@kde.org>\n"
@@ -43,8 +43,9 @@ msgid "Helps clean unwanted traces the u
 msgstr "ユーザがシステム上に残す不要な痕跡を消去します。"
 
 #: main.cpp:47
-#, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+#, fuzzy, kde-format
+#| msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "(c) 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
@@ -82,17 +83,17 @@ msgstr "サムネイルのキャッシ
 msgid "Sweeps without user interaction"
 msgstr ""
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "サムネイルを削除できませんでした。"
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "ファイルは存在しますが、削除できませんでした。"
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "ファビコンを削除できませんでした。"
@@ -207,19 +208,19 @@ msgstr "最近使用したアプリケ
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "最近使用したアプリケーションのリストを KDE のメニューから消去します"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "全般"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "ウェブ閲覧"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
@@ -227,22 +228,22 @@ msgstr ""
 "場合によってはあなたにとって貴重なデータを削除しようとしています。本当によろ"
 "しいですか？"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "クリーンアップ開始..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "%1を消去..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "%1の消去に失敗しました: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "クリーンアップが完了しました。"
diff -pruN 4:18.04.1-1/po/kk/sweeper.po 4:20.04.1-0ubuntu1/po/kk/sweeper.po
--- 4:18.04.1-1/po/kk/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/kk/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -5,8 +5,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
 "PO-Revision-Date: 2010-07-07 06:12+0600\n"
 "Last-Translator: Sairan Kikkarin <sairan@computer.org>\n"
 "Language-Team: Kazakh <kde-i18n-doc@kde.org>\n"
@@ -39,8 +39,9 @@ msgid "Helps clean unwanted traces the u
 msgstr "Пайдаланушының жүйедегі қалдырылған керегі жоқ іздерін тазалау құралы."
 
 #: main.cpp:47
-#, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+#, fuzzy, kde-format
+#| msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "(c) 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
@@ -78,17 +79,17 @@ msgstr "Нобай суреттер кэ
 msgid "Sweeps without user interaction"
 msgstr "Пайдаланушының қатысусыз тазалау"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Нобай кетіруге келмейді."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Файл бар, бірақ кетруге келмейді."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "favicon кетіруге келмейді."
@@ -203,40 +204,40 @@ msgstr "Жуырдағы қолданб
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "KDE мәзіріндегі жуырда жеккен бағдарламаларың тізімін тазалау"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Жалпы"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Вебті ақтару"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "Пайдалы болуы мүмкін деректер өшіруде. Өшірле берсін бе?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Тазалауды бастау..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "%1 дегенді тазалау..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "%1 дегенді тазалау жаңылысы: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Тазалау аяқталды"
diff -pruN 4:18.04.1-1/po/km/sweeper.po 4:20.04.1-0ubuntu1/po/km/sweeper.po
--- 4:18.04.1-1/po/km/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/km/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -7,8 +7,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
 "PO-Revision-Date: 2012-07-10 16:53+0700\n"
 "Last-Translator: sutha <sutha@khmeros.info>\n"
 "Language-Team: Khmer <support@khmeros>\n"
@@ -43,8 +43,9 @@ msgid "Helps clean unwanted traces the u
 msgstr "ជំនួយ​ដាន​ដែល​មិន​ចង់​សម្អាត អ្នក​ប្រើ​ទុក​នៅ​លើ​ប្រទុក ។"
 
 #: main.cpp:47
-#, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+#, fuzzy, kde-format
+#| msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "រក្សាសិទ្ធិ​ឆ្នាំ ២០០៣-២០០៥ ដោយ Ralf Hoelzer"
 
 #: main.cpp:51
@@ -82,17 +83,17 @@ msgstr "ឃ្លាំង​​រូ
 msgid "Sweeps without user interaction"
 msgstr "Sweeps ​មិន​ចាំបាច់​អន្តរកម្ម​អ្នក​ប្រើ"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "មិន​អាច​យក​រូបភាព​តូច​​ចេញ​បាន​ទេ ។"
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "មាន​ឯកសារ ប៉ុន្តែ​មិន​អាច​យក​ចេញ​បាន​ទេ ។"
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "មិន​អាច​យក favicon ចេញ​បាន​ទេ ។"
@@ -205,40 +206,40 @@ msgstr "កម្មវិធី​ថ
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "សម្អាត​បញ្ជី​ឯកសារ​ដែល​ប្រើ​ថ្មីៗ​នេះ ពី​ម៉ឺនុយ​កម្មវិធី KDE"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "ទូទៅ"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "ការ​រុករក​បណ្ដាញ"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "អ្នក​កំពុង​លុប​ទិន្នន័យ​ដែល​មាន​តម្លៃ​យ៉ាង​ខ្លាំង​ចំពោះ​អ្នក ។ តើ​អ្នក​ច្បាស់​ហើយ​ឬ  ?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "កំពុង​ចាប់ផ្ដើម​សម្អាត..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "កំពុង​សម្អាត %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "ការ​សម្អាត %1 បាន​បរាជ័យ ៖ %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "បាន​បញ្ចប់​ការ​សម្អាត ។"
diff -pruN 4:18.04.1-1/po/ko/sweeper.po 4:20.04.1-0ubuntu1/po/ko/sweeper.po
--- 4:18.04.1-1/po/ko/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/ko/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -1,26 +1,27 @@
 # Translation of sweeper to Korean.
 # Copyright (C) 2007 This_file_is_part_of_KDE
 # This file is distributed under the same license as the kdeutils package.
+# Shinjo Park <kde@peremen.name>, 2007, 2009, 2010, 2019, 2020.
 #
-# Shinjo Park <kde@peremen.name>, 2007, 2009, 2010.
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2010-07-05 23:55+0900\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2020-04-05 12:54+0200\n"
 "Last-Translator: Shinjo Park <kde@peremen.name>\n"
-"Language-Team: Korean <cho.sungjae@gmail.com>\n"
+"Language-Team: Korean <kde-kr@kde.org>\n"
 "Language: ko\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=1; plural=0;\n"
+"X-Generator: Lokalize 19.04.3\n"
 
 #, kde-format
 msgctxt "NAME OF TRANSLATORS"
 msgid "Your names"
-msgstr "Shinjo Park"
+msgstr "박신조"
 
 #, kde-format
 msgctxt "EMAIL OF TRANSLATORS"
@@ -39,8 +40,8 @@ msgstr "시스템에 남아 있는 사
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
-msgstr "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
+msgstr "© 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
 #, kde-format
@@ -77,17 +78,17 @@ msgstr "미리 보기 그림 캐시"
 msgid "Sweeps without user interaction"
 msgstr "사용자 입력 없이 실행하기"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "미리 보기 그림을 삭제할 수 없습니다."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "파일이 존재하지만 삭제할 수 없었습니다."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "파비콘을 삭제할 수 없습니다."
@@ -137,7 +138,7 @@ msgstr "실행 명령 기록"
 msgid ""
 "Clears the history of commands run through the Run Command tool on the "
 "desktop"
-msgstr "데스크톱의 실행 명령에서 사용한 명령의 기록을 삭제합니다"
+msgstr "바탕 화면의 실행 명령에서 사용한 명령의 기록을 삭제합니다"
 
 #: privacyfunctions.h:88
 #, kde-format
@@ -200,41 +201,41 @@ msgstr "최근 프로그램"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "KDE 메뉴에서 최근에 사용되었던 프로그램 목록을 삭제합니다"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "일반"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "웹 브라우징"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr ""
 "나중에 가치가 있을 수도 있는 데이터를 삭제하려고 합니다. 계속하시겠습니까?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "청소 중..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "%1 청소 중..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "%1 청소 실패: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "청소가 완료되었습니다."
@@ -246,8 +247,8 @@ msgid ""
 "Check all cleanup actions you would like to perform. These will be executed "
 "by pressing the button below."
 msgstr ""
-"청소하고 싶은 항목들을 모두 선택하십시오. 아래에 있는 단추를 누르면 청소를 시"
-"작합니다."
+"청소하고 싶은 항목을 모두 선택하십시오. 아래에 있는 단추를 누르면 청소를 시작"
+"합니다."
 
 #. i18n: ectx: property (text), widget (QTreeWidget, privacyListView)
 #: sweeperdialog.ui:37
diff -pruN 4:18.04.1-1/po/lt/sweeper.po 4:20.04.1-0ubuntu1/po/lt/sweeper.po
--- 4:18.04.1-1/po/lt/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/lt/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -6,9 +6,9 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2012-08-05 00:44+0300\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2020-02-22 13:52+0200\n"
 "Last-Translator: Liudas Ališauskas <liudas.alisauskas@gmail.com>\n"
 "Language-Team: Lithuanian <kde-i18n-lt@kde.org>\n"
 "Language: lt\n"
@@ -17,34 +17,34 @@ msgstr ""
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=4; plural=(n==1 ? 0 : n%10>=2 && (n%100<10 || n"
 "%100>=20) ? 1 : n%10==0 || (n%100>10 && n%100<20) ? 2 : 3);\n"
-"X-Generator: Lokalize 1.5\n"
+"X-Generator: Poedit 2.2.4\n"
 
 #, kde-format
 msgctxt "NAME OF TRANSLATORS"
 msgid "Your names"
-msgstr "Darius Žitkevičius,Liudas Ališauskas"
+msgstr "Darius Žitkevičius, Liudas Ališauskas, Moo"
 
 #, kde-format
 msgctxt "EMAIL OF TRANSLATORS"
 msgid "Your emails"
-msgstr "skystis@splius.lt,liudas@akmc.lt"
+msgstr "skystis@splius.lt,liudas@akmc.lt, <>"
 
 #: main.cpp:43
 #, kde-format
 msgid "Sweeper"
-msgstr "Sweeper"
+msgstr "Išvalymo įrankis"
 
 #: main.cpp:45
 #, kde-format
 msgid "Helps clean unwanted traces the user leaves on the system."
 msgstr ""
-"Padeda išvalyti nepageidaujamus pėdsakus, kuriuos palieka naudotojas "
+"Padeda išvalyti nepageidaujamus pėdsakus, kuriuos naudotojas palieka "
 "sistemoje."
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
-msgstr "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
+msgstr "© 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
 #, kde-format
@@ -74,62 +74,62 @@ msgstr "Benjamin Meyer"
 #: main.cpp:53 privacyfunctions.h:68
 #, kde-format
 msgid "Thumbnail Cache"
-msgstr "Miniatiūrų talpykla (cache)"
+msgstr "Miniatiūrų podėlis"
 
 #: main.cpp:61
 #, kde-format
 msgid "Sweeps without user interaction"
-msgstr "Išvalo be naudotojo įsiterpimo"
+msgstr "Išvalo be naudotojo sąveikos"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
-msgstr "Miniatiūra negalėjo būti pašalinta."
+msgstr "Nepavyko pašalinti miniatiūros."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
-msgstr "Failas egzistuoja, bet negalėjo būti pašalintas."
+msgstr "Failas yra, tačiau nepavyko jo pašalinti."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
-msgstr "Piktograma negalėjo būti pašalinta."
+msgstr "Nepavyko pašalinti svetainės piktogramos."
 
 #: privacyfunctions.h:37
 #, kde-format
 msgid "Cookies"
-msgstr "Sausainukai"
+msgstr "Slapukai"
 
 #: privacyfunctions.h:38
 #, kde-format
 msgid "Clears all stored cookies set by websites"
-msgstr "Pašalina visus išsaugotus svetainių sausainukus"
+msgstr "Išvalo visus laikomus internetinių svetainių nustatytus slapukus"
 
 #: privacyfunctions.h:48
 #, kde-format
 msgid "Cookie Policies"
-msgstr "Sausainukų taisyklės"
+msgstr "Slapukų politikos"
 
 #: privacyfunctions.h:49
 #, kde-format
 msgid "Clears the cookie policies for all visited websites"
-msgstr "Išvalo visų aplankytų svetainių slapukų taisykles"
+msgstr "Išvalo visų aplankytų internetinių svetainių slapukų politikas"
 
 #: privacyfunctions.h:58
 #, kde-format
 msgid "Saved Clipboard Contents"
-msgstr "Išsaugotas talpyklės turinys"
+msgstr "Įrašytas iškarpinės turinys"
 
 #: privacyfunctions.h:59
 #, kde-format
 msgid "Clears the clipboard contents stored by Klipper"
-msgstr "Išvalo talpyklės turinį, saugomą Klipper"
+msgstr "Išvalo Klipper laikomą iškarpinės turinį"
 
 #: privacyfunctions.h:69
 #, kde-format
 msgid "Clears all cached thumbnails"
-msgstr "Pašalina visas talpykloje esančias miniatiūras–"
+msgstr "Išvalo visas podėlyje esančias miniatiūras"
 
 #: privacyfunctions.h:78
 #, kde-format
@@ -142,8 +142,8 @@ msgid ""
 "Clears the history of commands run through the Run Command tool on the "
 "desktop"
 msgstr ""
-"Išvalo komandų istoriją, kurios buvo įvestos „Vykdyti komandą“ įrankio "
-"pagalba darbastalyje"
+"Išvalo komandų, kurios buvo paleistos naudojant „Vykdyti komandą“ įrankį "
+"darbalaukyje, istoriją"
 
 #: privacyfunctions.h:88
 #, kde-format
@@ -153,97 +153,96 @@ msgstr "Formų užbaigimo įrašai"
 #: privacyfunctions.h:89
 #, kde-format
 msgid "Clears values which were entered into forms on websites"
-msgstr "Išvalo formų turinį, kurias pildėte Interneto svetainėse"
+msgstr "Išvalo reikšmes, kurios buvo įvestos internetinių svetainių formose"
 
 #: privacyfunctions.h:98
 #, kde-format
 msgid "Web History"
-msgstr "Interneto istorija"
+msgstr "Saityno istorija"
 
 #: privacyfunctions.h:99
 #, kde-format
 msgid "Clears the history of visited websites"
-msgstr "Išvalo aplankytų svetainių istoriją"
+msgstr "Išvalo aplankytų internetinių svetainių istoriją"
 
 #: privacyfunctions.h:108
 #, kde-format
 msgid "Web Cache"
-msgstr "Interneto talpykla"
+msgstr "Saityno podėlis"
 
 #: privacyfunctions.h:109
 #, kde-format
 msgid "Clears the temporary cache of websites visited"
-msgstr "Išvalo laikiną aplankytų svetainių talpyklą"
+msgstr "Išvalo aplankytų internetinių svetainių laikinąjį podėlį"
 
 #: privacyfunctions.h:118
 #, kde-format
 msgid "Recent Documents"
-msgstr "Paskutiniai dokumentai"
+msgstr "Paskiausiai naudoti dokumentai"
 
 #: privacyfunctions.h:119
 #, kde-format
 msgid ""
 "Clears the list of recently used documents from the KDE applications menu"
-msgstr "Išvalo iš KDE programų meniu paskutinių naudotų dokumentų sąrašą"
+msgstr "Išvalo paskiausiai naudotų dokumentų sąrašą iš KDE programų meniu"
 
 #: privacyfunctions.h:128
 #, kde-format
 msgid "Favorite Icons"
-msgstr "Žymelių ženkliukai"
+msgstr "Svetainių piktogramos"
 
 #: privacyfunctions.h:129
 #, kde-format
 msgid "Clears the FavIcons cached from visited websites"
-msgstr "Išvalo talpykloje esančias aplankytų svetainių ikonas"
+msgstr "Išvalo aplankytų internetinių svetainių piktogramų podėlį"
 
 #: privacyfunctions.h:138
 #, kde-format
 msgid "Recent Applications"
-msgstr "Paskiausios programos"
+msgstr "Paskiausiai naudotojos programos"
 
 #: privacyfunctions.h:139
 #, kde-format
 msgid "Clears the list of recently used applications from KDE menu"
-msgstr "Išvalo iš KDE programų meniu paskutinių naudotų dokumentų sąrašą"
+msgstr "Išvalo paskiausiai naudotų programų sąrašą iš KDE meniu"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Bendri"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
-msgstr "Žiniatinklio naršymas"
+msgstr "Naršymas saityne"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
-msgstr ""
-"Jūs naikinate duomenis, kurie gali būti jums reikalingi. Aš Jūs įsitikinęs?"
+msgstr "Ištrinate galimai jums vertingus duomenis. Aš esate tikri?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
-msgstr "Pradedamas valymas..."
+msgstr "Pradedamas išvalymas..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
-msgstr "Valoma %1..."
+msgstr "Išvaloma %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
-msgstr "%1 valymas nepavyko: %2"
+msgstr "%1 išvalymas nepavyko: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
-msgstr "Valymas užbaigtas."
+msgstr "Išvalymas užbaigtas."
 
 #. i18n: ectx: property (whatsThis), widget (QTreeWidget, privacyListView)
 #: sweeperdialog.ui:27
@@ -252,20 +251,20 @@ msgid ""
 "Check all cleanup actions you would like to perform. These will be executed "
 "by pressing the button below."
 msgstr ""
-"Nurodykite kokius valymo veiksmus norite atlikti. Jie bus įvykdyti paspaudus "
-"mygtuką žemiau."
+"Pažymėkite visus norimus atlikti išvalymo veiksmus. Jie bus įvykdyti "
+"paspaudus žemiau esantį mygtuką."
 
 #. i18n: ectx: property (text), widget (QTreeWidget, privacyListView)
 #: sweeperdialog.ui:37
 #, kde-format
 msgid "Privacy Settings"
-msgstr "Privatumo nustatymai"
+msgstr "Privatumo nuostatos"
 
 #. i18n: ectx: property (text), widget (QTreeWidget, privacyListView)
 #: sweeperdialog.ui:42
 #, kde-format
 msgid "Description"
-msgstr "Aprašymas"
+msgstr "Aprašas"
 
 #. i18n: ectx: property (text), widget (QPushButton, selectAllButton)
 #: sweeperdialog.ui:58
@@ -277,16 +276,16 @@ msgstr "Pažymėti &viską"
 #: sweeperdialog.ui:65
 #, kde-format
 msgid "Select &None"
-msgstr "Nieko nežymėti"
+msgstr "Nieko &nežymėti"
 
 #. i18n: ectx: property (whatsThis), widget (QPushButton, cleanupButton)
 #: sweeperdialog.ui:88
 #, kde-format
 msgid "Immediately performs the cleanup actions selected above"
-msgstr "Nedelsiant įvykdys visus valymo veiksmus, kurie pažymėti aukščiau"
+msgstr "Nedelsiant įvykdo aukščiau pažymėtus išvalymo veiksmus"
 
 #. i18n: ectx: property (text), widget (QPushButton, cleanupButton)
 #: sweeperdialog.ui:91
 #, kde-format
 msgid "&Clean Up"
-msgstr "&Valyti"
+msgstr "Iš&valyti"
diff -pruN 4:18.04.1-1/po/lv/sweeper.po 4:20.04.1-0ubuntu1/po/lv/sweeper.po
--- 4:18.04.1-1/po/lv/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/lv/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -9,8 +9,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
 "PO-Revision-Date: 2009-06-07 20:54+0300\n"
 "Last-Translator: Viesturs Zariņš <viesturs.zarins@mii.lu.lv>\n"
 "Language-Team: Latvian <locale@laka.lv>\n"
@@ -43,8 +43,9 @@ msgid "Helps clean unwanted traces the u
 msgstr "Palīdz notīrīt nevajadzīgās pēdas sistēmā, kuras atstāj lietotājs."
 
 #: main.cpp:47
-#, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+#, fuzzy, kde-format
+#| msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "(c) 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
@@ -82,17 +83,17 @@ msgstr "Sīktēlu kešatmiņa"
 msgid "Sweeps without user interaction"
 msgstr ""
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Nevarēja noņemt sīktēlu."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Fails eksistē, bet nevar noņemt."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Nevar noņemt favicon."
@@ -208,40 +209,40 @@ msgstr "Nesenās lietotnes"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Notīra sarakstu ar nesen izmantotajām lietotnēm no KDE izvēlnes"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Pamata"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Tīmekļa pārlūkošana"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "Jūs dzēšat datus, kuri ir vērtīgi jums. Vai esat drošs?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Uzkopšanas sākšana..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "%1 attīrīšana..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Neizdevās attīrīt %1: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Attīrīšana pabeigta"
diff -pruN 4:18.04.1-1/po/mr/sweeper.po 4:20.04.1-0ubuntu1/po/mr/sweeper.po
--- 4:18.04.1-1/po/mr/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/mr/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -5,8 +5,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: \n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
 "PO-Revision-Date: 2013-03-14 15:47+0530\n"
 "Last-Translator: Chetan Khona <chetan@kompkin.com>\n"
 "Language-Team: Marathi <kde-i18n-doc@kde.org>\n"
@@ -38,8 +38,9 @@ msgid "Helps clean unwanted traces the u
 msgstr ""
 
 #: main.cpp:47
-#, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+#, fuzzy, kde-format
+#| msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "(c) 2003 - 2005, रॉल्फ हॉल्जर"
 
 #: main.cpp:51
@@ -77,17 +78,17 @@ msgstr ""
 msgid "Sweeps without user interaction"
 msgstr ""
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr ""
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr ""
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr ""
@@ -200,40 +201,40 @@ msgstr "नुकतेच वापर
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr ""
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "सामान्य"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "वेब ब्राऊजिंग"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr ""
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr ""
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr ""
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr ""
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr ""
diff -pruN 4:18.04.1-1/po/nb/sweeper.po 4:20.04.1-0ubuntu1/po/nb/sweeper.po
--- 4:18.04.1-1/po/nb/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/nb/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -6,11 +6,11 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
 "PO-Revision-Date: 2010-06-10 15:17+0200\n"
 "Last-Translator: Bjørn Steensrud <bjornst@skogkatt.homelinux.org>\n"
-"Language-Team: Norwegian Bokmål <i18n-nb@lister.ping.uio.no>\n"
+"Language-Team: Norwegian Bokmål <l10n-no@lister.huftis.org>\n"
 "Language: nb\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
@@ -44,8 +44,8 @@ msgstr ""
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
-msgstr "© 2003–2005 Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
+msgstr ""
 
 #: main.cpp:51
 #, kde-format
@@ -82,17 +82,17 @@ msgstr "Mellomlager for minibilder"
 msgid "Sweeps without user interaction"
 msgstr "Feier uten brukers medvirkning"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Et minibilde kunne ikke fjernes."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Fila finnes, men kunne ikke fjernes."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Et favorittikon kunne ikke fjernes."
@@ -207,40 +207,40 @@ msgstr "Nylig brukte programmer"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Tømmer lista over nylig brukte programmer fra KDE-menyen"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Generelt"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Nettlesing"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "Du er i ferd med å slette data som kan ha verdi for deg. Er du sikker?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Begynner opprydding …"
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Tømmer %1 …"
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Tømming av %1 mislyktes: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Tømming ferdig."
diff -pruN 4:18.04.1-1/po/nds/sweeper.po 4:20.04.1-0ubuntu1/po/nds/sweeper.po
--- 4:18.04.1-1/po/nds/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/nds/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -9,8 +9,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
 "PO-Revision-Date: 2010-05-29 06:59+0200\n"
 "Last-Translator: Manfred Wiese <m.j.wiese@web.de>\n"
 "Language-Team: Low Saxon <kde-i18n-nds@kde.org>\n"
@@ -44,8 +44,9 @@ msgstr ""
 "dat wüllt."
 
 #: main.cpp:47
-#, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+#, fuzzy, kde-format
+#| msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "© 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
@@ -83,17 +84,17 @@ msgstr "Vöransichten-Twischenspieker"
 msgid "Sweeps without user interaction"
 msgstr "Ahn Bruker-Nafraag schier maken"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "En Vöransicht lett sik nich wegmaken."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Dat gifft de Datei, man se lett sik nich wegmaken."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "En Nettsiet-Lüttbild lett sik nich wegmaken."
@@ -209,19 +210,19 @@ msgstr "Tolest bruukt Programmen"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Maakt de List vun tolest bruukt Programmen in't KDE-Menü leddig"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Allgemeen"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Nettkieken"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
@@ -229,22 +230,22 @@ msgstr ""
 "Du wullt Daten wegdoon, de villicht doch noch bruukst. Wullt Du redig "
 "wiedermaken?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Oprümen fangt an..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "%1 warrt wegdaan..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Dat Wegdoon vun \"%1\" is fehlslaan: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Oprümen is beendt."
diff -pruN 4:18.04.1-1/po/nl/sweeper.po 4:20.04.1-0ubuntu1/po/nl/sweeper.po
--- 4:18.04.1-1/po/nl/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/nl/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -10,20 +10,20 @@
 # Rinse de Vries <rinsedevries@kde.nl>, 2004, 2005, 2007.
 # Kristof Bal <kristof.bal@gmail.com>, 2008.
 # Freek de Kruijf <f.de.kruijf@hetnet.nl>, 2009.
-# Freek de Kruijf <freekdekruijf@kde.nl>, 2010.
+# Freek de Kruijf <freekdekruijf@kde.nl>, 2010, 2019.
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2010-05-14 10:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-07-05 16:12+0200\n"
 "Last-Translator: Freek de Kruijf <freekdekruijf@kde.nl>\n"
 "Language-Team: Dutch <kde-i18n-nl@kde.org>\n"
 "Language: nl\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 1.0\n"
+"X-Generator: Lokalize 19.04.2\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 
 #, kde-format
@@ -50,8 +50,8 @@ msgstr ""
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
-msgstr "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
+msgstr "© 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
 #, kde-format
@@ -88,17 +88,17 @@ msgstr "Miniatuurcache"
 msgid "Sweeps without user interaction"
 msgstr "Maakt schoon zonder interactie met de gebruiker"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Een miniatuur kon niet worden verwijderd."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Het bestand bestaat maar kon niet worden verwijderd."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Een favicon kon niet worden verwijderd."
@@ -213,19 +213,19 @@ msgstr "Recente programma's"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Wist de lijst met recent gebruikte programma's in het KDE-menu"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Algemeen"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Webbrowsen"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
@@ -233,22 +233,22 @@ msgstr ""
 "U staat op het punt gegevens te verwijderen die mogelijk waardevol zijn. "
 "Wilt u doorgaan?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Schoonmaak wordt gestart..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Bezig met wissen van %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Wissen van %1 is mislukt: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Schoonmaak voltooid."
diff -pruN 4:18.04.1-1/po/nn/sweeper.po 4:20.04.1-0ubuntu1/po/nn/sweeper.po
--- 4:18.04.1-1/po/nn/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/nn/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -1,21 +1,21 @@
 # Translation of sweeper to Norwegian Nynorsk
 #
 # Gaute Hvoslef Kvalnes <gaute@verdsveven.com>, 2003, 2004, 2005.
-# Karl Ove Hufthammer <karl@huftis.org>, 2004, 2007, 2008, 2016.
+# Karl Ove Hufthammer <karl@huftis.org>, 2004, 2007, 2008, 2016, 2019.
 # Eirik U. Birkeland <eirbir@gmail.com>, 2008, 2009.
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2016-10-20 20:30+0100\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-07-17 20:47+0200\n"
 "Last-Translator: Karl Ove Hufthammer <karl@huftis.org>\n"
-"Language-Team: Norwegian Nynorsk <i18n-nn@lister.ping.uio.no>\n"
+"Language-Team: Norwegian Nynorsk <l10n-no@lister.huftis.org>\n"
 "Language: nn\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 2.0\n"
+"X-Generator: Lokalize 19.04.2\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 "X-Environment: kde\n"
 "X-Accelerator-Marker: &\n"
@@ -44,7 +44,7 @@ msgstr ""
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "© 2003–2005 Ralf Hoelzer"
 
 #: main.cpp:51
@@ -82,17 +82,17 @@ msgstr "Mellomlager for ikon"
 msgid "Sweeps without user interaction"
 msgstr "Ryddar opp utan brukarmedverknad"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Klarte ikkje fjerna miniatyrbilete."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Fila finst, men kunne ikkje fjernast."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Eit favorittikon kunne ikkje fjernast."
@@ -207,40 +207,40 @@ msgstr "Nyleg brukte program"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Slettar lista over nyleg brukte program frå KDE-programmenyen"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Generelt"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Nettlesing"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "Du er i ferd med å sletta data som kan ha verdi for deg. Er du sikker?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Byrjar opprydding …"
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Ryddar opp %1 …"
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Feil ved opprydding av %1: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Opprydding fullført."
diff -pruN 4:18.04.1-1/po/pa/sweeper.po 4:20.04.1-0ubuntu1/po/pa/sweeper.po
--- 4:18.04.1-1/po/pa/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/pa/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -2,20 +2,20 @@
 # Amanpreet Singh Alam <aalam@redhat.com>, 2004, 2005.
 # Amanpreet Singh Brar <amanpreetalam@yahoo.com>, 2005.
 # Amanpreet Singh Alam <amanpreetalam@yahoo.com>, 2005.
-# A S Alam <aalam@users.sf.net>, 2007, 2008, 2009, 2010.
+# A S Alam <aalam@users.sf.net>, 2007, 2008, 2009, 2010, 2019.
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2010-10-16 09:15+0530\n"
-"Last-Translator: A S Alam <aalam@users.sf.net>\n"
-"Language-Team: Punjabi/Panjabi <punjabi-users@lists.sf.net>\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-02-10 10:11-0800\n"
+"Last-Translator: A S Alam <alam.yellow@gmail.com>\n"
+"Language-Team: Punjabi <punjabi-users@lists.sf.net>\n"
 "Language: pa\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 1.1\n"
+"X-Generator: Lokalize 2.0\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 "\n"
 
@@ -27,7 +27,7 @@ msgstr "ਅਮਨਪਰੀਤ ਸਿੰ
 #, kde-format
 msgctxt "EMAIL OF TRANSLATORS"
 msgid "Your emails"
-msgstr "aalam@users.sf.net"
+msgstr "alam.yellow@gmail.com"
 
 #: main.cpp:43
 #, kde-format
@@ -37,11 +37,12 @@ msgstr "ਸਵੀਪਰ"
 #: main.cpp:45
 #, kde-format
 msgid "Helps clean unwanted traces the user leaves on the system."
-msgstr "ਯੂਜ਼ਰ ਵਲੋਂ ਸਿਸਟਮ ਉੱਤੇ ਅਣ-ਚਾਹੇ ਸੁਰਾਗ ਹਟਾਉਣ ਵਿੱਚ ਮੱਦਦ।"
+msgstr "ਵਰਤੋਂਕਾਰ ਵਲੋਂ ਸਿਸਟਮ ਉੱਤੇ ਅਣ-ਚਾਹੇ ਸੁਰਾਗ ਹਟਾਉਣ ਵਿੱਚ ਮਦਦ ਕਰਦਾ ਹੈ।"
 
 #: main.cpp:47
-#, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+#, fuzzy, kde-format
+#| msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "(c) 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
@@ -77,19 +78,19 @@ msgstr "ਥੰਮਨੇਲ ਕੈਂਚ
 #: main.cpp:61
 #, kde-format
 msgid "Sweeps without user interaction"
-msgstr "ਯੂਜ਼ਰ ਦੇ ਦਖਲ ਬਿਨਾਂ ਸਾਫ਼ ਕਰੋ"
+msgstr "ਵਰਤੋਂਕਾਰ ਦੇ ਦਖਲ ਬਿਨਾਂ ਸਾਫ਼ ਕਰੋ"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
-msgstr "ਇੱਕ ਥੰਮਨੇਲ ਹਟਾਇਆ ਨਹੀਂ ਜਾ ਸਕਿਆ।"
+msgstr "ਥੰਮਨੇਲ ਹਟਾਇਆ ਨਹੀਂ ਜਾ ਸਕਿਆ।"
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "ਫਾਇਲ ਮੌਜੂਦ ਹੈ, ਪਰ ਹਟਾਈ ਨਹੀਂ ਜਾ ਸਕੀ।"
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "ਇੱਕ ਫੈਵੀਕੋਨ ਹਟਾਇਆ ਨਹੀਂ ਜਾ ਸਕਿਆ।"
@@ -139,7 +140,7 @@ msgstr "ਕਮਾਂਡ ਅਤੀਤ ਚ
 msgid ""
 "Clears the history of commands run through the Run Command tool on the "
 "desktop"
-msgstr "ਵਿਹੜੇ ਵਿਚਲੇ ਚਲਾਓ ਕਮਾਂਡ ਸੰਦ ਨਾਲ ਚਲਾਈਆਂ ਕਮਾਂਡਾਂ ਦਾ ਅਤੀਤ ਖਤਮ ਹੋ ਜਾਵੇਗਾ"
+msgstr "ਡੈਸਕਟਾਪ ਵਿਚਲੇ ਚਲਾਓ ਕਮਾਂਡ ਸੰਦ ਨਾਲ ਚਲਾਈਆਂ ਕਮਾਂਡਾਂ ਦਾ ਅਤੀਤ ਖਤਮ ਹੋ ਜਾਵੇਗਾ"
 
 #: privacyfunctions.h:88
 #, kde-format
@@ -159,12 +160,12 @@ msgstr "ਵੈੱਬ ਅਤੀਤ"
 #: privacyfunctions.h:99
 #, kde-format
 msgid "Clears the history of visited websites"
-msgstr "ਖੋਲੀਆਂ ਵੈੱਬ-ਸਾਈਟਾਂ ਦਾ ਅਤੀਤ ਖਤਮ ਕਰੋ"
+msgstr "ਖੋਲ੍ਹੀਆਂ ਵੈੱਬ-ਸਾਈਟਾਂ ਦਾ ਅਤੀਤ ਖਤਮ ਕਰੋ"
 
 #: privacyfunctions.h:108
 #, kde-format
 msgid "Web Cache"
-msgstr "ਵੈੱਬ ਕੈਚੇ"
+msgstr "ਵੈੱਬ ਕੈਸ਼"
 
 #: privacyfunctions.h:109
 #, kde-format
@@ -190,7 +191,7 @@ msgstr "ਪਸੰਦੀਦਾ ਆਈਕ
 #: privacyfunctions.h:129
 #, kde-format
 msgid "Clears the FavIcons cached from visited websites"
-msgstr "ਖੋਲੀਆਂ ਸਾਇਟਾਂ ਤੋਂ ਪ੍ਰਾਪਤ ਫੈਵੀਕੋਨ ਕੂਕੀਡ ਸਾਫ਼ ਕਰੋ"
+msgstr "ਖੋਲ੍ਹੀਆਂ ਸਾਇਟਾਂ ਤੋਂ ਪ੍ਰਾਪਤ ਫੈਵੀਕੋਨ ਕੂਕੀਡ ਸਾਫ਼ ਕਰੋ"
 
 #: privacyfunctions.h:138
 #, kde-format
@@ -202,40 +203,40 @@ msgstr "ਤਾਜ਼ਾ ਐਪਲੀਕ
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "ਕੇਡੀਈ ਮੇਨੂ ਵਿੱਚੋਂ ਤਾਜ਼ਾ ਵਰਤੀਆਂ ਐਪਲੀਕੇਸ਼ਨਾਂ ਦੀ ਲਿਸਟ ਸਾਫ਼ ਕਰੋ"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "ਸਧਾਰਨ"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "ਵੈੱਬ ਬਰਾਊਜ਼ਿੰਗ"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "ਤੁਸੀਂ ਉਹ ਡਾਟਾ ਹਟਾ ਰਹੇ ਹੋ ਜਿਹੜਾ ਕਿ ਲਾਭਦਾਇਕ ਹੋ ਸਕਦਾ ਹੈ, ਕੀ ਤੁਸੀਂ ਇਸ ਲਈ ਸਹਿਮਤ ਹੋ?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
-msgstr "ਸਾਫ਼ ਕਰਨਾ ਸ਼ੁਰੂ..."
+msgstr "ਸਾਫ਼ ਕਰਨਾ ਸ਼ੁਰੂ ਕੀਤਾ ਜਾ ਰਿਹਾ ਹੈ..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "%1 ਨੂੰ ਸਾਫ ਕੀਤਾ ਜਾ ਰਿਹਾ ਹੈ..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "%1 ਨੂੰ ਸਾਫ਼ ਕਰਨਾ ਫੇਲ੍ਹ ਹੋਇਆ: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "ਸਫਾਈ ਮੁਕੰਮਲ ਹੋਈ ਹੈ।"
@@ -254,7 +255,7 @@ msgstr ""
 #: sweeperdialog.ui:37
 #, kde-format
 msgid "Privacy Settings"
-msgstr "ਨਿੱਜੀਤਵ ਸਥਾਪਨ"
+msgstr "ਪਰਦੇਦਾਰੀ ਸੈਟਿੰਗਾਂ"
 
 #. i18n: ectx: property (text), widget (QTreeWidget, privacyListView)
 #: sweeperdialog.ui:42
diff -pruN 4:18.04.1-1/po/pl/sweeper.po 4:20.04.1-0ubuntu1/po/pl/sweeper.po
--- 4:18.04.1-1/po/pl/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/pl/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -6,20 +6,20 @@
 # Michal Rudolf <mrudolf@kdewebdev.org>, 2004, 2005.
 # Krzysztof Lichota <lichota@mimuw.edu.pl>, 2005.
 # Marta Rybczyńska <kde-i18n@rybczynska.net>, 2008.
-# Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>, 2012.
+# Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>, 2012, 2019.
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2012-01-21 08:11+0100\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-07-21 10:08+0200\n"
 "Last-Translator: Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>\n"
 "Language-Team: Polish <kde-i18n-doc@kde.org>\n"
 "Language: pl\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 1.2\n"
+"X-Generator: Lokalize 19.07.70\n"
 "Plural-Forms: nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 "
 "|| n%100>=20) ? 1 : 2);\n"
 
@@ -46,8 +46,8 @@ msgstr ""
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
-msgstr "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
+msgstr "© 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
 #, kde-format
@@ -84,17 +84,17 @@ msgstr "Bufor miniaturek"
 msgid "Sweeps without user interaction"
 msgstr "Czyści bez działania użytkownika"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Miniaturka nie mogła być usunięta."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Plik istnieje, ale nie może być usunięty."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Nie można usunąć favicon."
@@ -208,40 +208,40 @@ msgstr "Ostatnie programy"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Czyści listę ostatnio używanych programów w menu KDE"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Ogólne"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Przeglądanie sieci"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "Na pewno usunąć wybrane dane?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Rozpoczęto czyszczenie..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Czyszczenie: %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Nieudane czyszczenie %1: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Czyszczenie zakończone."
diff -pruN 4:18.04.1-1/po/pt/sweeper.po 4:20.04.1-0ubuntu1/po/pt/sweeper.po
--- 4:18.04.1-1/po/pt/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/pt/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -1,9 +1,9 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: privacy\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2010-05-06 11:20+0100\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-07-05 11:46+0100\n"
 "Last-Translator: Pedro Morais <morais@kde.org>\n"
 "Language-Team: pt <kde-i18n-pt@kde.org>\n"
 "Language: pt\n"
@@ -37,8 +37,8 @@ msgstr ""
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
-msgstr "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
+msgstr "© 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
 #, kde-format
@@ -75,17 +75,17 @@ msgstr "'Cache' de Miniaturas"
 msgid "Sweeps without user interaction"
 msgstr "Limpa sem qualquer interacção do utilizador"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Não foi possível remover uma miniatura."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "O ficheiro existe mas não pode ser removido."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Não foi possível remover um 'favicon'."
@@ -202,41 +202,41 @@ msgstr "Aplicações Recentes"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Limpa a lista de aplicações usadas recentemente do menu do KDE"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Geral"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Navegação Web"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr ""
 "Você está a remover dados que poderão ser valiosos para si. Tem a certeza?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "A iniciar a limpeza..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "A limpar o %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "A limpeza do %1 foi mal-sucedida: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "A limpeza terminou."
diff -pruN 4:18.04.1-1/po/pt_BR/sweeper.po 4:20.04.1-0ubuntu1/po/pt_BR/sweeper.po
--- 4:18.04.1-1/po/pt_BR/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/pt_BR/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -1,16 +1,16 @@
 # Translation of sweeper.po to Brazilian Portuguese
-# Copyright (C) 2003, 2004, 2008, 2009, 2010, 2014 Free Software Foundation, Inc.
+# Copyright (C) 2003, 2004, 2008, 2009, 2010, 2014, 2019 Free Software Foundation, Inc.
 #
 # Lisiane Sztoltz <lisiane@conectiva.com.br>, 2003.
 # Henrique Pinto <stampede@coltec.ufmg.br>, 2003.
 # Lisiane Sztoltz Teixeira <lisiane@conectiva.com.br>, 2004.
-# André Marcelo Alvarenga <alvarenga@kde.org>, 2008, 2009, 2010, 2014.
+# André Marcelo Alvarenga <alvarenga@kde.org>, 2008, 2009, 2010, 2014, 2019.
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2014-06-28 19:34-0300\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-07-07 10:24-0300\n"
 "Last-Translator: André Marcelo Alvarenga <alvarenga@kde.org>\n"
 "Language-Team: Brazilian Portuguese <kde-i18n-pt_br@kde.org>\n"
 "Language: pt_BR\n"
@@ -18,7 +18,7 @@ msgstr ""
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n > 1);\n"
-"X-Generator: Lokalize 1.5\n"
+"X-Generator: Lokalize 19.04.2\n"
 
 #, kde-format
 msgctxt "NAME OF TRANSLATORS"
@@ -43,8 +43,8 @@ msgstr ""
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
-msgstr "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
+msgstr "© 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
 #, kde-format
@@ -81,17 +81,17 @@ msgstr "Cache de miniaturas"
 msgid "Sweeps without user interaction"
 msgstr "Limpa sem qualquer interação do usuário"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Não foi possível remover uma miniatura."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "O arquivo existe mas não pode ser excluído."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Não foi possível remover um favicon."
@@ -211,19 +211,19 @@ msgstr ""
 "Limpa a lista de aplicativos recentemente usados do menu de aplicativos do "
 "KDE"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Geral"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Navegação Web"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
@@ -231,22 +231,22 @@ msgstr ""
 "Você está excluindo dados que são potencialmente valiosos para você. Tem "
 "certeza disto?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Iniciando a limpeza..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Limpando %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "A limpeza de %1 falhou: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "A limpeza foi concluída."
diff -pruN 4:18.04.1-1/po/ro/sweeper.po 4:20.04.1-0ubuntu1/po/ro/sweeper.po
--- 4:18.04.1-1/po/ro/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/ro/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -7,8 +7,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: privacy\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
 "PO-Revision-Date: 2011-10-20 08:18+0300\n"
 "Last-Translator: Sergiu Bivol <sergiu@ase.md>\n"
 "Language-Team: Romanian <kde-i18n-ro@kde.org>\n"
@@ -41,8 +41,9 @@ msgid "Helps clean unwanted traces the u
 msgstr "Ajută la curățarea urmelor nedorite lăsate de utilizator în sistem."
 
 #: main.cpp:47
-#, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+#, fuzzy, kde-format
+#| msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "(c) 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
@@ -80,17 +81,17 @@ msgstr "Cache de mini-imagini"
 msgid "Sweeps without user interaction"
 msgstr "Mătură fără intervenția utilizatorului"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "O miniatură nu a putut fi eliminată."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Fișierul există dar nu a putut fi eliminat."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Un favicon nu a putut fi eliminat."
@@ -204,19 +205,19 @@ msgstr "Aplicații recente"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Curăță lista aplicațiilor utilizate recent din meniul KDE"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "General"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Navigare web"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
@@ -224,22 +225,22 @@ msgstr ""
 "Sînteți pe cale să ștergeți date care vă sînt probabil utile. Doriți acest "
 "lucru?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Încep curățarea..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Curăț %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Curățarea %1 a eșuat: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Curățirea s-a terminat."
diff -pruN 4:18.04.1-1/po/ru/docs/sweeper/index.docbook 4:20.04.1-0ubuntu1/po/ru/docs/sweeper/index.docbook
--- 4:18.04.1-1/po/ru/docs/sweeper/index.docbook	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/ru/docs/sweeper/index.docbook	1970-01-01 00:00:00.000000000 +0000
@@ -1,109 +0,0 @@
-<?xml version="1.0" ?>
-<!DOCTYPE article PUBLIC "-//KDE//DTD DocBook XML V4.5-Based Variant V1.1//EN" "dtd/kdedbx45.dtd" [
-  <!ENTITY % addindex "IGNORE">
-  <!ENTITY % Russian "INCLUDE">
-]>
-
-<article id="sweeper" lang="&language;">
-
-<articleinfo>
-<title
->Приложение Sweeper</title>
-<authorgroup>
-<author
->&Burkhard.Lueck; &Burkhard.Lueck.mail;</author>
-
-<othercredit role="translator"
-><firstname
->Ольга</firstname
-><surname
->Миронова</surname
-><affiliation
-><address
-><email
->omiro@basealt.ru</email
-></address
-></affiliation
-><contrib
->Перевод на русский язык</contrib
-></othercredit
-><othercredit role="reviewer"
-><firstname
->Александр</firstname
-><surname
->Яворский</surname
-><contrib
->Рецензирование</contrib
-></othercredit
-> 
-</authorgroup>
-
-<date
->2018-01-03</date>
-<releaseinfo
->1.11 (Приложения KDE 17.12)</releaseinfo>
-
-<keywordset>
-<keyword
->KDE</keyword>
-<keyword
->конфиденциальность</keyword>
-<keyword
->безопасность</keyword>
-</keywordset>
-</articleinfo>
-
-<para
->Приложение &sweeper; удаляет из системы содержимое, появившееся во время работы пользователя в окружении рабочего стола &plasma; и с приложениями &kde;, сохранение которого пользователь считает нежелательным. </para>
-
-<para>
-<screenshot>
-  <mediaobject>
-    <imageobject>
-      <imagedata fileref="sweeper.png" format="PNG"/>
-    </imageobject>
-  </mediaobject>
-</screenshot>
-</para>
-
-<para
->Для выделения и удаления всего содержимого воспользуйтесь кнопками <guibutton
->Выделить все</guibutton
-> и <guibutton
->Очистить выбор</guibutton
-> или выберите необходимые пункты в разделах <guilabel
->Общее</guilabel
-> и <guilabel
->Просмотр Интернета</guilabel
->. </para>
-
-<para
->Выберите разделы разделы личных данных для удаления и кнопку <guibutton
->Очистить</guibutton
->. Все данные, соответствующие отмеченным разделам, будут удалены. </para>
-
-<note
-><para
->Приложение удаляет кэшированные данные приложений &plasma; и приложений &kde; из папки кэша. Чтобы определить адрес этой папки, в терминале &konsole; введите команду <userinput
-><command
->qtpaths</command
-> <option
->--paths GenericCacheLocation</option
-></userinput
->. Удаление кэшированных данных с помощью &sweeper; сделает невозможным чтение этих данных такими приложениями как диспетчер файлов. Однако сохраняется возможность чтения необработанных данных, которые продолжают храниться на диске, при помощи программ, которые могут работать с диском на низком уровне. </para>
-</note>
-
-</article>
-
-<!--
-Local Variables:
-mode: xml
-sgml-minimize-attributes:nil
-sgml-general-insert-case:lower
-sgml-indent-step:0
-sgml-indent-data:nil
-End:
-
-vim:tabstop=2:shiftwidth=2:expandtab
-kate: space-indent on; indent-width 2; tab-width 2; indent-mode none;
--->
diff -pruN 4:18.04.1-1/po/ru/sweeper.po 4:20.04.1-0ubuntu1/po/ru/sweeper.po
--- 4:18.04.1-1/po/ru/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/ru/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -11,20 +11,20 @@
 # Andrey Cherepanov <skull@kde.ru>, 2009.
 # Nick Shaforostoff <shaforostoff@kde.ru>, 2009.
 # Nick Shaforostoff <shafff@ukr.net>, 2009.
-# Alexander Potashev <aspotashev@gmail.com>, 2010.
+# Alexander Potashev <aspotashev@gmail.com>, 2010, 2019.
 msgid ""
 msgstr ""
 "Project-Id-Version: privacy\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2010-08-20 18:54+0400\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-10-15 11:48+0300\n"
 "Last-Translator: Alexander Potashev <aspotashev@gmail.com>\n"
 "Language-Team: Russian <kde-russian@lists.kde.ru>\n"
 "Language: ru\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 1.1\n"
+"X-Generator: Lokalize 19.07.70\n"
 "Plural-Forms: nplurals=4; plural=n==1 ? 3 : n%10==1 && n%100!=11 ? 0 : n"
 "%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\n"
 "X-Environment: kde\n"
@@ -55,7 +55,7 @@ msgstr ""
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "© Ralf Hoelzer, 2003-2005"
 
 #: main.cpp:51
@@ -93,17 +93,17 @@ msgstr "Кэш миниатюр"
 msgid "Sweeps without user interaction"
 msgstr "Очистить без взаимодействия с пользователем"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Миниатюры не могут быть удалены."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Файл существует, но не может быть удалён"
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Значки сайтов не могут быть удалены"
@@ -216,40 +216,40 @@ msgstr "Последние прилож
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Очистить список последних используемых приложений"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Основное"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Просмотр Интернета"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "Вы удаляете данные, которые могут быть вам полезны. Продолжить?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Начало очистки..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Очистка %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Очистка раздела «%1» не выполнена: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Очистка завершена."
diff -pruN 4:18.04.1-1/po/sk/sweeper.po 4:20.04.1-0ubuntu1/po/sk/sweeper.po
--- 4:18.04.1-1/po/sk/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/sk/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -1,19 +1,20 @@
 # translation of sweeper.po to Slovak
 # Richard Fric <Richard.Fric@kdemail.net>, 2007.
 # Michal Sulek <misurel@gmail.com>, 2009, 2010.
+# Matej Mrenica <matejm98mthw@gmail.com>, 2019.
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2010-06-29 19:39+0200\n"
-"Last-Translator: Michal Sulek <misurel@gmail.com>\n"
-"Language-Team: Slovak <kde-sk@linux.sk>\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-11-18 11:02+0100\n"
+"Last-Translator: Matej Mrenica <matejm98mthw@gmail.com>\n"
+"Language-Team: Slovak <kde-i18n-doc@kde.org>\n"
 "Language: sk\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 1.0\n"
+"X-Generator: Lokalize 19.11.80\n"
 "Plural-Forms: nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;\n"
 
 #, kde-format
@@ -38,8 +39,8 @@ msgstr "Pomáha vyčistiť nechcené sto
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
-msgstr "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
+msgstr "© 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
 #, kde-format
@@ -76,17 +77,17 @@ msgstr "Vyrovnávacia pamäť náhľadov
 msgid "Sweeps without user interaction"
 msgstr "Vyčistí bez zásahu užívateľa"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Náhľady sa nepodarilo odstrániť."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Súbor existuje, ale nepodaril sa odstrániť."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Nepodarilo sa odstrániť favicon."
@@ -177,7 +178,7 @@ msgstr "Nedávne dokumenty"
 #, kde-format
 msgid ""
 "Clears the list of recently used documents from the KDE applications menu"
-msgstr "Vyčistí zoznam nedávno použitých dokumentov z menu aplikácií KDE"
+msgstr "Vyčistí zoznam nedávno použitých dokumentov z ponuky aplikácií KDE"
 
 #: privacyfunctions.h:128
 #, kde-format
@@ -197,43 +198,43 @@ msgstr "Nedávne aplikácie"
 #: privacyfunctions.h:139
 #, kde-format
 msgid "Clears the list of recently used applications from KDE menu"
-msgstr "Vyčistí zoznam nedávno použitých aplikácií z menu KDE"
+msgstr "Vyčistí zoznam nedávno použitých aplikácií z ponuky KDE"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Všeobecné"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Prehliadanie webu"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr ""
 "Chystáte sa odstrániť dáta, ktoré sa vám možno ešte hodia. Ste si istý?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Spúšťa sa čistenie..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Čistí sa %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Čistenie %1 zlyhalo: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Vyčistenie bolo dokončené."
diff -pruN 4:18.04.1-1/po/sl/sweeper.po 4:20.04.1-0ubuntu1/po/sl/sweeper.po
--- 4:18.04.1-1/po/sl/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/sl/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -9,8 +9,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: privacy\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
 "PO-Revision-Date: 2013-07-29 13:58+0200\n"
 "Last-Translator: Andrej Mernik <andrejm@ubuntu.si>\n"
 "Language-Team: Slovenian <lugos-slo@lugos.si>\n"
@@ -43,8 +43,9 @@ msgid "Helps clean unwanted traces the u
 msgstr "Pomaga počistiti neželene sledi, ki jih na računalniku pusti uporabnik"
 
 #: main.cpp:47
-#, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+#, fuzzy, kde-format
+#| msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "© 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
@@ -82,17 +83,17 @@ msgstr "Predpomnilnik za sličice"
 msgid "Sweeps without user interaction"
 msgstr "Čisti brez posredovanja uporabnika"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Sličice ni bilo mogoče odstraniti."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Datoteka obstaja, a je ni bilo mogoče odstraniti."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Ikone zaznamka ni bilo mogoče odstraniti."
@@ -205,41 +206,41 @@ msgstr "Nedavni programi"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Počisti seznam nedavno uporabljenih programov iz menija KDE"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Splošno"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Brskanje po spletu"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr ""
 "Izbrisali boste podatke, ki so lahko pomembni za vas. Ali ste prepričani?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Zaganjanje čiščenja ..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Čiščenje %1 ..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Čiščenje %1 ni uspelo: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Čiščenje končano."
diff -pruN 4:18.04.1-1/po/sr/sweeper.po 4:20.04.1-0ubuntu1/po/sr/sweeper.po
--- 4:18.04.1-1/po/sr/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/sr/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -9,7 +9,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
 "Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"POT-Creation-Date: 2018-08-16 09:11+0200\n"
 "PO-Revision-Date: 2016-03-20 15:25+0100\n"
 "Last-Translator: Chusslove Illich <caslav.ilic@gmx.net>\n"
 "Language-Team: Serbian <kde-i18n-sr@kde.org>\n"
diff -pruN 4:18.04.1-1/po/sv/sweeper.po 4:20.04.1-0ubuntu1/po/sv/sweeper.po
--- 4:18.04.1-1/po/sv/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/sv/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -3,20 +3,20 @@
 # Copyright (C) 2003, 2004, 2007, 2008, 2009 Free Software Foundation, Inc.
 #
 # Mattias Newzella <newzella@linux.nu>, 2003, 2004.
-# Stefan Asserhäll <stefan.asserhall@bredband.net>, 2004, 2007, 2008, 2009, 2010.
+# Stefan Asserhäll <stefan.asserhall@bredband.net>, 2004, 2007, 2008, 2009, 2010, 2019.
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2010-05-06 18:43+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-07-07 14:32+0100\n"
 "Last-Translator: Stefan Asserhäll <stefan.asserhall@bredband.net>\n"
 "Language-Team: Swedish <kde-i18n-doc@kde.org>\n"
 "Language: sv\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 1.0\n"
+"X-Generator: Lokalize 2.0\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 
 #, kde-format
@@ -41,7 +41,7 @@ msgstr "Hjälper till att rensa oönskad
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "© 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
@@ -79,17 +79,17 @@ msgstr "Miniatyrbildscache"
 msgid "Sweeps without user interaction"
 msgstr "Rensar utan inblandning av användaren"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "En miniatyrbild kunde inte tas bort."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Filen finns men kunde inte tas bort."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "En favoritikon kunde inte tas bort."
@@ -204,40 +204,40 @@ msgstr "Senaste program"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Rensar listan med senast använda program från KDE-menyn"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Allmänt"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Webbläsning"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "Du tar bort data som kan vara av värde för dig. Är du säker?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Startar rensning..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Rensar %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Rensning av %1 misslyckades: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Rensning klar."
diff -pruN 4:18.04.1-1/po/tr/sweeper.po 4:20.04.1-0ubuntu1/po/tr/sweeper.po
--- 4:18.04.1-1/po/tr/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/tr/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -9,8 +9,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: kdeutils-kde4\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
 "PO-Revision-Date: 2014-06-08 14:02+0000\n"
 "Last-Translator: Volkan Gezer <volkangezer@gmail.com>\n"
 "Language-Team: Turkish (http://www.transifex.com/projects/p/kdeutils-k-tr/"
@@ -43,8 +43,9 @@ msgstr ""
 "Kullanıcı tarafından sistemde bırakılmış olan ve istenmeyen izleri temizler."
 
 #: main.cpp:47
-#, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+#, fuzzy, kde-format
+#| msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "(c) 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
@@ -82,17 +83,17 @@ msgstr "Küçük Resim Önbelleği"
 msgid "Sweeps without user interaction"
 msgstr "Kullanıcı etkileşimi olmadan temizler"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Bir küçük resim silinemez."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Dosya var ancak silinemiyor."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Bir favicon silinemez."
@@ -208,41 +209,41 @@ msgstr "Son Kullanılan Uygulamalar"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "KDE menüsündeki son kullanılan uygulamalar listesini temizler"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Genel"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Web Tarama"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr ""
 "Sizin için önemli olabilecek bazı verileri silmek üzeresiniz. Emin misiniz?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Temizlik işlemi başlatılıyor..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "%1 temizleniyor..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "%1 temizlenirken bir hata oluştu: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Temizlik işlemi tamamlandı."
diff -pruN 4:18.04.1-1/po/ug/sweeper.po 4:20.04.1-0ubuntu1/po/ug/sweeper.po
--- 4:18.04.1-1/po/ug/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/ug/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -6,8 +6,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
 "PO-Revision-Date: 2013-09-08 07:05+0900\n"
 "Last-Translator: Gheyret Kenji <gheyret@gmail.com>\n"
 "Language-Team: Uyghur Computer Science Association <UKIJ@yahoogroups.com>\n"
@@ -38,8 +38,9 @@ msgid "Helps clean unwanted traces the u
 msgstr ""
 
 #: main.cpp:47
-#, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+#, fuzzy, kde-format
+#| msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "(c) 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
@@ -77,17 +78,17 @@ msgstr ""
 msgid "Sweeps without user interaction"
 msgstr ""
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr ""
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr ""
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr ""
@@ -200,40 +201,40 @@ msgstr "يېقىنقى پروگرامم
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr ""
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "ئادەتتىكى"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "تور كۆرۈش"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr ""
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr ""
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr ""
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr ""
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr ""
diff -pruN 4:18.04.1-1/po/uk/sweeper.po 4:20.04.1-0ubuntu1/po/uk/sweeper.po
--- 4:18.04.1-1/po/uk/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/uk/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -1,25 +1,25 @@
 # Translation of sweeper.po to Ukrainian
-# Copyright (C) 2003-2011 This_file_is_part_of_KDE
+# Copyright (C) 2003-2019 This_file_is_part_of_KDE
 # This file is distributed under the license LGPL version 2.1 or
 # version 3 or later versions approved by the membership of KDE e.V.
 #
 # Andriy Rysin <rysin@kde.org>, 2003, 2004.
 # Eugene Onischenko <oneugene@ukr.net>, 2004, 2005.
 # Ivan Petrouchtchak <fr.ivan@ukrainian-orthodox.org>, 2007, 2008.
-# Yuri Chornoivan <yurchor@ukr.net>, 2009, 2010, 2011.
+# Yuri Chornoivan <yurchor@ukr.net>, 2009, 2010, 2011, 2019.
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2011-02-20 11:32+0200\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-07-05 07:10+0300\n"
 "Last-Translator: Yuri Chornoivan <yurchor@ukr.net>\n"
-"Language-Team: Ukrainian <translation@linux.org.ua>\n"
+"Language-Team: Ukrainian <kde-i18n-uk@kde.org>\n"
 "Language: uk\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 1.2\n"
+"X-Generator: Lokalize 19.07.70\n"
 "Plural-Forms: nplurals=4; plural=n==1 ? 3 : n%10==1 && n%100!=11 ? 0 : n"
 "%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\n"
 
@@ -46,7 +46,7 @@ msgstr ""
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
 msgstr "© Ralf Hoelzer, 2003–2005"
 
 #: main.cpp:51
@@ -84,17 +84,17 @@ msgstr "Кеш мініатюр"
 msgid "Sweeps without user interaction"
 msgstr "Очищення без втручання користувача"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "Піктограму не вдалося вилучити."
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "Файл існує, але його не вдалося вилучити."
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "Не вдалося вилучити favicon."
@@ -207,41 +207,41 @@ msgstr "Недавні програми"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "Очищає список недавно вжитих програм з меню KDE"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "Загальне"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Навігація інтернетом"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr ""
 "Ви збираєтесь вилучити дані, які, можливо, важливі для вас. Продовжити?"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "Починаю очищення..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "Поступ очищення %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "Очищення %1 зазнало невдачі: %2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "Очищення завершено."
diff -pruN 4:18.04.1-1/po/zh_CN/sweeper.po 4:20.04.1-0ubuntu1/po/zh_CN/sweeper.po
--- 4:18.04.1-1/po/zh_CN/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/zh_CN/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -1,17 +1,16 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: kdeorg\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2018-04-26 06:12-0400\n"
-"Last-Translator: guoyunhebrave <guoyunhebrave@gmail.com>\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2020-05-09 13:52\n"
+"Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: Chinese Simplified\n"
 "Language: zh_CN\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=1; plural=0;\n"
-"X-Generator: crowdin.com\n"
 "X-Crowdin-Project: kdeorg\n"
 "X-Crowdin-Language: zh-CN\n"
 "X-Crowdin-File: /kf5-stable/messages/kdeutils/sweeper.pot\n"
@@ -38,8 +37,8 @@ msgstr "帮您清理用户留在系统
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
-msgstr "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
+msgstr "© 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
 #, kde-format
@@ -49,7 +48,7 @@ msgstr "Ralf Hoelzer"
 #: main.cpp:51
 #, kde-format
 msgid "Original author"
-msgstr "原作者"
+msgstr "最初作者"
 
 #: main.cpp:52
 #, kde-format
@@ -76,17 +75,17 @@ msgstr "缩略图缓存"
 msgid "Sweeps without user interaction"
 msgstr "无需用户交互进行清理"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "一个缩略图无法删除。"
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "文件存在但无法删除。"
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "一个网站图标无法删除。"
@@ -94,12 +93,12 @@ msgstr "一个网站图标无法删除
 #: privacyfunctions.h:37
 #, kde-format
 msgid "Cookies"
-msgstr "Cookies"
+msgstr "Cookie"
 
 #: privacyfunctions.h:38
 #, kde-format
 msgid "Clears all stored cookies set by websites"
-msgstr "清理所有储存的网站 cookies"
+msgstr "清理所有储存的网站 Cookie"
 
 #: privacyfunctions.h:48
 #, kde-format
@@ -109,7 +108,7 @@ msgstr "Cookie 规则"
 #: privacyfunctions.h:49
 #, kde-format
 msgid "Clears the cookie policies for all visited websites"
-msgstr "清理所有访问过站点的 cookies 规则"
+msgstr "清理所有访问过站点的 Cookie 规则"
 
 #: privacyfunctions.h:58
 #, kde-format
@@ -199,40 +198,40 @@ msgstr "最近使用的程序"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "清理 KDE 应用程序菜单上用户最近使用过的程序"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "常规"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "Web 浏览"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "您正要删除可能对您有用的数据。您确认要删除吗？"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "开始清理..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "正在清理 %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "清理 %1 失败：%2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "清理完成。"
@@ -249,19 +248,19 @@ msgstr "选中所有您要进行的清
 #: sweeperdialog.ui:37
 #, kde-format
 msgid "Privacy Settings"
-msgstr ""
+msgstr "隐私设置"
 
 #. i18n: ectx: property (text), widget (QTreeWidget, privacyListView)
 #: sweeperdialog.ui:42
 #, kde-format
 msgid "Description"
-msgstr "描述"
+msgstr "说明"
 
 #. i18n: ectx: property (text), widget (QPushButton, selectAllButton)
 #: sweeperdialog.ui:58
 #, kde-format
 msgid "Select &All"
-msgstr "全选(&A)"
+msgstr "全选 (&A)"
 
 #. i18n: ectx: property (text), widget (QPushButton, selectNoneButton)
 #: sweeperdialog.ui:65
diff -pruN 4:18.04.1-1/po/zh_TW/sweeper.po 4:20.04.1-0ubuntu1/po/zh_TW/sweeper.po
--- 4:18.04.1-1/po/zh_TW/sweeper.po	2018-05-08 00:12:30.000000000 +0000
+++ 4:20.04.1-0ubuntu1/po/zh_TW/sweeper.po	2020-05-12 01:16:33.000000000 +0000
@@ -4,21 +4,21 @@
 # Keng-Tso Ou <jupiter@ocool.org>, 2003.
 # Franklin Weng <franklin at goodhorse dot idv dot tw>, 2007.
 # Frank Weng (a.k.a. Franklin) <franklin at goodhorse dot idv dot tw>, 2008, 2009, 2010.
+# pan93412 <pan93412@gmail.com>, 2019.
 msgid ""
 msgstr ""
 "Project-Id-Version: sweeper\n"
-"Report-Msgid-Bugs-To: http://bugs.kde.org\n"
-"POT-Creation-Date: 2017-10-12 03:24+0200\n"
-"PO-Revision-Date: 2010-05-30 14:11+0800\n"
-"Last-Translator: Frank Weng (a.k.a. Franklin) <franklin at goodhorse dot idv "
-"dot tw>\n"
-"Language-Team: Chinese Traditional <zh-l10n@linux.org.tw>\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2020-02-14 03:28+0100\n"
+"PO-Revision-Date: 2019-07-09 14:11+0800\n"
+"Last-Translator: pan93412 <pan93412@gmail.com>\n"
+"Language-Team: Chinese <zh-l10n@lists.linux.org.tw>\n"
 "Language: zh_TW\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=1; plural=0;\n"
-"X-Generator: Lokalize 1.0\n"
+"X-Generator: Lokalize 19.04.2\n"
 
 #, kde-format
 msgctxt "NAME OF TRANSLATORS"
@@ -42,8 +42,8 @@ msgstr "協助您清除使用者在系
 
 #: main.cpp:47
 #, kde-format
-msgid "(c) 2003-2005, Ralf Hoelzer"
-msgstr "(c) 2003-2005, Ralf Hoelzer"
+msgid "© 2003-2005, Ralf Hoelzer"
+msgstr "© 2003-2005, Ralf Hoelzer"
 
 #: main.cpp:51
 #, kde-format
@@ -80,17 +80,17 @@ msgstr "縮圖快取"
 msgid "Sweeps without user interaction"
 msgstr "清除時不與使用者互動"
 
-#: privacyfunctions.cpp:61 privacyfunctions.cpp:70 privacyfunctions.cpp:79
+#: privacyfunctions.cpp:60 privacyfunctions.cpp:69 privacyfunctions.cpp:78
 #, kde-format
 msgid "A thumbnail could not be removed."
 msgstr "無法移除縮圖。"
 
-#: privacyfunctions.cpp:150
+#: privacyfunctions.cpp:149
 #, kde-format
 msgid "The file exists but could not be removed."
 msgstr "檔案存在，但無法被移除。"
 
-#: privacyfunctions.cpp:236
+#: privacyfunctions.cpp:234
 #, kde-format
 msgid "A favicon could not be removed."
 msgstr "無法移除圖示。"
@@ -203,40 +203,40 @@ msgstr "最近使用的應用程式"
 msgid "Clears the list of recently used applications from KDE menu"
 msgstr "清除 KDE 應用程式選單中列出的最近使用的文件"
 
-#: sweeper.cpp:49
+#: sweeper.cpp:34
 #, kde-format
 msgctxt "General system content"
 msgid "General"
 msgstr "一般"
 
-#: sweeper.cpp:51
+#: sweeper.cpp:35
 #, kde-format
 msgctxt "Web browsing content"
 msgid "Web Browsing"
 msgstr "網頁瀏覽"
 
-#: sweeper.cpp:126
+#: sweeper.cpp:115
 #, kde-format
 msgid ""
 "You are deleting data that is potentially valuable to you. Are you sure?"
 msgstr "您現在清除的是可能對您有價值的資料。確定要這樣做？"
 
-#: sweeper.cpp:132
+#: sweeper.cpp:121
 #, kde-format
 msgid "Starting cleanup..."
 msgstr "開始清除..."
 
-#: sweeper.cpp:138
+#: sweeper.cpp:125
 #, kde-format
 msgid "Clearing %1..."
 msgstr "正在清除 %1..."
 
-#: sweeper.cpp:143
+#: sweeper.cpp:130
 #, kde-format
 msgid "Clearing of %1 failed: %2"
 msgstr "清除 %1 失敗：%2"
 
-#: sweeper.cpp:149
+#: sweeper.cpp:136
 #, kde-format
 msgid "Clean up finished."
 msgstr "已完成清除。"
@@ -284,86 +284,3 @@ msgstr "馬上執行上方選取的清
 #, kde-format
 msgid "&Clean Up"
 msgstr "清除(&C)"
-
-#~ msgid "Network privacy level:"
-#~ msgstr "網路隱私等級:"
-
-#~ msgid "Low"
-#~ msgstr "低"
-
-#~ msgid "Medium"
-#~ msgstr "中"
-
-#~ msgid "High"
-#~ msgstr "高"
-
-#~ msgid "Custom"
-#~ msgstr "使用者自訂"
-
-#~ msgid "Financial Information"
-#~ msgstr "財務資訊"
-
-#~ msgid ""
-#~ "Warn me when I visit a site that uses my financial or purchase "
-#~ "information:"
-#~ msgstr "當我瀏覽使用我的財務或購物資訊的網站時對我發出警告："
-
-#~ msgid "For marketing or advertising purposes"
-#~ msgstr "因行銷或廣告目的"
-
-#~ msgid "To share with other companies"
-#~ msgstr "與其他公司分享"
-
-#~ msgid "Health Information"
-#~ msgstr "健康資訊"
-
-#~ msgid ""
-#~ "Warn me when I visit a site that uses my health or medical information: "
-#~ msgstr "當我瀏覽使用我的健康或醫療資訊的網站時對我發出警告："
-
-#~ msgid "Demographics"
-#~ msgstr "人口統計資料"
-
-#~ msgid ""
-#~ "Warn me when I visit a site that uses my non-personally identifiable "
-#~ "information:"
-#~ msgstr "當我瀏覽使用我非個人可識別資訊的網站對我發出警告："
-
-#~ msgid "To determine my interests, habits or general behavior"
-#~ msgstr "來偵查我的興趣，習慣或者一般行為"
-
-#~ msgid ""
-#~ "Warn me when I visit a site that shares my personal information with "
-#~ "other companies"
-#~ msgstr "當我瀏覽將與其他公司分享我個人資訊的網站對我發出警告"
-
-#~ msgid ""
-#~ "Warn me when I visit a site that does not let me know what information "
-#~ "they have about me"
-#~ msgstr "當我瀏覽一個不告知我其所掌握關於我之資訊的網站對我發出警告"
-
-#~ msgid "Personal Information"
-#~ msgstr "個人資訊"
-
-#~ msgid ""
-#~ "Warn me when I visit a site that may contact me about other products or "
-#~ "services:"
-#~ msgstr "當我瀏覽將因其他產品或服務聯繫我的網站對我發出警告"
-
-#~ msgid "Warn me when I visit a site that may use my personal information to:"
-#~ msgstr "當我瀏覽將把我的個人資訊作為其他用途的網站對我發出警告："
-
-#~ msgid "Determine my habits, interests or general behavior"
-#~ msgstr "來偵查我的興趣，習慣或者一般行為"
-
-#~ msgid "Via telephone"
-#~ msgstr "透過電話"
-
-#~ msgid "Via mail"
-#~ msgstr "透過郵件"
-
-#~ msgid "Via email"
-#~ msgstr "透過電子郵件"
-
-#~ msgid "And do not allow me to remove my contact information"
-#~ msgstr "以及不讓我移除我的聯絡資訊"
diff -pruN 4:18.04.1-1/privacyaction.cpp 4:20.04.1-0ubuntu1/privacyaction.cpp
--- 4:18.04.1-1/privacyaction.cpp	2018-05-06 04:10:53.000000000 +0000
+++ 4:20.04.1-0ubuntu1/privacyaction.cpp	2020-05-11 21:17:33.000000000 +0000
@@ -28,9 +28,4 @@ PrivacyAction::PrivacyAction(QTreeWidget
    setCheckState(0, Qt::Unchecked);
 }
 
-PrivacyAction::~PrivacyAction()
-{
-   // nothing to do
-}
-
 // kate: tab-width 3; indent-mode cstyle; replace-tabs true;
diff -pruN 4:18.04.1-1/privacyaction.h 4:20.04.1-0ubuntu1/privacyaction.h
--- 4:18.04.1-1/privacyaction.h	2018-05-06 04:10:53.000000000 +0000
+++ 4:20.04.1-0ubuntu1/privacyaction.h	2020-05-11 21:17:33.000000000 +0000
@@ -25,7 +25,7 @@ class PrivacyAction : public QTreeWidget
 {
    public:
       PrivacyAction(QTreeWidgetItem * parent, const QString &name, const QString &desc = QString());
-      ~PrivacyAction();
+      ~PrivacyAction() override = default;
       
       QString getErrMsg() const { return errMsg; }
       
diff -pruN 4:18.04.1-1/privacyfunctions.cpp 4:20.04.1-0ubuntu1/privacyfunctions.cpp
--- 4:18.04.1-1/privacyfunctions.cpp	2018-05-06 04:10:53.000000000 +0000
+++ 4:20.04.1-0ubuntu1/privacyfunctions.cpp	2020-05-11 21:17:33.000000000 +0000
@@ -24,7 +24,6 @@
 #include <KConfig>
 #include <KConfigGroup>
 #include <KRecentDocument>
-#include <KToolInvocation>
 #include <KActivities/Stats/Cleaning>
 #include <KActivities/Stats/ResultSet>
 #include <KActivities/Stats/Terms>
@@ -41,7 +40,7 @@
 #include <QStandardPaths>
 #include <QStringList>
 
-#include "config-sweeper.h"
+#include <config-sweeper.h>
 
 namespace KAStats = KActivities::Stats;
 
@@ -56,8 +55,8 @@ bool ClearThumbnailsAction::action()
    QDir thumbnailDir( QDir::homePath() + QLatin1String( "/.cache/thumbnails/normal" ));
    thumbnailDir.setFilter( QDir::Files );
    const QStringList entries = thumbnailDir.entryList();
-   for( QStringList::const_iterator it = entries.begin() ; it != entries.end() ; ++it) {
-      if(!thumbnailDir.remove(*it)) {
+   for(const QString &entry: entries) {
+      if(!thumbnailDir.remove(entry)) {
          errMsg = i18n("A thumbnail could not be removed.");
          return false;
       }
@@ -65,8 +64,8 @@ bool ClearThumbnailsAction::action()
 
    thumbnailDir.setPath(QDir::homePath() + QLatin1String( "/.cache/thumbnails/large" ));
    const QStringList entries2 = thumbnailDir.entryList();
-   for( QStringList::const_iterator it = entries2.begin() ; it != entries2.end() ; ++it) {
-      if(!thumbnailDir.remove(*it)) {
+   for(const QString &entry: entries2) {
+      if(!thumbnailDir.remove(entry)) {
          errMsg = i18n("A thumbnail could not be removed.");
          return false;
       }
@@ -74,8 +73,8 @@ bool ClearThumbnailsAction::action()
 
    thumbnailDir.setPath(QDir::homePath() + QLatin1String( "/.cache/thumbnails/fail" ));
    const QStringList entries3 = thumbnailDir.entryList();
-   for( QStringList::const_iterator it = entries3.begin() ; it != entries3.end() ; ++it) {
-      if(!thumbnailDir.remove(*it)) {
+   for(const QString &entry: entries3) {
+      if(!thumbnailDir.remove(entry)) {
          errMsg = i18n("A thumbnail could not be removed.");
          return false;
       }
@@ -125,7 +124,7 @@ bool ClearAllCookiesPoliciesAction::acti
 bool ClearSavedClipboardContentsAction::action()
 {
    if(!QDBusConnection::sessionBus().interface()->isServiceRegistered(QStringLiteral("org.kde.klipper"))) {
-      KConfig *c = new KConfig(QStringLiteral("klipperrc"), KConfig::NoGlobals);
+      auto c = new KConfig(QStringLiteral("klipperrc"), KConfig::NoGlobals);
       KConfigGroup group(c, "General");
       group.deleteEntry("ClipboardData");
       c->sync();
@@ -155,8 +154,7 @@ bool ClearFormCompletionAction::action()
 
 bool ClearWebCacheAction::action()
 {
-   QStringList lst;
-   lst << QStringLiteral("--clear-all");
+   const QStringList lst { QStringLiteral("--clear-all") };
    return QProcess::startDetached(QFile::decodeName(KDE_INSTALL_FULL_LIBEXECDIR_KF5 "/kio_http_cache_cleaner"), lst);
 }
 
@@ -203,8 +201,8 @@ bool ClearFaviconsAction::action()
    QDir().mkpath(path);
    konqiBookmarkMgr =
       KBookmarkManager::managerForFile(path, QStringLiteral("konqueror"));
-   qDebug() << "saving the favicons that are in konqueror bookmarks" ;
-   qDebug() << "opened konqueror bookmarks at " << konqiBookmarkMgr->path() ;
+   qDebug() << "saving the favicons that are in konqueror bookmarks"
+            << "opened konqueror bookmarks at " << konqiBookmarkMgr->path() ;
 
    // get the entire slew of bookmarks
    KBookmarkGroup konqiBookmarks = konqiBookmarkMgr->root();
@@ -228,11 +226,11 @@ bool ClearFaviconsAction::action()
    const QStringList entries = favIconDir.entryList();
 
    // erase all files in favicon directory...
-   for( QStringList::const_iterator it = entries.begin() ; it != entries.end() ; ++it) {
+   for(const QString &entry: entries) {
       // ...if we're not supposed to save them, of course
-      if (!saveTheseFavicons.contains(*it)) {
-         qDebug() << "removing " << *it ;
-         if(!favIconDir.remove(*it)) {
+      if (!saveTheseFavicons.contains(entry)) {
+         qDebug() << "removing " << entry ;
+         if(!favIconDir.remove(entry)) {
             errMsg = i18n("A favicon could not be removed.");
             return false;
          }
diff -pruN 4:18.04.1-1/privacyfunctions.h 4:20.04.1-0ubuntu1/privacyfunctions.h
--- 4:18.04.1-1/privacyfunctions.h	2018-05-06 04:10:53.000000000 +0000
+++ 4:20.04.1-0ubuntu1/privacyfunctions.h	2020-05-11 21:17:33.000000000 +0000
@@ -37,8 +37,8 @@ class ClearAllCookiesAction : public Pri
          : PrivacyAction(parent, i18n("Cookies"),
                          i18n("Clears all stored cookies set by websites")) { }
 
-      bool action();
-      /* reimp */ QString configKey() const { return QStringLiteral("ClearAllCookies"); }
+      bool action() override;
+      QString configKey() const override { return QStringLiteral("ClearAllCookies"); }
 };
 
 class ClearAllCookiesPoliciesAction : public PrivacyAction
@@ -47,8 +47,8 @@ class ClearAllCookiesPoliciesAction : pu
       explicit ClearAllCookiesPoliciesAction(QTreeWidgetItem * parent)
          : PrivacyAction(parent, i18n("Cookie Policies"),
                          i18n("Clears the cookie policies for all visited websites")) { }
-      bool action();
-      /* reimp */ QString configKey() const { return QStringLiteral("ClearAllCookiesPolicies"); }
+      bool action() override;
+      QString configKey() const override { return QStringLiteral("ClearAllCookiesPolicies"); }
 };
 
 class ClearSavedClipboardContentsAction : public PrivacyAction
@@ -57,8 +57,8 @@ class ClearSavedClipboardContentsAction
       explicit ClearSavedClipboardContentsAction(QTreeWidgetItem * parent)
          : PrivacyAction(parent, i18n("Saved Clipboard Contents"),
                          i18n("Clears the clipboard contents stored by Klipper")) { }
-      bool action();
-      /* reimp */ QString configKey() const { return QStringLiteral("ClearSavedClipboardContents"); }
+      bool action() override;
+      QString configKey() const override { return QStringLiteral("ClearSavedClipboardContents"); }
 };
 
 class ClearThumbnailsAction : public PrivacyAction
@@ -67,8 +67,8 @@ class ClearThumbnailsAction : public Pri
       explicit ClearThumbnailsAction(QTreeWidgetItem * parent)
          : PrivacyAction(parent, i18n("Thumbnail Cache"),
                          i18n("Clears all cached thumbnails")) { }
-      bool action();
-      /* reimp */ QString configKey() const { return QStringLiteral("ClearThumbnails"); }
+      bool action() override;
+      QString configKey() const override { return QStringLiteral("ClearThumbnails"); }
 };
 
 class ClearRunCommandHistoryAction : public PrivacyAction
@@ -77,8 +77,8 @@ class ClearRunCommandHistoryAction : pub
       explicit ClearRunCommandHistoryAction(QTreeWidgetItem * parent)
          : PrivacyAction(parent, i18n("Run Command History"),
                          i18n("Clears the history of commands run through the Run Command tool on the desktop")) { }
-      bool action();
-      /* reimp */ QString configKey() const { return QStringLiteral("ClearRunCommandHistory"); }
+      bool action() override;
+      QString configKey() const override { return QStringLiteral("ClearRunCommandHistory"); }
 };
 
 class ClearFormCompletionAction : public PrivacyAction
@@ -87,8 +87,8 @@ class ClearFormCompletionAction : public
       explicit ClearFormCompletionAction(QTreeWidgetItem * parent)
          : PrivacyAction(parent, i18n("Form Completion Entries"),
                          i18n("Clears values which were entered into forms on websites")) { }
-      bool action();
-      /* reimp */ QString configKey() const { return QStringLiteral("ClearFormCompletion"); }
+      bool action() override;
+      QString configKey() const override { return QStringLiteral("ClearFormCompletion"); }
 };
 
 class ClearWebHistoryAction : public PrivacyAction
@@ -97,8 +97,8 @@ class ClearWebHistoryAction : public Pri
       explicit ClearWebHistoryAction(QTreeWidgetItem * parent)
          : PrivacyAction(parent, i18n("Web History"),
                          i18n("Clears the history of visited websites")) { }
-      bool action();
-      /* reimp */ QString configKey() const { return QStringLiteral("ClearWebHistory"); }
+      bool action() override;
+      QString configKey() const override { return QStringLiteral("ClearWebHistory"); }
 };
 
 class ClearWebCacheAction : public PrivacyAction
@@ -107,8 +107,8 @@ class ClearWebCacheAction : public Priva
       explicit ClearWebCacheAction(QTreeWidgetItem * parent)
          : PrivacyAction(parent, i18n("Web Cache"),
                          i18n("Clears the temporary cache of websites visited")) { }
-      bool action();
-      /* reimp */ QString configKey() const { return QStringLiteral("ClearWebCache"); }
+      bool action() override;
+      QString configKey() const override { return QStringLiteral("ClearWebCache"); }
 };
 
 class ClearRecentDocumentsAction : public PrivacyAction
@@ -117,8 +117,8 @@ class ClearRecentDocumentsAction : publi
       explicit ClearRecentDocumentsAction(QTreeWidgetItem * parent)
          : PrivacyAction(parent, i18n("Recent Documents"),
                          i18n("Clears the list of recently used documents from the KDE applications menu")) { }
-      bool action();
-      /* reimp */ QString configKey() const { return QStringLiteral("ClearRecentDocuments"); }
+      bool action() override;
+      QString configKey() const override { return QStringLiteral("ClearRecentDocuments"); }
 };
 
 class ClearFaviconsAction : public PrivacyAction
@@ -127,8 +127,8 @@ class ClearFaviconsAction : public Priva
       explicit ClearFaviconsAction(QTreeWidgetItem * parent)
          : PrivacyAction(parent, i18n("Favorite Icons"),
                          i18n("Clears the FavIcons cached from visited websites")) { }
-      bool action();
-      /* reimp */ QString configKey() const { return QStringLiteral("ClearFavIcons"); }
+      bool action() override;
+      QString configKey() const override { return QStringLiteral("ClearFavIcons"); }
 };
 
 class ClearRecentApplicationAction : public PrivacyAction
@@ -137,8 +137,8 @@ class ClearRecentApplicationAction : pub
       explicit ClearRecentApplicationAction(QTreeWidgetItem * parent)
          : PrivacyAction(parent, i18n("Recent Applications"),
                          i18n("Clears the list of recently used applications from KDE menu")) { }
-      bool action();
-      /* reimp */ QString configKey() const { return QStringLiteral("ClearQuickStartMenu"); }
+      bool action() override;
+      QString configKey() const override { return QStringLiteral("ClearQuickStartMenu"); }
 };
 
 
diff -pruN 4:18.04.1-1/sweeper.cpp 4:20.04.1-0ubuntu1/sweeper.cpp
--- 4:18.04.1-1/sweeper.cpp	2018-05-06 04:10:53.000000000 +0000
+++ 4:20.04.1-0ubuntu1/sweeper.cpp	2020-05-11 21:17:33.000000000 +0000
@@ -30,11 +30,13 @@
 #include <QDBusConnection>
 
 Sweeper::Sweeper(bool automatic)
-   : KXmlGuiWindow(0)
+   : KXmlGuiWindow(nullptr)
+   , generalCLI(new QTreeWidgetItem(QStringList(i18nc("General system content", "General"))))
+   , webbrowsingCLI(new QTreeWidgetItem(QStringList(i18nc("Web browsing content", "Web Browsing"))))
    , m_privacyConfGroup(KSharedConfig::openConfig(QStringLiteral("kprivacyrc"), KConfig::NoGlobals), "Cleaning")
    , m_automatic(automatic)
 {
-   QWidget *mainWidget = new QWidget(this);
+   auto mainWidget = new QWidget(this);
    ui.setupUi(mainWidget);
    setCentralWidget(mainWidget);
 
@@ -46,9 +48,7 @@ Sweeper::Sweeper(bool automatic)
 
    setAutoSaveSettings();
 
-   generalCLI     = new QTreeWidgetItem(QStringList() << i18nc("General system content", "General"));
    sw->addTopLevelItem(generalCLI);
-   webbrowsingCLI = new QTreeWidgetItem(QStringList() << i18nc("Web browsing content", "Web Browsing"));
    sw->addTopLevelItem(webbrowsingCLI);
 
    generalCLI->setExpanded(true);
@@ -81,19 +81,15 @@ Sweeper::~Sweeper()
 
 void Sweeper::load()
 {
-   QLinkedList<PrivacyAction*>::iterator itr;
-
-   for (itr = checklist.begin(); itr != checklist.end(); ++itr) {
-      (*itr)->setCheckState(0, m_privacyConfGroup.readEntry((*itr)->configKey(), true) ? Qt::Checked : Qt::Unchecked);
+   for (auto &&act: checklist) {
+      act->setCheckState(0, m_privacyConfGroup.readEntry(act->configKey(), true) ? Qt::Checked : Qt::Unchecked);
    }
 }
 
 void Sweeper::save()
 {
-   QLinkedList<PrivacyAction*>::iterator itr;
-
-   for (itr = checklist.begin(); itr != checklist.end(); ++itr) {
-      m_privacyConfGroup.writeEntry((*itr)->configKey(), (*itr)->checkState(0) == Qt::Checked);
+   for (auto &&act: checklist) {
+      m_privacyConfGroup.writeEntry(act->configKey(), act->checkState(0) == Qt::Checked);
    }
 
    m_privacyConfGroup.sync();
@@ -101,25 +97,18 @@ void Sweeper::save()
 
 void Sweeper::selectAll()
 {
-   QLinkedList<PrivacyAction*>::iterator itr;
-
-   for (itr = checklist.begin(); itr != checklist.end(); ++itr) {
-      (*itr)->setCheckState(0, Qt::Checked);
+   for (auto &&act: checklist) {
+      act->setCheckState(0, Qt::Checked);
    }
-
 }
 
 void Sweeper::selectNone()
 {
-   QLinkedList<PrivacyAction*>::iterator itr;
-
-   for (itr = checklist.begin(); itr != checklist.end(); ++itr) {
-      (*itr)->setCheckState(0, Qt::Unchecked);
+   for (auto &&act: checklist) {
+      act->setCheckState(0, Qt::Unchecked);
    }
-
 }
 
-
 void Sweeper::cleanup()
 {
    if (!m_automatic) {
@@ -131,16 +120,14 @@ void Sweeper::cleanup()
    ui.statusTextEdit->clear();
    ui.statusTextEdit->setText(i18n("Starting cleanup..."));
 
-   QLinkedList<PrivacyAction*>::iterator itr;
-
-   for (itr = checklist.begin(); itr != checklist.end(); ++itr) {
-      if((*itr)->checkState(0) == Qt::Checked) {
-         QString statusText = i18n("Clearing %1...", (*itr)->text(0));
+   for (auto &&act: checklist) {
+      if(act->checkState(0) == Qt::Checked) {
+         QString statusText = i18n("Clearing %1...", act->text(0));
          ui.statusTextEdit->append(statusText);
 
          // actions return whether they were successful
-         if(!(*itr)->action()) {
-            QString errorText =  i18n("Clearing of %1 failed: %2", (*itr)->text(0), (*itr)->getErrMsg());
+         if(!act->action()) {
+            QString errorText = i18n("Clearing of %1 failed: %2", act->text(0), act->getErrMsg());
             ui.statusTextEdit->append(errorText);
          }
       }
diff -pruN 4:18.04.1-1/sweeper.h 4:20.04.1-0ubuntu1/sweeper.h
--- 4:18.04.1-1/sweeper.h	2018-05-06 04:10:53.000000000 +0000
+++ 4:20.04.1-0ubuntu1/sweeper.h	2020-05-11 21:17:33.000000000 +0000
@@ -22,7 +22,7 @@
 #include <KConfigGroup>
 #include <KXmlGuiWindow>
 
-#include <QLinkedList>
+#include <QVector>
 
 #include "ui_sweeperdialog.h"
 
@@ -58,10 +58,10 @@ class Sweeper: public KXmlGuiWindow
        */
       Ui::SweeperDialog ui;
 
-      QLinkedList<PrivacyAction*> checklist;
+      QVector<PrivacyAction*> checklist;
 
-      QTreeWidgetItem *generalCLI;
-      QTreeWidgetItem *webbrowsingCLI;
+      QTreeWidgetItem * const generalCLI;
+      QTreeWidgetItem * const webbrowsingCLI;
 
       KConfigGroup m_privacyConfGroup;
 
diff -pruN 4:18.04.1-1/sweeperui.rc 4:20.04.1-0ubuntu1/sweeperui.rc
--- 4:18.04.1-1/sweeperui.rc	2018-05-06 04:10:53.000000000 +0000
+++ 4:20.04.1-0ubuntu1/sweeperui.rc	2020-05-11 21:17:33.000000000 +0000
@@ -1,5 +1,5 @@
-<!DOCTYPE kpartgui>
-<kpartgui name="sweeper" version="1">
+<!DOCTYPE gui SYSTEM "kpartgui.dtd">
+<gui name="sweeper" version="1">
 <MenuBar>
 </MenuBar>
-</kpartgui>
+</gui>
